##########################################################################################################################################;
# Empirical Example for "Extrapolating: External Validity ind Overidentification in i LATE Framework," by J. Angrist ind I. Fernandez-Val ;
##########################################################################################################################################;

#######################################################################################;
# Program:  Female LFP		  			                              #;
# Source of data:  CENSUS80 (Josh web site)					      #;
# Variables:									      #;
#		- y1: weeksm1							      #;
#		- y2: workedm							      #;
#		- x: morkids							      #;
#		- z1: samesex							      #;
#		- z2: multi2nd							      #;
#		- g1: age group							      #;
#		- g2: educ group						      #;		
#		- g = 10*g1 + g2: age-educ group				      #;
#		- gi1 ... gi16: age-educ group indicator for 11, 12, ..., 44	      #;
#######################################################################################;

# Std. Errors computed using EL-bootstrap; ucomment lines 2,040 and 2,549 to obtain nonparametric bootstrap std. errors;
# This code produces Tables 3 and 4, and Figure 1

library(foreign);
library(stats);
library(sem);
library(sandwich)
#library(lattice);

data	<- read.dta("/Users/Ivan/Dropbox/ivanf/ExtrapoLATE/Data/fulldata.dta");
attach(data);

################################################################################################;
#  FUNCTIONS FROM PACKAGE GMM VERSION 1.0-6 :
################################################################################################;

gmm <- function(g,x,t0=NULL,gradv=NULL, type=c("twoStep","cue","iterative"), wmatrix = c("optimal","ident"),  vcov=c("HAC","iid"), 
                kernel=c("Quadratic Spectral","Truncated", "Bartlett", "Parzen", "Tukey-Hanning"),crit=10e-7,bw = bwAndrews2, 
                prewhite = FALSE, ar.method = "ols", approx="AR(1)",tol = 1e-7, itermax=100,intercept=TRUE,optfct=c("optim","optimize"), ...)
{
  type <- match.arg(type)
  kernel <- match.arg(kernel)
  vcov <- match.arg(vcov)
  wmatrix <- match.arg(wmatrix)
  optfct <- match.arg(optfct)
  typeg=0
  
  if (is(g,"formula"))
  {
    typeg=1
    dat <- get_dat(g,x,intercept=intercept)
    x <- dat$x
    
    g <- function(tet,x,ny=dat$ny,nh=dat$nh,k=dat$k)
    {
      tet <- matrix(tet,ncol=k)
      if (intercept)
      {
        e <- x[,1:ny] -  x[,(ny+1):(ny+k)]%*%t(tet)
        gt <- e
        for (i in 2:nh)
        {
          gt <- cbind(gt,e*x[,(ny+k+i)])
        }
      }
      if (!intercept)
        e <- x[,1:ny] -  x[,(ny+1):(ny+k)]%*%t(tet)
      gt <- e*x[,ny+k+1]
      if (nh > 1)
      {	
        for (i in 2:nh)
        {
          gt <- cbind(gt,e*x[,(ny+k+i)])
        }
      }
      return(gt)
    }
    gradv <- function(x,ny=dat$ny,nh=dat$nh,k=dat$k)
    {
      dgb <- -(t(x[,(ny+k+1):(ny+k+nh)])%*%x[,(ny+1):(ny+k)])%x%diag(rep(1,ny))/nrow(x)
      return(dgb)
    }
    tetlin <- function(x,w,ny=dat$ny,nh=dat$nh,k=dat$k)
    {
      n <- nrow(x)
      ym <- as.matrix(x[,1:ny])
      xm <- as.matrix(x[,(ny+1):(ny+k)])
      hm <- as.matrix(x[,(ny+k+1):(ny+k+nh)])
      whx <- solve(w,(crossprod(hm,xm)%x%diag(ny)))	
      wvecyh <- solve(w,matrix(crossprod(ym,hm),ncol=1))
      dg <- gradv(x)
      xx <- crossprod(dg,whx)
      par <- solve(xx,crossprod(dg,wvecyh))
      gb <- matrix(colSums(g(par,x))/n,ncol=1)
      value <- crossprod(gb,solve(w,gb)) 
      res <- list(par=par,value=value)
      return(res)
    }
  }
  if (optfct == "optimize")
  {
    n = nrow(g(t0[1],x))
    q = ncol(g(t0[1],x))
    k = 1
    k2 <- k
    df <- q-k
  }
  else
  {
    if (typeg)
    {
      k <- dat$k
      k2 <- k*dat$ny
      n <- nrow(x)
      q <- dat$ny*dat$nh
      df <- q-k*dat$ny
    }
    else
    {
      n = nrow(g(t0,x))
      q = ncol(g(t0,x))
      k = length(t0)
      k2 <- k
      df <- q-k
    }
  }
  obj1 <- function(thet)
  {
    gt <- g(thet,x)
    gbar <- as.vector(colMeans(gt))
    obj <- crossprod(gbar,solve(w,gbar))
    return(obj)
  }
  iid <- function(thet)
  {
    gt <- g(thet,x)
    v <- crossprod(gt,gt)/n
    return(v)
  }
  Gf <- function(thet)
  {
    myenv <- new.env()
    assign('x',x,envir=myenv)
    assign('thet',thet,envir=myenv)
    barg <- function(x,thet)
    {
      gt <- g(thet,x)
      gbar <- as.vector(colMeans(gt))
      return(gbar)
    }
    G <- attr(numericDeriv(quote(barg(x,thet)),"thet",myenv),"gradient")
    return(G)
  }
  
  if (q == k2 | wmatrix == "ident")
  {
    if (typeg)
    {
      w <- diag(q)
      res <- tetlin(x,w)
      z = list(par=res$par,objective=res$value)
    }
    else
    {
      w=diag(rep(1,q))
      if (optfct == "optim")
        res <- optim(t0,obj1, ...)
      else
      {
        res <- optimize(obj1,t0, ...)
        res$par <- res$minimum
        res$value <- res$objective
      }	
      z = list(par=res$par,objective=res$value)	
    }
  }
  else
  {
    if (type=="twoStep")
    {
      w=diag(rep(1,q))
      if (typeg)
      {
        res1 <- tetlin(x,w)
      }
      else
      {
        if (optfct == "optim")
          res1 <- optim(t0,obj1, ...)
        else
        {
          res1 <- optimize(obj1,t0, ...)
          res1$par <- res1$minimum
          res1$value <- res1$objective
        }	
      }
      if (vcov == "iid")
        w <- iid(res1$par)
      if (vcov == "HAC")
        w <- HAC(g(res1$par,x), kernel=kernel, bw=bw,prewhite=prewhite,ar.method=ar.method,approx=approx,tol=tol)
      if (typeg)
      {
        res2 <- tetlin(x,w)
      }
      else
      {
        if (optfct == "optim")
          res2 <- optim(res1$par,obj1, ...)
        else
        {
          res2 <- optimize(obj1,t0, ...)
          res2$par <- res2$minimum
          res2$value <- res2$objective
        }	
      }
      z = list(par=res2$par,objective=res2$value)	
    }
    if (type=="cue")
    {
      obj_cue <- function(thet)
      {
        gt <- g(thet,x)
        gbar <- as.vector(colMeans(gt))
        if (vcov == "iid")
          w2 <- iid(thet)
        if (vcov == "HAC")
          w2 <- HAC(g(thet,x), kernel=kernel, bw=bw,prewhite=prewhite,ar.method=ar.method,approx=approx,tol=tol)
        obj <- crossprod(gbar,solve(w2,gbar))
        return(obj)
      }	
      if (typeg)
      {
        if (is.null(t0))
          t0 <- tetlin(x,diag(rep(1,q)))$par
        if (optfct == "optim")
        {
          res2 <- optim(t0,obj_cue, ...)
        }	
        else
        {
          res2 <- optimize(obj_cue,t0, ...)
          res2$par <- res2$minimum
          res2$value <- res2$objective
        }
      }
      else
      {
        if (optfct == "optim")
          res2 <- optim(t0,obj_cue, ...)
        else
        {
          res2 <- optimize(obj_cue,t0, ...)
          res2$par <- res2$minimum
          res2$value <- res2$objective
        }	
      }
      z = list(par=res2$par,objective=res2$value)	
    }
    if (type=="iterative")
    {
      w=diag(rep(1,q))
      if (typeg)
        res <- tetlin(x,w)
      else
      {
        if (optfct == "optim")
          res <- optim(t0,obj1, ...)
        else
        {
          res <- optimize(obj1,t0, ...)
          res$par <- res$minimum
          res$value <- res$objective
        }	
      }
      ch <- 100000
      j <- 1
      while(ch>crit)
      {
        tet <- res$par
        if (vcov == "iid")
          w <- iid(tet)
        if (vcov == "HAC")
          w <- HAC(g(tet,x), kernel=kernel, bw=bw,prewhite=prewhite,ar.method=ar.method,approx=approx,tol=tol)
        if (typeg)
          res <- tetlin(x,w)
        else
        {	
          if (optfct == "optim")
            res <- optim(tet,obj1, ...)
          else
          {
            res <- optimize(obj1,t0, ...)
            res$par <- res$minimum
            res$value <- res$objective
          }	
        }
        ch <- crossprod(abs(tet-res$par)/tet,abs(tet-res$par)/tet)
        if (j>itermax)
        {
          cat("No convergence after ",itermax," iterations")
          ch <- crit
        }
        j <- j+1	
      }
      
      z = list(par=res$par,objective=res$value)	
    }
  }
  
  if (!is.function(gradv)) 
    G <- Gf(z$par)
  else
    if (typeg)
      G <- gradv(x)
  else	
    G <- gradv(z$par,x)
  
  if (vcov == "iid")
    v <- iid(z$par)/n
  else
    v <- HAC(g(z$par,x), kernel=kernel, bw=bw,prewhite=prewhite,ar.method=ar.method,approx=approx,tol=tol)/n
  
  if (wmatrix == "optimal")
  {
    z$vcov <- solve(crossprod(G,solve(v,G)))
  }
  else
  {
    GGG <- solve(crossprod(G),t(G))
    z$vcov <- GGG%*%v%*%t(GGG)
  }
  
  z$gt <- g(z$par,x)
  if (typeg==0)
    names(z$par) <- paste("Theta[",1:k,"]",sep="")
  if (typeg == 1)
  {
    namex <- colnames(dat$x[,(dat$ny+1):(dat$ny+dat$k)])
    nameh <- colnames(dat$x[,(dat$ny+dat$k+1):(dat$ny+dat$k+dat$nh)])
    if (dat$ny > 1)
    {
      namey <- colnames(dat$x[,1:dat$ny])
      names(z$par) <- paste(rep(namey,dat$k),"_",rep(namex,rep(dat$ny,dat$k)),sep="")
      colnames(z$gt) <- paste(rep(namey,dat$nh),"_",rep(nameh,rep(dat$ny,dat$nh)),sep="")
    }
    if (dat$ny == 1)
    {
      names(z$par) <- namex
      colnames(z$gt) <- nameh
    }
  }
  
  dimnames(z$vcov) <- list(names(z$par),names(z$par))
  z$df <- df
  z$k <- k
  z$n <- n
  z$met <- type
  z$kernel <- kernel
  class(z) <- "gmm"
  z
}


HAC <- function (x, weights = weightsAndrews2, bw = bwAndrews2, prewhite = FALSE, ar.method = "ols", kernel=c("Quadratic Spectral", "Truncated", "Bartlett", "Parzen", "Tukey-Hanning"), approx="AR(1)",tol = 1e-7) 
{
  n.orig <- n <- nrow(x)
  k <- ncol(x)
  kernel=match.arg(kernel)  
  if(prewhite > 0) 
  {
    var.fit <- ar(x, order.max = prewhite, demean = FALSE, aic = FALSE, method = ar.method)
    if(k > 1) D <- solve(diag(ncol(x)) - apply(var.fit$ar, 2:3, sum))
    else D <- as.matrix(1/(1 - sum(var.fit$ar)))
    x <- as.matrix(na.omit(var.fit$resid))
    n <- n - prewhite
  }
  weights <- weights(x, ar.method = ar.method,kernel=kernel,bw=bw, approx = approx, prewhite = 1, tol = tol)
  if (length(weights) > n) 
  {
    warning("more weights than observations, only first n used")
    weights <- weights[1:n]
  }
  utu <- 0.5 * crossprod(x) * weights[1]
  wsum <- n * weights[1]/2
  w2sum <- n * weights[1]^2/2
  if (length(weights) > 1) {
    for (ii in 2:length(weights)) {
      utu <- utu + weights[ii] * crossprod(x[1:(n - 
                                                  ii + 1), , drop = FALSE], x[ii:n, , drop = FALSE])
      wsum <- wsum + (n - ii + 1) * weights[ii]
      w2sum <- w2sum + (n - ii + 1) * weights[ii]^2
    }
  }
  utu <- utu + t(utu)
  
  if(prewhite > 0) {
    utu <- crossprod(t(D), utu) %*% t(D)
  }
  wsum <- 2 * wsum
  w2sum <- 2 * w2sum
  bc <- n^2/(n^2 - wsum)
  df <- n^2/w2sum
  rval <- utu/n.orig
  
  return(rval)
}

weightsAndrews2 <- function (x, bw = bwAndrews2, kernel = c("Quadratic Spectral", 
                                                            "Truncated", "Bartlett", "Parzen", "Tukey-Hanning"), approx = c("AR(1)", 
                                                                                                                            "ARMA(1,1)"), prewhite = 1, ar.method = "ols", tol = 1e-7, verbose = FALSE)
{
  kernel <- match.arg(kernel)
  approx=match.arg(approx)
  
  if (is.function(bw)) 
    bw <- bw(x, kernel = kernel, prewhite = prewhite, ar.method = ar.method, approx=approx)
  n <- NROW(x) 
  weights <- kweights(0:(n - 1)/bw, kernel = kernel)
  weights <- weights[1:max(which(abs(weights) > tol))]
  return(weights)
}


bwAndrews2 <- function (x, kernel = c("Quadratic Spectral", 
                                      "Truncated", "Bartlett", "Parzen", "Tukey-Hanning"), approx = c("AR(1)", 
                                                                                                      "ARMA(1,1)"), prewhite = 1, ar.method = "ols") 
{
  kernel <- match.arg(kernel)
  approx <- match.arg(approx)
  n <- nrow(x)
  k <- ncol(x)
  
  if (approx == "AR(1)") {
    fitAR1 <- function(x) {
      rval <- ar(x, order.max = 1, aic = FALSE, method = "ols")
      rval <- c(rval$ar, sqrt(rval$var.pred))
      names(rval) <- c("rho", "sigma")
      return(rval)
    }
    ar.coef <- apply(x, 2, fitAR1)
    denum <- sum((ar.coef["sigma", ]/(1 - ar.coef["rho", 
                                                  ]))^4)
    alpha2 <- sum(4 * ar.coef["rho", ]^2 * ar.coef["sigma", 
                                                   ]^4/(1 - ar.coef["rho", ])^8)/denum
    alpha1 <- sum(4 * ar.coef["rho", ]^2 * ar.coef["sigma", 
                                                   ]^4/((1 - ar.coef["rho", ])^6 * (1 + ar.coef["rho", 
                                                                                                ])^2))/denum
  }
  else {
    fitARMA11 <- function(x) {
      rval <- arima(x, order = c(1, 0, 1), include.mean = FALSE)
      rval <- c(rval$coef, sqrt(rval$sigma2))
      names(rval) <- c("rho", "psi", "sigma")
      return(rval)
    }
    arma.coef <- apply(x, 2, fitARMA11)
    denum <- sum(((1 + arma.coef["psi", ]) * arma.coef["sigma", 
                                                       ]/(1 - arma.coef["rho", ]))^4)
    alpha2 <- sum(4 * ((1 + arma.coef["rho", ] * 
                          arma.coef["psi", ]) * (arma.coef["rho", ] + arma.coef["psi", 
                                                                                ]))^2 * arma.coef["sigma", ]^4/(1 - arma.coef["rho", 
                                                                                                                              ])^8)/denum
    alpha1 <- sum(4 * ((1 + arma.coef["rho", ] * 
                          arma.coef["psi", ]) * (arma.coef["rho", ] + arma.coef["psi", 
                                                                                ]))^2 * arma.coef["sigma", ]^4/((1 - arma.coef["rho", 
                                                                                                                               ])^6 * (1 + arma.coef["rho", ])^2))/denum
  }
  rval <- switch(kernel, Truncated = {
    0.6611 * (n * alpha2)^(1/5)
  }, Bartlett = {
    1.1447 * (n * alpha1)^(1/3)
  }, Parzen = {
    2.6614 * (n * alpha2)^(1/5)
  }, "Tukey-Hanning" = {
    1.7462 * (n * alpha2)^(1/5)
  }, "Quadratic Spectral" = {
    1.3221 * (n * alpha2)^(1/5)
  })
  return(rval)
}

summary.gmm <- function(object, interval=FALSE, ...)
{
  z <- object
  se <- sqrt(diag(z$vcov))
  par <- z$par
  tval <- par/se
  j <- z$objective*z$n
  ans <- list(met=z$met,kernel=z$kernel,algo=z$algo)
  names(ans$met) <- "GMM method"
  names(ans$kernel) <- "kernel for cov matrix"
  
  ans$par <- round(cbind(par,se, tval, 2 * pnorm(abs(tval), lower.tail = FALSE)),5)
  
  dimnames(ans$par) <- list(names(z$par), 
                            c("Estimate", "Std. Error", "t value", "Pr(>|t|)"))
  
  ans$J_test <- noquote(paste("Test-J degrees of freedom is ",z$df,sep=""))
  ans$j <- noquote(cbind(j,ifelse(z$df>0,pchisq(j,z$df,lower.tail = FALSE),"*******")))
  dimnames(ans$j) <- list("Test E(g)=0:  ",c("J-test","Pz(>j)"))
  
  if (interval != FALSE)
  {
    zs <- qnorm((1-interval)/2,lower.tail=FALSE)
    ch <- zs*se
    ans$interval <- cbind(par-ch,par+ch)
    dimnames(ans$interval) <- list(names(par),c("Theta_lower","Theta_upper"))
  }
  class(ans) <- "summary.gmm"
  ans
}

lintest <- function(object,R,c)
{
  z <- object
  dl <- nrow(R)
  rest <- R%*%z$par - c
  if (class(z)=="gmm")
    vcov_par <- z$vcov
  else
    vcov_par <- z$vcov_par
  
  vcov <- R%*%vcov_par%*%t(R)
  h0 <- matrix(rep(NA,nrow(R)),ncol=1)	
  for (i in 1:nrow(R))
  {
    testnames <- names(z$par)[R[i,]!=0]
    rn <- R[i,][R[i,]!=0]
    if (rn[1] != 1)
      h0[i] <- paste(rn[1],"*",testnames[1],sep="")
    else
      h0[i] <- testnames[1]
    if (length(rn) > 1)
    {
      for (j in 2:length(rn))
      {
        if (rn[j] >= 0)
        {	
          if (rn[j] != 1)					
            h0[i] <- paste(h0[i]," + ",rn[j],"*",testnames[j],sep="")
          else
            h0[i] <- paste(h0[i]," + ",testnames[j],sep="")
        }
        else
        {	
          if (abs(rn[j]) != 1)					
            h0[i] <- paste(h0[i]," - ",abs(rn[j]),"*",testnames[j],sep="")					
          else
            h0[i] <- paste(h0[i]," - ",testnames[j],sep="")
        }
      }
    }
    h0[i] <- paste(h0[i]," = ",c[i],sep="")
  }
  rh <- solve(vcov,rest)		
  ans <- list(description <- "Wald test for H0: R(Theta)=c")
  ans$H0 <- noquote(h0)
  colnames(ans$H0) <- "Null Hypothesis"		
  wt <- crossprod(rest,rh)
  pv <- pchisq(wt,dl,lower.tail=FALSE)
  res <- cbind(wt,pv)
  dimnames(res) <- list("Wald test", c("Statistics","P-Value"))
  ans$result <- res
  ans
} 



rho <- function(x,lamb,derive=0,type=c("EL","ET","CUE"),drop=TRUE)
{
  
  type <- match.arg(type)
  lamb <- matrix(lamb,ncol=1)
  gml <- x%*%lamb
  ch <- 0
  if (derive==0)
  {
    if (type == "EL")
    {
      ch <- sum(gml>=1)
      if (drop)
      {				
        gml <- (gml<1)*gml
        rhomat <- log(1-gml) 
      }
      else
      {
        if (ch>0)
          rhomat <- NaN
        else
          rhomat <- log(1-gml) 
      }
    }
    if (type == "ET")
      rhomat <- -exp(gml)
    
    if (type == "CUE")
      rhomat <- -gml -0.5*gml^2
  }
  if (derive==1)
  {
    if (type == "EL")
      rhomat <- -1/(1-gml) 
    
    if (type == "ET")
      rhomat <- -exp(gml)
    
    if (type == "CUE")
      rhomat <- -1 -gml
  }
  if (derive==2)
  {
    if (type == "EL")
      rhomat <- -1/(1-gml)^2 
    
    if (type == "ET")
      rhomat <- -exp(gml)
    
    if (type == "CUE")
      rhomat <- -1
  }
  rhom <-list(ch = ch, rhomat=rhomat) 
  return(rhom)
}

get_lamb <- function(g,tet,x,type=c('EL','ET','CUE'),tol_lam=1e-12,maxiterlam=1000,tol_obj=1e-7)
{
  type <- match.arg(type)	
  gt <- g(tet,x)
  n <- nrow(gt)
  tol_cond=1e-12
  gb <- colMeans(gt)
  khat <- crossprod(gt)/n
  lamb0 <- -solve(khat,gb)
  conv_mes <- "Normal convergence" 
  
  singular <-0
  crit <-1e30
  crit0 <- crit
  dcrit <- 10
  dgblam <- -10
  gblam0 <- NULL
  
  j <- 1
  while ((crit > tol_lam*( 1+sqrt( crossprod(lamb0) ) ) ) & (j<=maxiterlam))
  { 
    rho2 <- as.numeric(rho(gt,lamb0,derive=2,type=type)$rhomat)
    rho1 <- as.numeric(rho(gt,lamb0,derive=1,type=type)$rhomat)
    gblam <- colMeans(rho1*gt)
    klam <- crossprod(rho2*gt,gt)/n
    chklam <- sum(abs(klam))
    if (!is.null(gblam0))
      dgblam <- crossprod(gblam)-crossprod(gblam0)
    
    if (is.na(chklam) | chklam == 0 | chklam == Inf |  dgblam>0 | dgblam == Inf | is.na(dgblam) | dcrit < 0)
    {
      lamb1 <- rep(sqrt(1/n),length(lamb0))
      crit <- 0
      singular=2
      conv_mes <- "The algorithm produced singular system,  NaN or Inf" 
    }
    else
    {
      if (rcond(klam)>tol_cond)
      {
        lamb1 <- lamb0-solve(klam,gblam)
        crit <- sqrt(crossprod(lamb0-lamb1))
        lamb0 <- lamb1
      }
      else
      {
        lamb1 <- rep(sqrt(1/n),length(lamb0))
        crit <- 0
        singular=2
        conv_mes <- "The algorithm produced singular system" 
      }
    }
    gblam0 <- gblam
    j <- j+1
    dcrit<- crit0-crit
    crit0 <- crit
  }
  z <- list("lambda"=lamb1,singular=singular,conv_mes=conv_mes)
  if (j>maxiterlam | max(abs(gblam))>tol_obj)
  {
    singular <- 1
    conv_mes <- "No convergence after 'maxiterlam' iterations"
    z$singular <- singular		
  }
  z$obj <- crossprod(gblam)
  return(z)
}

gel <- function(g,x,tet0,gradv=NULL,smooth=FALSE,type=c("EL","ET","CUE","ETEL"), vcov=c("HAC","iid"), kernel = c("Bartlett", "Parzen", 
                                                                                                                 "Truncated", "Tukey-Hanning"), bw=bwAndrews2, approx = c("AR(1)", 
                                                                                                                                                                          "ARMA(1,1)"), prewhite = 1, ar.method = "ols", tol_weights = 1e-7, tol_lam=1e-9, tol_obj = 1e-9, 
                tol_mom = 1e-9,maxiterlam=1000, constraint=FALSE,intercept=TRUE,optfct=c("optim","optimize"),optlam=c("iter","numeric"),...)
{
  vcov=match.arg(vcov)
  type <- match.arg(type)
  optfct <- match.arg(optfct)
  optlam <- match.arg(optlam)
  weights=weightsAndrews2
  if (type == "ETEL")
  {
    typel <- "ET"
    typet <- "EL"	
  }
  else
  {
    typel <- type
    typet <- type
  }
  approx <- match.arg(approx)
  kernel <- match.arg(kernel)
  if(optfct=="optim")
    k <- length(tet0)
  else
    k <- 1
  
  typeg=0
  if (is(g,"formula"))
  {
    typeg=1
    dat <- get_dat(g,x,intercept=intercept)
    x <- dat$x
    
    g <- function(tet,x,ny=dat$ny,nh=dat$nh,k=dat$k)
    {
      tet <- matrix(tet,ncol=k)
      if (intercept)
      {
        e <- x[,1:ny] -  x[,(ny+1):(ny+k)]%*%t(tet)
        gt <- e
        for (i in 2:nh)
        {
          gt <- cbind(gt,e*x[,(ny+k+i)])
        }
      }
      if (!intercept)
        e <- x[,1:ny] -  x[,(ny+1):(ny+k)]%*%t(tet)
      gt <- e*x[,ny+k+1]
      if (nh > 1)
      {	
        for (i in 2:nh)
        {
          gt <- cbind(gt,e*x[,(ny+k+i)])
        }
      }
      return(gt)
    }
    gradv <- function(tet,x,ny=dat$ny,nh=dat$nh,k=dat$k)
    {
      tet <- matrix(tet,ncol=k)
      dgb <- -(t(x[,(ny+k+1):(ny+k+nh)])%*%x[,(ny+1):(ny+k)])%x%diag(rep(1,ny))/nrow(x)
      return(dgb)
    }
  }	
  if (typeg)
    n <- nrow(x)
  else
    n = nrow(g(tet0,x))
  
  if (smooth)
  {
    g1 <- g
    rgmm <- gmm(g,x,tet0,wmatrix="ident")
    
    if (is.function(weights))
      w <- weights(g(rgmm$par,x),kernel=kernel,bw=bw,prewhite = prewhite,ar.method=ar.method,approx=approx,tol=tol_weights)
    else
      w <- weights
    sg <- function(thet,x)
    {
      gf <- g1(thet,x)
      gt <- smooth_g(gf, weights=w)$smoothx 
      return(gt)
    }
    g <- sg
  }	
  lll <- 1
  thetf <- function(tet)
  {
    if (optlam=="iter")
    {
      lamblist <- get_lamb(g,tet,x,type=typel,tol_lam=tol_lam,maxiterlam=maxiterlam,tol_obj=tol_obj)
      lamb <- lamblist$lambda
      gt <- g(tet,x)
      pt <- -rho(gt,lamb,type=typet,derive=1)$rhomat/nrow(gt)
      checkmom <- sum(as.numeric(pt)*gt)
      if (lamblist$singular==0)		
        p <- sum(rho(gt,lamb,type=typet)$rhomat) + abs(checkmom)/tol_mom
      if (lamblist$singular==1)		
        p <- sum(rho(gt,lamb,type=typet)$rhomat) + abs(checkmom)/tol_mom + lamblist$obj/tol_mom
      if (lamblist$singular==2)		
        p <- 1e50*lll
      lll <- lll+1
    }
    else
    {
      gt <- g(tet,x)
      rhofct <- function(lamb)
      {
        rhof <- -sum(rho(gt,lamb,type=typet)$rhomat)
        return(rhof)
      }
      if (ncol(gt)>1)
        rlamb <- optim(rep(0,ncol(gt)),rhofct,...)
      else
      {
        rlamb <- optimize(rhofct,c(-1,1))
        rlamb$par <- rlamb$minimum
        rlamb$value <- rlamb$objective
      }
      lamb <- rlamb$par
      pt <- -rho(gt,lamb,type=typet,derive=1)$rhomat/nrow(gt)
      checkmom <- sum(as.numeric(pt)*gt)
      p <- -rlamb$value + (checkmom)^2/tol_mom + (sum(as.numeric(pt))-1)^2/tol_mom
    }
    return(p)
  }
  
  if (!constraint)
    if (optfct == "optim")
      res <- optim(tet0,thetf,...)
  else
  {
    res <- optimize(thetf,tet0,...)
    res$par <- res$minimum
    res$convergence <- "Pas applicable"
  }
  else
    res <- constrOptim(tet0,thetf,...)
  
  
  rlamb <- get_lamb(g,res$par,x,type=typel,tol_lam=tol_lam,maxiterlam=maxiterlam,tol_obj=tol_obj)
  z <- list(par=res$par,lambda=rlamb$lam,conv_lambda=rlamb$conv_mes,conv_par=res$convergence)
  z$foc_lambda <- rlamb$obj
  z$type <- type
  z$gt <- g(z$par,x)
  rhom <- rho(z$gt,z$lambda,type=typet)
  z$pt <- -rho(z$gt,z$lambda,type=typet,derive=1)$rhomat/n
  z$conv_moment <- colSums(as.numeric(z$pt)*z$gt)
  z$conv_pt <- sum(as.numeric(z$pt))
  
  z$objective <- sum(as.numeric(rhom$rhomat)-rho(1,0,type=typet)$rhomat)/n
  
  if (type == "EL")	
  {
    z$badrho <- rhom$ch
    names(z$badrho) <- "Number_of_bad_rho"
  }
  
  Gf <- function(thet)
  {
    myenv <- new.env()
    assign('x',x,envir=myenv)
    assign('thet',thet,envir=myenv)
    barg <- function(x,thet)
    {
      gt <- g(thet,x)
      gbar <- as.vector(colMeans(gt))
      return(gbar)
    }
    G <- attr(numericDeriv(quote(barg(x,thet)),"thet",myenv),"gradient")
    return(G)
  }
  if (!is.function(gradv)) 
    G <- Gf(z$par)
  else
    G <- gradv(z$par,x)
  if (vcov == "iid")
    khat <- crossprod(z$gt)
  else
    khat <- HAC(g(z$par,x), kernel=kernel, bw=bw,prewhite=prewhite,ar.method=ar.method,approx=approx,tol=tol_weights)
  
  kg <- solve(khat,G)
  z$vcov_par <- solve(crossprod(G,kg))/n
  z$vcov_lambda <- ((solve(khat)-kg%*%z$vcov_par%*%t(kg)))/n
  
  if (smooth) z$weights<-w
  
  if (typeg ==0)
  {
    names(z$par) <- paste("Theta[",1:k,"]",sep="")
    colnames(z$gt) <- paste("gt[",1:ncol(z$gt),"]",sep="")
    names(z$lambda) <- paste("Lambda[",1:ncol(z$gt),"]",sep="")
  }
  if (typeg == 1)
  {
    namex <- colnames(dat$x[,(dat$ny+1):(dat$ny+dat$k)])
    nameh <- colnames(dat$x[,(dat$ny+dat$k+1):(dat$ny+dat$k+dat$nh)])
    if (dat$ny > 1)
    {
      namey <- colnames(dat$x[,1:dat$ny])
      names(z$par) <- paste(rep(namey,dat$k),"_",rep(namex,rep(dat$ny,dat$k)),sep="")
      colnames(z$gt) <- paste(rep(namey,dat$nh),"_",rep(nameh,rep(dat$ny,dat$nh)),sep="")
      names(z$lambda) <- paste("Lam(",rep(namey,dat$nh),"_",rep(nameh,rep(dat$ny,dat$nh)),")",sep="")
    }
    if (dat$ny == 1)
    {
      names(z$par) <- namex
      colnames(z$gt) <- nameh
      names(z$lambda) <- nameh
    }
  }
  dimnames(z$vcov_par) <- list(names(z$par),names(z$par))
  dimnames(z$vcov_lambda) <- list(names(z$lambda),names(z$lambda))
  
  class(z) <- "gel"
  return(z)
}


smooth_g <- function (x, bw = bwAndrews2, prewhite = 1, ar.method = "ols",weights=weightsAndrews2,
                      kernel=c("Bartlett","Parzen","Truncated","Tukey-Hanning"), approx = c("AR(1)","ARMA(1,1)"),
                      tol = 1e-7) 
{
  kernel <- match.arg(kernel)
  approx <- match.arg(approx)
  
  n <- nrow(x)
  if (is.function(weights))
  {
    w <- weights(x, bw = bw, kernel = kernel,  
                 prewhite = prewhite, ar.method = ar.method, tol = tol, 
                 verbose = FALSE, approx = approx)
  }
  else
    w <- weights
  
  
  rt <- length(w)
  if (rt >= 2)
  {
    w <- c(w[rt:2],w)
    w <- w / sum(w)
    rt <- rt-1
    sgt <- function(t) crossprod(x[(t-rt):(t+rt),],w)
    x[(rt+1):(n-rt),] <- t(sapply((rt+1):(n-rt),sgt))
    sx <- list("smoothx"=x,"kern_weights"=w)
    return(sx)		
  }
  else
    sx <- list("smoothx"=x,"kern_weights"=1)
  return(sx)		
}

bwNeweyWest2 <- function (x, kernel = c("Bartlett", "Parzen", 
                                        "Quadratic Spectral", "Truncated", "Tukey-Hanning"), 
                          prewhite = 1, ar.method = "ols",...) 
{
  kernel <- match.arg(kernel)
  if (kernel %in% c("Truncated", "Tukey-Hanning")) 
    stop(paste("Automatic bandwidth selection only available for ", 
               dQuote("Bartlett"), ", ", dQuote("Parzen"), " and ", 
               dQuote("Quadratic Spectral"), " kernel. Use ", sQuote("bwAndrews2"), 
               " instead.", sep = ""))
  prewhite <- as.integer(prewhite)
  n <- nrow(x)
  k <- ncol(x)
  weights <- rep(1, k)
  if (length(weights) < 2) 
    weights <- 1
  mrate <- switch(kernel, Bartlett = 2/9, Parzen = 4/25, "Quadratic Spectral" = 2/25)
  m <- floor(ifelse(prewhite > 0, 3, 4) * (n/100)^mrate)
  if (prewhite > 0) {
    x <- as.matrix(na.omit(ar(x, order.max = prewhite, 
                              demean = FALSE, aic = FALSE, method = ar.method)$resid))
    n <- n - prewhite
  }
  hw <- x %*% weights
  sigmaj <- function(j) sum(hw[1:(n - j)] * hw[(j + 1):n])/n
  sigma <- sapply(0:m, sigmaj)
  s0 <- sigma[1] + 2 * sum(sigma[-1])
  s1 <- 2 * sum(1:m * sigma[-1])
  s2 <- 2 * sum((1:m)^2 * sigma[-1])
  qrate <- 1/(2 * ifelse(kernel == "Bartlett", 1, 2) + 1)
  rval <- switch(kernel, Bartlett = {
    1.1447 * ((s1/s0)^2)^qrate
  }, Parzen = {
    2.6614 * ((s2/s0)^2)^qrate
  }, "Quadratic Spectral" = {
    1.3221 * ((s2/s0)^2)^qrate
  })
  rval <- rval * (n + prewhite)^qrate
  return(rval)
}

summary.gel <- function(object,interval=FALSE, ...)
{
  z <- object
  n <- nrow(z$gt)
  khat <- crossprod(z$gt)/n
  gbar <- colMeans(z$gt)
  
  se_par <- sqrt(diag(z$vcov_par))
  par <- z$par
  tval <- par/se_par
  
  se_parl <- sqrt(diag(z$vcov_lambda))
  lamb <- z$lambda
  tvall <- lamb/se_parl
  
  LR_test <- 2*z$objective*n
  LM_test <- n*crossprod(z$lambda,crossprod(khat,z$lambda))
  J_test <- n*crossprod(gbar,solve(khat,gbar))
  test <- c(LR_test,LM_test,J_test)
  vptest <- pchisq(test,(ncol(z$gt)-length(z$par)),lower.tail=FALSE)
  ans <- list(type=z$type)
  names(ans$type) <-"Type of GEL"
  
  ans$par <- round(cbind(par,se_par, tval, 2 * pnorm(abs(tval), lower.tail = FALSE)),5)
  ans$lambda <- round(cbind(lamb,se_parl, tvall, 2 * pnorm(abs(tvall), lower.tail = FALSE)),5)
  
  dimnames(ans$par) <- list(names(z$par), 
                            c("Estimate", "Std. Error", "t value", "Pr(>|t|)"))
  dimnames(ans$lambda) <- list(names(z$lambda), 
                               c("Estimate", "Std. Error", "t value", "Pr(>|t|)"))
  
  ans$test <- cbind(test,vptest)
  dimnames(ans$test) <- list(c("LR test","LM test","J test"),c("statistics","p-value"))	
  
  if (interval != FALSE)
  {
    zs <- qnorm((1-interval)/2,lower.tail=FALSE)
    ch <- zs*se_par
    ans$interval_par <- cbind(par-ch,par+ch)
    dimnames(ans$interval_par) <- list(names(par),c("Theta_lower","Theta_upper"))
    chl <- zs*se_parl
    ans$interval_lam <- cbind(lamb-chl,lamb+chl)
    dimnames(ans$interval_lam) <- list(names(lamb),c("Lambda_lower","Lambda_upper"))
  }
  
  
  if (z$type == "EL")
    ans$badrho <- z$badrho
  if (!is.null(z$weights))
  {
    ans$weights <- z$weights
  }
  ans$conv_par <- z$conv_par
  ans$conv_pt <- z$conv_pt
  ans$conv_moment <- cbind(z$conv_moment)
  ans$conv_lambda <- z$conv_lambda
  names(ans$conv_par) <- "Convergence_code_theta"
  names(ans$conv_pt) <- "Sum_of_pt"
  names(ans$conv_lambda) <- "Convergence_code_for_lambda"
  dimnames(ans$conv_moment) <- list(names(z$gt),"Sample_moment_with_pt")
  class(ans) <- "summary.gel"
  ans	
}

get_dat <- function (formula,h,intercept=TRUE) 
{
  cl <- match.call()
  mf <- match.call(expand.dots = FALSE)
  m <- match(c("formula", "data"), names(mf), 0L)
  mf <- mf[c(1L, m)]
  mf$drop.unused.levels <- TRUE
  mf[[1L]] <- as.name("model.frame")
  mf <- eval(mf, parent.frame())
  mt <- attr(mf, "terms")
  
  h <- cbind(rep(1,nrow(h)),h)
  colnames(h) <- c("Intercept",paste("h",1:(ncol(h)-1),sep=""))
  y <- as.matrix(model.response(mf, "numeric"))
  x <- as.matrix(model.matrix(mt, mf, NULL))
  if (!intercept)
  {
    x <- as.matrix(x[,2:ncol(x)])
    h <- as.matrix(h[,2:ncol(h)])
  }
  ny <- ncol(y)
  k <- ncol(x)
  nh <- ncol(h)
  if (nrow(y) != nrow(x) | nrow(x) != nrow(h) | nrow(y)!=nrow(h))
    stop("The number of observations of X, Y and H must be the same")
  if (nh<k)
    stop("The number of moment conditions must be at least equal to the number of coefficients to estimate")
  if (is.null(colnames(y)))
  {
    if (ny>1) 
      colnames(y) <- paste("y",1:ncol(y),sep="")
    if (ny == 1) 
      colnames(y) <- "y"
  }
  x <- cbind(y,x,h)
  return(list(x=x,nh=nh,ny=ny,k=k))
}




################################################################################################;
#				1 - ESTIMATES;
################################################################################################;


#############################;
# WEEKS WORKED;
#############################;

# MODELS WITHOUT COVARIATES;

form1	<- y1 ~ x;


iv1	<- tsls(form1, ~ z1, data = data);
iv2	<- tsls(form1, ~ z2, data = data);
iv12	<- tsls(form1, ~ z1 + z2, data = data);
gmm12	<- gmm(form1, x = cbind(z1,z2), vcov = "iid", type = "twoStep");


# MODELS WITH COVARIATES;

iv1g11	<- tsls(y1[g==11]~x[g==11], ~z1[g==11], data = data);
iv1g12	<- tsls(y1[g==12]~x[g==12], ~z1[g==12], data = data);
iv1g13	<- tsls(y1[g==13]~x[g==13], ~z1[g==13], data = data);
iv1g14	<- tsls(y1[g==14]~x[g==14], ~z1[g==14], data = data);
iv1g21	<- tsls(y1[g==21]~x[g==21], ~z1[g==21], data = data);
iv1g22	<- tsls(y1[g==22]~x[g==22], ~z1[g==22], data = data);
iv1g23	<- tsls(y1[g==23]~x[g==23], ~z1[g==23], data = data);
iv1g24	<- tsls(y1[g==24]~x[g==24], ~z1[g==24], data = data);
iv1g31	<- tsls(y1[g==31]~x[g==31], ~z1[g==31], data = data);
iv1g32	<- tsls(y1[g==32]~x[g==32], ~z1[g==32], data = data);
iv1g33	<- tsls(y1[g==33]~x[g==33], ~z1[g==33], data = data);
iv1g34	<- tsls(y1[g==34]~x[g==34], ~z1[g==34], data = data);


iv2g11	<- tsls(y1[g==11]~x[g==11], ~z2[g==11], data = data);
iv2g12	<- tsls(y1[g==12]~x[g==12], ~z2[g==12], data = data);
iv2g13	<- tsls(y1[g==13]~x[g==13], ~z2[g==13], data = data);
iv2g14	<- tsls(y1[g==14]~x[g==14], ~z2[g==14], data = data);
iv2g21	<- tsls(y1[g==21]~x[g==21], ~z2[g==21], data = data);
iv2g22	<- tsls(y1[g==22]~x[g==22], ~z2[g==22], data = data);
iv2g23	<- tsls(y1[g==23]~x[g==23], ~z2[g==23], data = data);
iv2g24	<- tsls(y1[g==24]~x[g==24], ~z2[g==24], data = data);
iv2g31	<- tsls(y1[g==31]~x[g==31], ~z2[g==31], data = data);
iv2g32	<- tsls(y1[g==32]~x[g==32], ~z2[g==32], data = data);
iv2g33	<- tsls(y1[g==33]~x[g==33], ~z2[g==33], data = data);
iv2g34	<- tsls(y1[g==34]~x[g==34], ~z2[g==34], data = data);

iv12g11	<- tsls(y1[g==11]~x[g==11], ~z1[g==11] + z2[g==11], data = data);
iv12g12	<- tsls(y1[g==12]~x[g==12], ~z1[g==12] + z2[g==12], data = data);
iv12g13	<- tsls(y1[g==13]~x[g==13], ~z1[g==13] + z2[g==13], data = data);
iv12g14	<- tsls(y1[g==14]~x[g==14], ~z1[g==14] + z2[g==14], data = data);
iv12g21	<- tsls(y1[g==21]~x[g==21], ~z1[g==21] + z2[g==21], data = data);
iv12g22	<- tsls(y1[g==22]~x[g==22], ~z1[g==22] + z2[g==22], data = data);
iv12g23	<- tsls(y1[g==23]~x[g==23], ~z1[g==23] + z2[g==23], data = data);
iv12g24	<- tsls(y1[g==24]~x[g==24], ~z1[g==24] + z2[g==24], data = data);
iv12g31	<- tsls(y1[g==31]~x[g==31], ~z1[g==31] + z2[g==31], data = data);
iv12g32	<- tsls(y1[g==32]~x[g==32], ~z1[g==32] + z2[g==32], data = data);
iv12g33	<- tsls(y1[g==33]~x[g==33], ~z1[g==33] + z2[g==33], data = data);
iv12g34	<- tsls(y1[g==34]~x[g==34], ~z1[g==34] + z2[g==34], data = data);

gmm12g11<- gmm(y1[g==11]~x[g==11], x = cbind(z1[g==11],z2[g==11]), vcov = "iid", type = "twoStep");
gmm12g12<- gmm(y1[g==12]~x[g==12], x = cbind(z1[g==12],z2[g==12]), vcov = "iid", type = "twoStep");
gmm12g13<- gmm(y1[g==13]~x[g==13], x = cbind(z1[g==13],z2[g==13]), vcov = "iid", type = "twoStep");
gmm12g14<- gmm(y1[g==14]~x[g==14], x = cbind(z1[g==14],z2[g==14]), vcov = "iid", type = "twoStep");
gmm12g21<- gmm(y1[g==21]~x[g==21], x = cbind(z1[g==21],z2[g==21]), vcov = "iid", type = "twoStep");
gmm12g22<- gmm(y1[g==22]~x[g==22], x = cbind(z1[g==22],z2[g==22]), vcov = "iid", type = "twoStep");
gmm12g23<- gmm(y1[g==23]~x[g==23], x = cbind(z1[g==23],z2[g==23]), vcov = "iid", type = "twoStep");
gmm12g24<- gmm(y1[g==24]~x[g==24], x = cbind(z1[g==24],z2[g==24]), vcov = "iid", type = "twoStep");
gmm12g31<- gmm(y1[g==31]~x[g==31], x = cbind(z1[g==31],z2[g==31]), vcov = "iid", type = "twoStep");
gmm12g32<- gmm(y1[g==32]~x[g==32], x = cbind(z1[g==32],z2[g==32]), vcov = "iid", type = "twoStep");
gmm12g33<- gmm(y1[g==33]~x[g==33], x = cbind(z1[g==33],z2[g==33]), vcov = "iid", type = "twoStep");
gmm12g34<- gmm(y1[g==34]~x[g==34], x = cbind(z1[g==34],z2[g==34]), vcov = "iid", type = "twoStep");


p11	<- mean(g==11);
p12	<- mean(g==12);
p13	<- mean(g==13);
p14	<- mean(g==14);
p21	<- mean(g==21);
p22	<- mean(g==22);
p23	<- mean(g==23);
p24	<- mean(g==24);
p31	<- mean(g==31);
p32	<- mean(g==32);
p33	<- mean(g==33);
p34	<- mean(g==34);

p11.x1	<- mean(g==11 & x==1) / mean(x==1);
p12.x1	<- mean(g==12 & x==1) / mean(x==1);
p13.x1	<- mean(g==13 & x==1) / mean(x==1);
p14.x1	<- mean(g==14 & x==1) / mean(x==1);
p21.x1	<- mean(g==21 & x==1) / mean(x==1);
p22.x1	<- mean(g==22 & x==1) / mean(x==1);
p23.x1	<- mean(g==23 & x==1) / mean(x==1);
p24.x1	<- mean(g==24 & x==1) / mean(x==1);
p31.x1	<- mean(g==31 & x==1) / mean(x==1);
p32.x1	<- mean(g==32 & x==1) / mean(x==1);
p33.x1	<- mean(g==33 & x==1) / mean(x==1);
p34.x1	<- mean(g==34 & x==1) / mean(x==1);

p11.x0	<- mean(g==11 & x==0) / mean(x==0);
p12.x0	<- mean(g==12 & x==0) / mean(x==0);
p13.x0	<- mean(g==13 & x==0) / mean(x==0);
p14.x0	<- mean(g==14 & x==0) / mean(x==0);
p21.x0	<- mean(g==21 & x==0) / mean(x==0);
p22.x0	<- mean(g==22 & x==0) / mean(x==0);
p23.x0	<- mean(g==23 & x==0) / mean(x==0);
p24.x0	<- mean(g==24 & x==0) / mean(x==0);
p31.x0	<- mean(g==31 & x==0) / mean(x==0);
p32.x0	<- mean(g==32 & x==0) / mean(x==0);
p33.x0	<- mean(g==33 & x==0) / mean(x==0);
p34.x0	<- mean(g==34 & x==0) / mean(x==0);



w1g11	<- (sum(x[z1==1 & g==11])/sum(z1==1 & g==11) - sum(x[z1==0 & g==11])/sum(z1==0 & g==11)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g12	<- (sum(x[z1==1 & g==12])/sum(z1==1 & g==12) - sum(x[z1==0 & g==12])/sum(z1==0 & g==12)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g13	<- (sum(x[z1==1 & g==13])/sum(z1==1 & g==13) - sum(x[z1==0 & g==13])/sum(z1==0 & g==13)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g14	<- (sum(x[z1==1 & g==14])/sum(z1==1 & g==14) - sum(x[z1==0 & g==14])/sum(z1==0 & g==14)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g21	<- (sum(x[z1==1 & g==21])/sum(z1==1 & g==21) - sum(x[z1==0 & g==21])/sum(z1==0 & g==21)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g22	<- (sum(x[z1==1 & g==22])/sum(z1==1 & g==22) - sum(x[z1==0 & g==22])/sum(z1==0 & g==22)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g23	<- (sum(x[z1==1 & g==23])/sum(z1==1 & g==23) - sum(x[z1==0 & g==23])/sum(z1==0 & g==23)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g24	<- (sum(x[z1==1 & g==24])/sum(z1==1 & g==24) - sum(x[z1==0 & g==24])/sum(z1==0 & g==24)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g31	<- (sum(x[z1==1 & g==31])/sum(z1==1 & g==31) - sum(x[z1==0 & g==31])/sum(z1==0 & g==31)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g32	<- (sum(x[z1==1 & g==32])/sum(z1==1 & g==32) - sum(x[z1==0 & g==32])/sum(z1==0 & g==32)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g33	<- (sum(x[z1==1 & g==33])/sum(z1==1 & g==33) - sum(x[z1==0 & g==33])/sum(z1==0 & g==33)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
w1g34	<- (sum(x[z1==1 & g==34])/sum(z1==1 & g==34) - sum(x[z1==0 & g==34])/sum(z1==0 & g==34)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));


w2g11	<- (sum(x[z2==1 & g==11])/sum(z2==1 & g==11) - sum(x[z2==0 & g==11])/sum(z2==0 & g==11)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g12	<- (sum(x[z2==1 & g==12])/sum(z2==1 & g==12) - sum(x[z2==0 & g==12])/sum(z2==0 & g==12)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g13	<- (sum(x[z2==1 & g==13])/sum(z2==1 & g==13) - sum(x[z2==0 & g==13])/sum(z2==0 & g==13)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g14	<- (sum(x[z2==1 & g==14])/sum(z2==1 & g==14) - sum(x[z2==0 & g==14])/sum(z2==0 & g==14)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g21	<- (sum(x[z2==1 & g==21])/sum(z2==1 & g==21) - sum(x[z2==0 & g==21])/sum(z2==0 & g==21)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g22	<- (sum(x[z2==1 & g==22])/sum(z2==1 & g==22) - sum(x[z2==0 & g==22])/sum(z2==0 & g==22)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g23	<- (sum(x[z2==1 & g==23])/sum(z2==1 & g==23) - sum(x[z2==0 & g==23])/sum(z2==0 & g==23)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g24	<- (sum(x[z2==1 & g==24])/sum(z2==1 & g==24) - sum(x[z2==0 & g==24])/sum(z2==0 & g==24)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g31	<- (sum(x[z2==1 & g==31])/sum(z2==1 & g==31) - sum(x[z2==0 & g==31])/sum(z2==0 & g==31)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g32	<- (sum(x[z2==1 & g==32])/sum(z2==1 & g==32) - sum(x[z2==0 & g==32])/sum(z2==0 & g==32)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g33	<- (sum(x[z2==1 & g==33])/sum(z2==1 & g==33) - sum(x[z2==0 & g==33])/sum(z2==0 & g==33)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
w2g34	<- (sum(x[z2==1 & g==34])/sum(z2==1 & g==34) - sum(x[z2==0 & g==34])/sum(z2==0 & g==34)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));

ov	<- p11*exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) + p12*exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) + p13*exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) + p14*exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) + p21*exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) + p22*exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) + p23*exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) + p24*exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) + p31*exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) + p32*exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) + p33*exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) + p34*exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n));
ovg11	<- exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) / ov ;
ovg12	<- exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) / ov ;
ovg13	<- exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) / ov ;
ovg14	<- exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) / ov ;
ovg21	<- exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) / ov ;
ovg22	<- exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) / ov ;
ovg23	<- exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) / ov ;
ovg24	<- exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) / ov ;
ovg31	<- exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) / ov ;
ovg32	<- exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) / ov ;
ovg33	<- exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) / ov ;
ovg34	<- exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n)) / ov ;


l1g11	<- iv1g11$coeff[2];
l1g12	<- iv1g12$coeff[2];
l1g13	<- iv1g13$coeff[2];
l1g14	<- iv1g14$coeff[2];
l1g21	<- iv1g21$coeff[2];
l1g22	<- iv1g22$coeff[2];
l1g23	<- iv1g23$coeff[2];
l1g24	<- iv1g24$coeff[2];
l1g31	<- iv1g31$coeff[2];
l1g32	<- iv1g32$coeff[2];
l1g33	<- iv1g33$coeff[2];
l1g34	<- iv1g34$coeff[2];

l2g11	<- iv2g11$coeff[2];
l2g12	<- iv2g12$coeff[2];
l2g13	<- iv2g13$coeff[2];
l2g14	<- iv2g14$coeff[2];
l2g21	<- iv2g21$coeff[2];
l2g22	<- iv2g22$coeff[2];
l2g23	<- iv2g23$coeff[2];
l2g24	<- iv2g24$coeff[2];
l2g31	<- iv2g31$coeff[2];
l2g32	<- iv2g32$coeff[2];
l2g33	<- iv2g33$coeff[2];
l2g34	<- iv2g34$coeff[2];

l12g11	<- iv12g11$coeff[2];
l12g12	<- iv12g12$coeff[2];
l12g13	<- iv12g13$coeff[2];
l12g14	<- iv12g14$coeff[2];
l12g21	<- iv12g21$coeff[2];
l12g22	<- iv12g22$coeff[2];
l12g23	<- iv12g23$coeff[2];
l12g24	<- iv12g24$coeff[2];
l12g31	<- iv12g31$coeff[2];
l12g32	<- iv12g32$coeff[2];
l12g33	<- iv12g33$coeff[2];
l12g34	<- iv12g34$coeff[2];

l13g11	<- gmm12g11$par[2];
l13g12	<- gmm12g12$par[2];
l13g13	<- gmm12g13$par[2];
l13g14	<- gmm12g14$par[2];
l13g21	<- gmm12g21$par[2];
l13g22	<- gmm12g22$par[2];
l13g23	<- gmm12g23$par[2];
l13g24	<- gmm12g24$par[2];
l13g31	<- gmm12g31$par[2];
l13g32	<- gmm12g32$par[2];
l13g33	<- gmm12g33$par[2];
l13g34	<- gmm12g34$par[2];

late11.y1	<- (p11*w1g11*l1g11 + p12*w1g12*l1g12 + p13*w1g13*l1g13 +p14*w1g14*l1g14 +p21*w1g21*l1g21 +p22*w1g22*l1g22 +p23*w1g23*l1g23 +p24*w1g24*l1g24 +p31*w1g31*l1g31 +p32*w1g32*l1g32 +p33*w1g33*l1g33 +p34*w1g34*l1g34) /
			(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34);
late12.y1	<- (p11*w2g11*l1g11 + p12*w2g12*l1g12 + p13*w2g13*l1g13 +p14*w2g14*l1g14 +p21*w2g21*l1g21 +p22*w2g22*l1g22 +p23*w2g23*l1g23 +p24*w2g24*l1g24 +p31*w2g31*l1g31 +p32*w2g32*l1g32 +p33*w2g33*l1g33 +p34*w2g34*l1g34) /
			(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34);			
late13.y1	<- (p11*w1g11*l13g11 + p12*w1g12*l13g12 + p13*w1g13*l13g13 +p14*w1g14*l13g14 +p21*w1g21*l13g21 +p22*w1g22*l13g22 +p23*w1g23*l13g23 +p24*w1g24*l13g24 +p31*w1g31*l13g31 +p32*w1g32*l13g32 +p33*w1g33*l13g33 +p34*w1g34*l13g34) /
			(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34);
late21.y1	<- (p11*w1g11*l2g11 + p12*w1g12*l2g12 + p13*w1g13*l2g13 +p14*w1g14*l2g14 +p21*w1g21*l2g21 +p22*w1g22*l2g22 +p23*w1g23*l2g23 +p24*w1g24*l2g24 +p31*w1g31*l2g31 +p32*w1g32*l2g32 +p33*w1g33*l2g33 +p34*w1g34*l2g34) /
			(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34);
late22.y1	<- (p11*w2g11*l2g11 + p12*w2g12*l2g12 + p13*w2g13*l2g13 +p14*w2g14*l2g14 +p21*w2g21*l2g21 +p22*w2g22*l2g22 +p23*w2g23*l2g23 +p24*w2g24*l2g24 +p31*w2g31*l2g31 +p32*w2g32*l2g32 +p33*w2g33*l2g33 +p34*w2g34*l2g34) /
			(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34);			
late23.y1	<- (p11*w2g11*l13g11 + p12*w2g12*l13g12 + p13*w2g13*l13g13 +p14*w2g14*l13g14 +p21*w2g21*l13g21 +p22*w2g22*l13g22 +p23*w2g23*l13g23 +p24*w2g24*l13g24 +p31*w2g31*l13g31 +p32*w2g32*l13g32 +p33*w2g33*l13g33 +p34*w2g34*l13g34) /
			(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34);			


ate1.y1		<- p11*l1g11  + p12*l1g12  + p13*l1g13  + p14*l1g14  + p21*l1g21  + p22*l1g22  + p23*l1g23  + p24*l1g24  + p31*l1g31  + p32*l1g32  + p33*l1g33  + p34*l1g34;
ate2.y1		<- p11*l2g11  + p12*l2g12  + p13*l2g13  + p14*l2g14  + p21*l2g21  + p22*l2g22  + p23*l2g23  + p24*l2g24  + p31*l2g31  + p32*l2g32  + p33*l2g33  + p34*l2g34;
ate12.y1	<- p11*l12g11 + p12*l12g12 + p13*l12g13 + p14*l12g14 + p21*l12g21 + p22*l12g22 + p23*l12g23 + p24*l12g24 + p31*l12g31 + p32*l12g32 + p33*l12g33 + p34*l12g34;
ate13.y1	<- p11*l13g11 + p12*l13g12 + p13*l13g13 + p14*l13g14 + p21*l13g21 + p22*l13g22 + p23*l13g23 + p24*l13g24 + p31*l13g31 + p32*l13g32 + p33*l13g33 + p34*l13g34;


ulate1.y1	<- iv1$coeff[2];
ulate2.y1	<- iv2$coeff[2];
ulate12.y1	<- iv12$coeff[2];
ulate13.y1	<- gmm12$par[2];

tot1.y1		<- p11.x1*l1g11 + p12.x1*l1g12 + p13.x1*l1g13 +p14.x1*l1g14 +p21.x1*l1g21 +p22.x1*l1g22 +p23.x1*l1g23 +p24.x1*l1g24 +p31.x1*l1g31 +p32.x1*l1g32 +p33.x1*l1g33 +p34.x1*l1g34;
tot2.y1		<- p11.x1*l2g11 + p12.x1*l2g12 + p13.x1*l2g13 +p14.x1*l2g14 +p21.x1*l2g21 +p22.x1*l2g22 +p23.x1*l2g23 +p24.x1*l2g24 +p31.x1*l2g31 +p32.x1*l2g32 +p33.x1*l2g33 +p34.x1*l2g34;
tot12.y1	<- p11.x1*l12g11 + p12.x1*l12g12 + p13.x1*l12g13 +p14.x1*l12g14 +p21.x1*l12g21 +p22.x1*l12g22 +p23.x1*l12g23 +p24.x1*l12g24 +p31.x1*l12g31 +p32.x1*l12g32 +p33.x1*l12g33 +p34*l12g34;
tot13.y1	<- p11.x1*l13g11 + p12.x1*l13g12 + p13.x1*l13g13 +p14.x1*l13g14 +p21.x1*l13g21 +p22.x1*l13g22 +p23.x1*l13g23 +p24.x1*l13g24 +p31.x1*l13g31 +p32.x1*l13g32 +p33.x1*l13g33 +p34*l13g34;

tnt1.y1		<- p11.x0*l1g11 + p12.x0*l1g12 + p13.x0*l1g13 +p14.x0*l1g14 +p21.x0*l1g21 +p22.x0*l1g22 +p23.x0*l1g23 +p24.x0*l1g24 +p31.x0*l1g31 +p32.x0*l1g32 +p33.x0*l1g33 +p34.x0*l1g34;
tnt2.y1		<- p11.x0*l2g11 + p12.x0*l2g12 + p13.x0*l2g13 +p14.x0*l2g14 +p21.x0*l2g21 +p22.x0*l2g22 +p23.x0*l2g23 +p24.x0*l2g24 +p31.x0*l2g31 +p32.x0*l2g32 +p33.x0*l2g33 +p34.x0*l2g34;
tnt12.y1	<- p11.x0*l12g11 + p12.x0*l12g12 + p13.x0*l12g13 +p14.x0*l12g14 +p21.x0*l12g21 +p22.x0*l12g22 +p23.x0*l12g23 +p24.x0*l12g24 +p31.x0*l12g31 +p32.x0*l12g32 +p33.x0*l12g33 +p34*l12g34;
tnt13.y1	<- p11.x0*l13g11 + p12.x0*l13g12 + p13.x0*l13g13 +p14.x0*l13g14 +p21.x0*l13g21 +p22.x0*l13g22 +p23.x0*l13g23 +p24.x0*l13g24 +p31.x0*l13g31 +p32.x0*l13g32 +p33.x0*l13g33 +p34*l13g34;


wlate11.y1	<- (p11*w1g11*ovg11*l1g11 + p12*w1g12*ovg12*l1g12 + p13*w1g13*ovg13*l1g13 +p14*w1g14*ovg14*l1g14 +p21*w1g21*ovg21*l1g21 +p22*w1g22*ovg22*l1g22 +p23*w1g23*ovg23*l1g23 +p24*w1g24*ovg24*l1g24 +p31*w1g31*ovg31*l1g31 +p32*w1g32*ovg32*l1g32 +p33*w1g33*ovg33*l1g33 +p34*w1g34*ovg34*l1g34) /
			(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34);
wlate12.y1	<- (p11*w2g11*ovg11*l1g11 + p12*w2g12*ovg12*l1g12 + p13*w2g13*ovg13*l1g13 +p14*w2g14*ovg14*l1g14 +p21*w2g21*ovg21*l1g21 +p22*w2g22*ovg22*l1g22 +p23*w2g23*ovg23*l1g23 +p24*w2g24*ovg24*l1g24 +p31*w2g31*ovg31*l1g31 +p32*w2g32*ovg32*l1g32 +p33*w2g33*ovg33*l1g33 +p34*w2g34*ovg34*l1g34) /
			(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34);
wlate21.y1	<- (p11*w1g11*ovg11*l2g11 + p12*w1g12*ovg12*l2g12 + p13*w1g13*ovg13*l2g13 +p14*w1g14*ovg14*l2g14 +p21*w1g21*ovg21*l2g21 +p22*w1g22*ovg22*l2g22 +p23*w1g23*ovg23*l2g23 +p24*w1g24*ovg24*l2g24 +p31*w1g31*ovg31*l2g31 +p32*w1g32*ovg32*l2g32 +p33*w1g33*ovg33*l2g33 +p34*w1g34*ovg34*l2g34) /
			(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34);
wlate22.y1	<- (p11*w2g11*ovg11*l2g11 + p12*w2g12*ovg12*l2g12 + p13*w2g13*ovg13*l2g13 +p14*w2g14*ovg14*l2g14 +p21*w2g21*ovg21*l2g21 +p22*w2g22*ovg22*l2g22 +p23*w2g23*ovg23*l2g23 +p24*w2g24*ovg24*l2g24 +p31*w2g31*ovg31*l2g31 +p32*w2g32*ovg32*l2g32 +p33*w2g33*ovg33*l2g33 +p34*w2g34*ovg34*l2g34) /
			(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34);


wate1.y1	<- (p11*ovg11*l1g11 + p12*ovg12*l1g12 + p13*ovg13*l1g13 +p14*ovg14*l1g14 +p21*ovg21*l1g21 +p22*ovg22*l1g22 +p23*ovg23*l1g23 +p24*ovg24*l1g24 +p31*ovg31*l1g31 +p32*ovg32*l1g32 +p33*ovg33*l1g33 +p34*ovg34*l1g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);
wate2.y1	<- (p11*ovg11*l2g11 + p12*ovg12*l2g12 + p13*ovg13*l2g13 +p14*ovg14*l2g14 +p21*ovg21*l2g21 +p22*ovg22*l2g22 +p23*ovg23*l2g23 +p24*ovg24*l2g24 +p31*ovg31*l2g31 +p32*ovg32*l2g32 +p33*ovg33*l2g33 +p34*ovg34*l2g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);
wate12.y1	<- (p11*ovg11*l12g11 + p12*ovg12*l12g12 + p13*ovg13*l12g13 +p14*ovg14*l12g14 +p21*ovg21*l12g21 +p22*ovg22*l12g22 +p23*ovg23*l12g23 +p24*ovg24*l12g24 +p31*ovg31*l12g31 +p32*ovg32*l12g32 +p33*ovg33*l12g33 +p34*ovg34*l12g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);
wate13.y1	<- (p11*ovg11*l13g11 + p12*ovg12*l13g12 + p13*ovg13*l13g13 +p14*ovg14*l13g14 +p21*ovg21*l13g21 +p22*ovg22*l13g22 +p23*ovg23*l13g23 +p24*ovg24*l13g24 +p31*ovg31*l13g31 +p32*ovg32*l13g32 +p33*ovg33*l13g33 +p34*ovg34*l13g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);

wtot1.y1	<- (p11.x1*ovg11*l1g11 + p12.x1*ovg12*l1g12 + p13.x1*ovg13*l1g13 +p14.x1*ovg14*l1g14 +p21.x1*ovg21*l1g21 +p22.x1*ovg22*l1g22 +p23.x1*ovg23*l1g23 +p24.x1*ovg24*l1g24 +p31.x1*ovg31*l1g31 +p32.x1*ovg32*l1g32 +p33.x1*ovg33*l1g33 +p34.x1*ovg34*l1g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);
wtot2.y1	<- (p11.x1*ovg11*l2g11 + p12.x1*ovg12*l2g12 + p13.x1*ovg13*l2g13 +p14.x1*ovg14*l2g14 +p21.x1*ovg21*l2g21 +p22.x1*ovg22*l2g22 +p23.x1*ovg23*l2g23 +p24.x1*ovg24*l2g24 +p31.x1*ovg31*l2g31 +p32.x1*ovg32*l2g32 +p33.x1*ovg33*l2g33 +p34.x1*ovg34*l2g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);
wtot12.y1	<- (p11.x1*ovg11*l12g11 + p12.x1*ovg12*l12g12 + p13.x1*ovg13*l12g13 +p14.x1*ovg14*l12g14 +p21.x1*ovg21*l12g21 +p22.x1*ovg22*l12g22 +p23.x1*ovg23*l12g23 +p24.x1*ovg24*l12g24 +p31.x1*ovg31*l12g31 +p32.x1*ovg32*l12g32 +p33.x1*ovg33*l12g33 +p34.x1*ovg34*l12g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);
wtot13.y1	<- (p11.x1*ovg11*l13g11 + p12.x1*ovg12*l13g12 + p13.x1*ovg13*l13g13 +p14.x1*ovg14*l13g14 +p21.x1*ovg21*l13g21 +p22.x1*ovg22*l13g22 +p23.x1*ovg23*l13g23 +p24.x1*ovg24*l13g24 +p31.x1*ovg31*l13g31 +p32.x1*ovg32*l13g32 +p33.x1*ovg33*l13g33 +p34.x1*ovg34*l13g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);

wtnt1.y1	<- (p11.x0*ovg11*l1g11 + p12.x0*ovg12*l1g12 + p13.x0*ovg13*l1g13 +p14.x0*ovg14*l1g14 +p21.x0*ovg21*l1g21 +p22.x0*ovg22*l1g22 +p23.x0*ovg23*l1g23 +p24.x0*ovg24*l1g24 +p31.x0*ovg31*l1g31 +p32.x0*ovg32*l1g32 +p33.x0*ovg33*l1g33 +p34.x0*ovg34*l1g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);
wtnt2.y1	<- (p11.x0*ovg11*l2g11 + p12.x0*ovg12*l2g12 + p13.x0*ovg13*l2g13 +p14.x0*ovg14*l2g14 +p21.x0*ovg21*l2g21 +p22.x0*ovg22*l2g22 +p23.x0*ovg23*l2g23 +p24.x0*ovg24*l2g24 +p31.x0*ovg31*l2g31 +p32.x0*ovg32*l2g32 +p33.x0*ovg33*l2g33 +p34.x0*ovg34*l2g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);
wtnt12.y1	<- (p11.x0*ovg11*l12g11 + p12.x0*ovg12*l12g12 + p13.x0*ovg13*l12g13 +p14.x0*ovg14*l12g14 +p21.x0*ovg21*l12g21 +p22.x0*ovg22*l12g22 +p23.x0*ovg23*l12g23 +p24.x0*ovg24*l12g24 +p31.x0*ovg31*l12g31 +p32.x0*ovg32*l12g32 +p33.x0*ovg33*l12g33 +p34.x0*ovg34*l12g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);
wtnt13.y1	<- (p11.x0*ovg11*l13g11 + p12.x0*ovg12*l13g12 + p13.x0*ovg13*l13g13 +p14.x0*ovg14*l13g14 +p21.x0*ovg21*l13g21 +p22.x0*ovg22*l13g22 +p23.x0*ovg23*l13g23 +p24.x0*ovg24*l13g24 +p31.x0*ovg31*l13g31 +p32.x0*ovg32*l13g32 +p33.x0*ovg33*l13g33 +p34.x0*ovg34*l13g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);



w1g11.y1	<- w1g11;
w1g12.y1	<- w1g12;
w1g13.y1	<- w1g13;
w1g14.y1	<- w1g14;
w1g21.y1	<- w1g21;
w1g22.y1	<- w1g22;
w1g23.y1	<- w1g23;
w1g24.y1	<- w1g24;
w1g31.y1	<- w1g31;
w1g32.y1	<- w1g32;
w1g33.y1	<- w1g33;
w1g34.y1	<- w1g34;

w2g11.y1	<- w2g11;
w2g12.y1	<- w2g12;
w2g13.y1	<- w2g13;
w2g14.y1	<- w2g14;
w2g21.y1	<- w2g21;
w2g22.y1	<- w2g22;
w2g23.y1	<- w2g23;
w2g24.y1	<- w2g24;
w2g31.y1	<- w2g31;
w2g32.y1	<- w2g32;
w2g33.y1	<- w2g33;
w2g34.y1	<- w2g34;

l1g11.y1	<- l1g11;
l1g12.y1	<- l1g12;
l1g13.y1	<- l1g13;
l1g14.y1	<- l1g14;
l1g21.y1	<- l1g21;
l1g22.y1	<- l1g22;
l1g23.y1	<- l1g23;
l1g24.y1	<- l1g24;
l1g31.y1	<- l1g31;
l1g32.y1	<- l1g32;
l1g33.y1	<- l1g33;
l1g34.y1	<- l1g34;

l2g11.y1	<- l2g11;
l2g12.y1	<- l2g12;
l2g13.y1	<- l2g13;
l2g14.y1	<- l2g14;
l2g21.y1	<- l2g21;
l2g22.y1	<- l2g22;
l2g23.y1	<- l2g23;
l2g24.y1	<- l2g24;
l2g31.y1	<- l2g31;
l2g32.y1	<- l2g32;
l2g33.y1	<- l2g33;
l2g34.y1	<- l2g34;

l12g11.y1	<- l12g11;
l12g12.y1	<- l12g12;
l12g13.y1	<- l12g13;
l12g14.y1	<- l12g14;
l12g21.y1	<- l12g21;
l12g22.y1	<- l12g22;
l12g23.y1	<- l12g23;
l12g24.y1	<- l12g24;
l12g31.y1	<- l12g31;
l12g32.y1	<- l12g32;
l12g33.y1	<- l12g33;
l12g34.y1	<- l12g34;

l13g11.y1	<- l13g11;
l13g12.y1	<- l13g12;
l13g13.y1	<- l13g13;
l13g14.y1	<- l13g14;
l13g21.y1	<- l13g21;
l13g22.y1	<- l13g22;
l13g23.y1	<- l13g23;
l13g24.y1	<- l13g24;
l13g31.y1	<- l13g31;
l13g32.y1	<- l13g32;
l13g33.y1	<- l13g33;
l13g34.y1	<- l13g34;

ovg11.y1	<- ovg11;
ovg12.y1	<- ovg12;
ovg13.y1	<- ovg13;
ovg14.y1	<- ovg14;
ovg21.y1	<- ovg21;
ovg22.y1	<- ovg22;
ovg23.y1	<- ovg23;
ovg24.y1	<- ovg24;
ovg31.y1	<- ovg31;
ovg32.y1	<- ovg32;
ovg33.y1	<- ovg33;
ovg34.y1	<- ovg34;


sel1g11.y1	<- sqrt(iv1g11$V[2,2]);
sel1g12.y1	<- sqrt(iv1g12$V[2,2]);
sel1g13.y1	<- sqrt(iv1g13$V[2,2]);
sel1g14.y1	<- sqrt(iv1g14$V[2,2]);
sel1g21.y1	<- sqrt(iv1g21$V[2,2]);
sel1g22.y1	<- sqrt(iv1g22$V[2,2]);
sel1g23.y1	<- sqrt(iv1g23$V[2,2]);
sel1g24.y1	<- sqrt(iv1g24$V[2,2]);
sel1g31.y1	<- sqrt(iv1g31$V[2,2]);
sel1g32.y1	<- sqrt(iv1g32$V[2,2]);
sel1g33.y1	<- sqrt(iv1g33$V[2,2]);
sel1g34.y1	<- sqrt(iv1g34$V[2,2]);

sel2g11.y1	<- sqrt(iv2g11$V[2,2]);
sel2g12.y1	<- sqrt(iv2g12$V[2,2]);
sel2g13.y1	<- sqrt(iv2g13$V[2,2]);
sel2g14.y1	<- sqrt(iv2g14$V[2,2]);
sel2g21.y1	<- sqrt(iv2g21$V[2,2]);
sel2g22.y1	<- sqrt(iv2g22$V[2,2]);
sel2g23.y1	<- sqrt(iv2g23$V[2,2]);
sel2g24.y1	<- sqrt(iv2g24$V[2,2]);
sel2g31.y1	<- sqrt(iv2g31$V[2,2]);
sel2g32.y1	<- sqrt(iv2g32$V[2,2]);
sel2g33.y1	<- sqrt(iv2g33$V[2,2]);
sel2g34.y1	<- sqrt(iv2g34$V[2,2]);

sel13g11.y1	<- summary(gmm12g11)$par[2,2];
sel13g12.y1	<- summary(gmm12g12)$par[2,2];
sel13g13.y1	<- summary(gmm12g13)$par[2,2];
sel13g14.y1	<- summary(gmm12g14)$par[2,2];
sel13g21.y1	<- summary(gmm12g21)$par[2,2];
sel13g22.y1	<- summary(gmm12g22)$par[2,2];
sel13g23.y1	<- summary(gmm12g23)$par[2,2];
sel13g24.y1	<- summary(gmm12g24)$par[2,2];
sel13g31.y1	<- summary(gmm12g31)$par[2,2];
sel13g32.y1	<- summary(gmm12g32)$par[2,2];
sel13g33.y1	<- summary(gmm12g33)$par[2,2];
sel13g34.y1	<- summary(gmm12g34)$par[2,2];

#############################;
# LFP;
#############################;

# MODELS WITHOUT COVARIATES;

form2	<- y2 ~ x;


iv1	<- tsls(form2, ~ z1, data = data);
iv2	<- tsls(form2, ~ z2, data = data);
iv12	<- tsls(form2, ~ z1 + z2, data = data);
gmm12	<- gmm(form2, x = cbind(z1,z2), vcov = "iid", type = "twoStep");


# MODELS WITH COVARIATES;


iv1g11	<- tsls(y2[g==11]~x[g==11], ~z1[g==11], data = data);
iv1g12	<- tsls(y2[g==12]~x[g==12], ~z1[g==12], data = data);
iv1g13	<- tsls(y2[g==13]~x[g==13], ~z1[g==13], data = data);
iv1g14	<- tsls(y2[g==14]~x[g==14], ~z1[g==14], data = data);
iv1g21	<- tsls(y2[g==21]~x[g==21], ~z1[g==21], data = data);
iv1g22	<- tsls(y2[g==22]~x[g==22], ~z1[g==22], data = data);
iv1g23	<- tsls(y2[g==23]~x[g==23], ~z1[g==23], data = data);
iv1g24	<- tsls(y2[g==24]~x[g==24], ~z1[g==24], data = data);
iv1g31	<- tsls(y2[g==31]~x[g==31], ~z1[g==31], data = data);
iv1g32	<- tsls(y2[g==32]~x[g==32], ~z1[g==32], data = data);
iv1g33	<- tsls(y2[g==33]~x[g==33], ~z1[g==33], data = data);
iv1g34	<- tsls(y2[g==34]~x[g==34], ~z1[g==34], data = data);


iv2g11	<- tsls(y2[g==11]~x[g==11], ~z2[g==11], data = data);
iv2g12	<- tsls(y2[g==12]~x[g==12], ~z2[g==12], data = data);
iv2g13	<- tsls(y2[g==13]~x[g==13], ~z2[g==13], data = data);
iv2g14	<- tsls(y2[g==14]~x[g==14], ~z2[g==14], data = data);
iv2g21	<- tsls(y2[g==21]~x[g==21], ~z2[g==21], data = data);
iv2g22	<- tsls(y2[g==22]~x[g==22], ~z2[g==22], data = data);
iv2g23	<- tsls(y2[g==23]~x[g==23], ~z2[g==23], data = data);
iv2g24	<- tsls(y2[g==24]~x[g==24], ~z2[g==24], data = data);
iv2g31	<- tsls(y2[g==31]~x[g==31], ~z2[g==31], data = data);
iv2g32	<- tsls(y2[g==32]~x[g==32], ~z2[g==32], data = data);
iv2g33	<- tsls(y2[g==33]~x[g==33], ~z2[g==33], data = data);
iv2g34	<- tsls(y2[g==34]~x[g==34], ~z2[g==34], data = data);

iv12g11	<- tsls(y2[g==11]~x[g==11], ~z1[g==11] + z2[g==11], data = data);
iv12g12	<- tsls(y2[g==12]~x[g==12], ~z1[g==12] + z2[g==12], data = data);
iv12g13	<- tsls(y2[g==13]~x[g==13], ~z1[g==13] + z2[g==13], data = data);
iv12g14	<- tsls(y2[g==14]~x[g==14], ~z1[g==14] + z2[g==14], data = data);
iv12g21	<- tsls(y2[g==21]~x[g==21], ~z1[g==21] + z2[g==21], data = data);
iv12g22	<- tsls(y2[g==22]~x[g==22], ~z1[g==22] + z2[g==22], data = data);
iv12g23	<- tsls(y2[g==23]~x[g==23], ~z1[g==23] + z2[g==23], data = data);
iv12g24	<- tsls(y2[g==24]~x[g==24], ~z1[g==24] + z2[g==24], data = data);
iv12g31	<- tsls(y2[g==31]~x[g==31], ~z1[g==31] + z2[g==31], data = data);
iv12g32	<- tsls(y2[g==32]~x[g==32], ~z1[g==32] + z2[g==32], data = data);
iv12g33	<- tsls(y2[g==33]~x[g==33], ~z1[g==33] + z2[g==33], data = data);
iv12g34	<- tsls(y2[g==34]~x[g==34], ~z1[g==34] + z2[g==34], data = data);

gmm12g11<- gmm(y2[g==11]~x[g==11], x = cbind(z1[g==11],z2[g==11]), vcov = "iid", type = "twoStep");
gmm12g12<- gmm(y2[g==12]~x[g==12], x = cbind(z1[g==12],z2[g==12]), vcov = "iid", type = "twoStep");
gmm12g13<- gmm(y2[g==13]~x[g==13], x = cbind(z1[g==13],z2[g==13]), vcov = "iid", type = "twoStep");
gmm12g14<- gmm(y2[g==14]~x[g==14], x = cbind(z1[g==14],z2[g==14]), vcov = "iid", type = "twoStep");
gmm12g21<- gmm(y2[g==21]~x[g==21], x = cbind(z1[g==21],z2[g==21]), vcov = "iid", type = "twoStep");
gmm12g22<- gmm(y2[g==22]~x[g==22], x = cbind(z1[g==22],z2[g==22]), vcov = "iid", type = "twoStep");
gmm12g23<- gmm(y2[g==23]~x[g==23], x = cbind(z1[g==23],z2[g==23]), vcov = "iid", type = "twoStep");
gmm12g24<- gmm(y2[g==24]~x[g==24], x = cbind(z1[g==24],z2[g==24]), vcov = "iid", type = "twoStep");
gmm12g31<- gmm(y2[g==31]~x[g==31], x = cbind(z1[g==31],z2[g==31]), vcov = "iid", type = "twoStep");
gmm12g32<- gmm(y2[g==32]~x[g==32], x = cbind(z1[g==32],z2[g==32]), vcov = "iid", type = "twoStep");
gmm12g33<- gmm(y2[g==33]~x[g==33], x = cbind(z1[g==33],z2[g==33]), vcov = "iid", type = "twoStep");
gmm12g34<- gmm(y2[g==34]~x[g==34], x = cbind(z1[g==34],z2[g==34]), vcov = "iid", type = "twoStep");

ov	<- p11*exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) + p12*exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) + p13*exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) + p14*exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) + p21*exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) + p22*exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) + p23*exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) + p24*exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) + p31*exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) + p32*exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) + p33*exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) + p34*exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n));
ovg11	<- exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) / ov ;
ovg12	<- exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) / ov ;
ovg13	<- exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) / ov ;
ovg14	<- exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) / ov ;
ovg21	<- exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) / ov ;
ovg22	<- exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) / ov ;
ovg23	<- exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) / ov ;
ovg24	<- exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) / ov ;
ovg31	<- exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) / ov ;
ovg32	<- exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) / ov ;
ovg33	<- exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) / ov ;
ovg34	<- exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n)) / ov ;



l1g11	<- iv1g11$coeff[2];
l1g12	<- iv1g12$coeff[2];
l1g13	<- iv1g13$coeff[2];
l1g14	<- iv1g14$coeff[2];
l1g21	<- iv1g21$coeff[2];
l1g22	<- iv1g22$coeff[2];
l1g23	<- iv1g23$coeff[2];
l1g24	<- iv1g24$coeff[2];
l1g31	<- iv1g31$coeff[2];
l1g32	<- iv1g32$coeff[2];
l1g33	<- iv1g33$coeff[2];
l1g34	<- iv1g34$coeff[2];

l2g11	<- iv2g11$coeff[2];
l2g12	<- iv2g12$coeff[2];
l2g13	<- iv2g13$coeff[2];
l2g14	<- iv2g14$coeff[2];
l2g21	<- iv2g21$coeff[2];
l2g22	<- iv2g22$coeff[2];
l2g23	<- iv2g23$coeff[2];
l2g24	<- iv2g24$coeff[2];
l2g31	<- iv2g31$coeff[2];
l2g32	<- iv2g32$coeff[2];
l2g33	<- iv2g33$coeff[2];
l2g34	<- iv2g34$coeff[2];

l12g11	<- iv12g11$coeff[2];
l12g12	<- iv12g12$coeff[2];
l12g13	<- iv12g13$coeff[2];
l12g14	<- iv12g14$coeff[2];
l12g21	<- iv12g21$coeff[2];
l12g22	<- iv12g22$coeff[2];
l12g23	<- iv12g23$coeff[2];
l12g24	<- iv12g24$coeff[2];
l12g31	<- iv12g31$coeff[2];
l12g32	<- iv12g32$coeff[2];
l12g33	<- iv12g33$coeff[2];
l12g34	<- iv12g34$coeff[2];

l13g11	<- gmm12g11$par[2];
l13g12	<- gmm12g12$par[2];
l13g13	<- gmm12g13$par[2];
l13g14	<- gmm12g14$par[2];
l13g21	<- gmm12g21$par[2];
l13g22	<- gmm12g22$par[2];
l13g23	<- gmm12g23$par[2];
l13g24	<- gmm12g24$par[2];
l13g31	<- gmm12g31$par[2];
l13g32	<- gmm12g32$par[2];
l13g33	<- gmm12g33$par[2];
l13g34	<- gmm12g34$par[2];


late11.y2	<- (p11*w1g11*l1g11 + p12*w1g12*l1g12 + p13*w1g13*l1g13 +p14*w1g14*l1g14 +p21*w1g21*l1g21 +p22*w1g22*l1g22 +p23*w1g23*l1g23 +p24*w1g24*l1g24 +p31*w1g31*l1g31 +p32*w1g32*l1g32 +p33*w1g33*l1g33 +p34*w1g34*l1g34) /
			 (p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34);
late12.y2	<- (p11*w2g11*l1g11 + p12*w2g12*l1g12 + p13*w2g13*l1g13 +p14*w2g14*l1g14 +p21*w2g21*l1g21 +p22*w2g22*l1g22 +p23*w2g23*l1g23 +p24*w2g24*l1g24 +p31*w2g31*l1g31 +p32*w2g32*l1g32 +p33*w2g33*l1g33 +p34*w2g34*l1g34) /
			 (p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34);			
late13.y2	<- (p11*w1g11*l13g11 + p12*w1g12*l13g12 + p13*w1g13*l13g13 +p14*w1g14*l13g14 +p21*w1g21*l13g21 +p22*w1g22*l13g22 +p23*w1g23*l13g23 +p24*w1g24*l13g24 +p31*w1g31*l13g31 +p32*w1g32*l13g32 +p33*w1g33*l13g33 +p34*w1g34*l13g34) /
			 (p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34);
late21.y2	<- (p11*w1g11*l2g11 + p12*w1g12*l2g12 + p13*w1g13*l2g13 +p14*w1g14*l2g14 +p21*w1g21*l2g21 +p22*w1g22*l2g22 +p23*w1g23*l2g23 +p24*w1g24*l2g24 +p31*w1g31*l2g31 +p32*w1g32*l2g32 +p33*w1g33*l2g33 +p34*w1g34*l2g34) /
			 (p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34);
late22.y2	<- (p11*w2g11*l2g11 + p12*w2g12*l2g12 + p13*w2g13*l2g13 +p14*w2g14*l2g14 +p21*w2g21*l2g21 +p22*w2g22*l2g22 +p23*w2g23*l2g23 +p24*w2g24*l2g24 +p31*w2g31*l2g31 +p32*w2g32*l2g32 +p33*w2g33*l2g33 +p34*w2g34*l2g34) /
			 (p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34);			
late23.y2	<- (p11*w2g11*l13g11 + p12*w2g12*l13g12 + p13*w2g13*l13g13 +p14*w2g14*l13g14 +p21*w2g21*l13g21 +p22*w2g22*l13g22 +p23*w2g23*l13g23 +p24*w2g24*l13g24 +p31*w2g31*l13g31 +p32*w2g32*l13g32 +p33*w2g33*l13g33 +p34*w2g34*l13g34) /
			(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34);			

ate1.y2		<- p11*l1g11 + p12*l1g12 + p13*l1g13 +p14*l1g14 +p21*l1g21 +p22*l1g22 +p23*l1g23 +p24*l1g24 +p31*l1g31 +p32*l1g32 +p33*l1g33 +p34*l1g34;
ate2.y2		<- p11*l2g11 + p12*l2g12 + p13*l2g13 +p14*l2g14 +p21*l2g21 +p22*l2g22 +p23*l2g23 +p24*l2g24 +p31*l2g31 +p32*l2g32 +p33*l2g33 +p34*l2g34;
ate12.y2	<- p11*l12g11 + p12*l12g12 + p13*l12g13 +p14*l12g14 +p21*l12g21 +p22*l12g22 +p23*l12g23 +p24*l12g24 +p31*l12g31 +p32*l12g32 +p33*l12g33 +p34*l12g34;
ate13.y2	<- p11*l13g11 + p12*l13g12 + p13*l13g13 +p14*l13g14 +p21*l13g21 +p22*l13g22 +p23*l13g23 +p24*l13g24 +p31*l13g31 +p32*l13g32 +p33*l13g33 +p34*l13g34;


ulate1.y2	<- iv1$coeff[2];
ulate2.y2	<- iv2$coeff[2];
ulate12.y2	<- iv12$coeff[2];
ulate13.y2	<- gmm12$par[2];

tot1.y2		<- p11.x1*l1g11 + p12.x1*l1g12 + p13.x1*l1g13 +p14.x1*l1g14 +p21.x1*l1g21 +p22.x1*l1g22 +p23.x1*l1g23 +p24.x1*l1g24 +p31.x1*l1g31 +p32.x1*l1g32 +p33.x1*l1g33 +p34.x1*l1g34;
tot2.y2		<- p11.x1*l2g11 + p12.x1*l2g12 + p13.x1*l2g13 +p14.x1*l2g14 +p21.x1*l2g21 +p22.x1*l2g22 +p23.x1*l2g23 +p24.x1*l2g24 +p31.x1*l2g31 +p32.x1*l2g32 +p33.x1*l2g33 +p34.x1*l2g34;
tot12.y2	<- p11.x1*l12g11 + p12.x1*l12g12 + p13.x1*l12g13 +p14.x1*l12g14 +p21.x1*l12g21 +p22.x1*l12g22 +p23.x1*l12g23 +p24.x1*l12g24 +p31.x1*l12g31 +p32.x1*l12g32 +p33.x1*l12g33 +p34*l12g34;
tot13.y2	<- p11.x1*l13g11 + p12.x1*l13g12 + p13.x1*l13g13 +p14.x1*l13g14 +p21.x1*l13g21 +p22.x1*l13g22 +p23.x1*l13g23 +p24.x1*l13g24 +p31.x1*l13g31 +p32.x1*l13g32 +p33.x1*l13g33 +p34*l13g34;

tnt1.y2		<- p11.x0*l1g11 + p12.x0*l1g12 + p13.x0*l1g13 +p14.x0*l1g14 +p21.x0*l1g21 +p22.x0*l1g22 +p23.x0*l1g23 +p24.x0*l1g24 +p31.x0*l1g31 +p32.x0*l1g32 +p33.x0*l1g33 +p34.x0*l1g34;
tnt2.y2		<- p11.x0*l2g11 + p12.x0*l2g12 + p13.x0*l2g13 +p14.x0*l2g14 +p21.x0*l2g21 +p22.x0*l2g22 +p23.x0*l2g23 +p24.x0*l2g24 +p31.x0*l2g31 +p32.x0*l2g32 +p33.x0*l2g33 +p34.x0*l2g34;
tnt12.y2	<- p11.x0*l12g11 + p12.x0*l12g12 + p13.x0*l12g13 +p14.x0*l12g14 +p21.x0*l12g21 +p22.x0*l12g22 +p23.x0*l12g23 +p24.x0*l12g24 +p31.x0*l12g31 +p32.x0*l12g32 +p33.x0*l12g33 +p34*l12g34;
tnt13.y2	<- p11.x0*l13g11 + p12.x0*l13g12 + p13.x0*l13g13 +p14.x0*l13g14 +p21.x0*l13g21 +p22.x0*l13g22 +p23.x0*l13g23 +p24.x0*l13g24 +p31.x0*l13g31 +p32.x0*l13g32 +p33.x0*l13g33 +p34*l13g34;


wlate11.y2	<- (p11*w1g11*ovg11*l1g11 + p12*w1g12*ovg12*l1g12 + p13*w1g13*ovg13*l1g13 +p14*w1g14*ovg14*l1g14 +p21*w1g21*ovg21*l1g21 +p22*w1g22*ovg22*l1g22 +p23*w1g23*ovg23*l1g23 +p24*w1g24*ovg24*l1g24 +p31*w1g31*ovg31*l1g31 +p32*w1g32*ovg32*l1g32 +p33*w1g33*ovg33*l1g33 +p34*w1g34*ovg34*l1g34) /
			(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34);
wlate12.y2	<- (p11*w2g11*ovg11*l1g11 + p12*w2g12*ovg12*l1g12 + p13*w2g13*ovg13*l1g13 +p14*w2g14*ovg14*l1g14 +p21*w2g21*ovg21*l1g21 +p22*w2g22*ovg22*l1g22 +p23*w2g23*ovg23*l1g23 +p24*w2g24*ovg24*l1g24 +p31*w2g31*ovg31*l1g31 +p32*w2g32*ovg32*l1g32 +p33*w2g33*ovg33*l1g33 +p34*w2g34*ovg34*l1g34) /
			(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34);
wlate21.y2	<- (p11*w1g11*ovg11*l2g11 + p12*w1g12*ovg12*l2g12 + p13*w1g13*ovg13*l2g13 +p14*w1g14*ovg14*l2g14 +p21*w1g21*ovg21*l2g21 +p22*w1g22*ovg22*l2g22 +p23*w1g23*ovg23*l2g23 +p24*w1g24*ovg24*l2g24 +p31*w1g31*ovg31*l2g31 +p32*w1g32*ovg32*l2g32 +p33*w1g33*ovg33*l2g33 +p34*w1g34*ovg34*l2g34) /
			(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34);
wlate22.y2	<- (p11*w2g11*ovg11*l2g11 + p12*w2g12*ovg12*l2g12 + p13*w2g13*ovg13*l2g13 +p14*w2g14*ovg14*l2g14 +p21*w2g21*ovg21*l2g21 +p22*w2g22*ovg22*l2g22 +p23*w2g23*ovg23*l2g23 +p24*w2g24*ovg24*l2g24 +p31*w2g31*ovg31*l2g31 +p32*w2g32*ovg32*l2g32 +p33*w2g33*ovg33*l2g33 +p34*w2g34*ovg34*l2g34) /
			(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34);


wate1.y2	<- (p11*ovg11*l1g11 + p12*ovg12*l1g12 + p13*ovg13*l1g13 +p14*ovg14*l1g14 +p21*ovg21*l1g21 +p22*ovg22*l1g22 +p23*ovg23*l1g23 +p24*ovg24*l1g24 +p31*ovg31*l1g31 +p32*ovg32*l1g32 +p33*ovg33*l1g33 +p34*ovg34*l1g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);
wate2.y2	<- (p11*ovg11*l2g11 + p12*ovg12*l2g12 + p13*ovg13*l2g13 +p14*ovg14*l2g14 +p21*ovg21*l2g21 +p22*ovg22*l2g22 +p23*ovg23*l2g23 +p24*ovg24*l2g24 +p31*ovg31*l2g31 +p32*ovg32*l2g32 +p33*ovg33*l2g33 +p34*ovg34*l2g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);
wate12.y2	<- (p11*ovg11*l12g11 + p12*ovg12*l12g12 + p13*ovg13*l12g13 +p14*ovg14*l12g14 +p21*ovg21*l12g21 +p22*ovg22*l12g22 +p23*ovg23*l12g23 +p24*ovg24*l12g24 +p31*ovg31*l12g31 +p32*ovg32*l12g32 +p33*ovg33*l12g33 +p34*ovg34*l12g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);
wate13.y2	<- (p11*ovg11*l13g11 + p12*ovg12*l13g12 + p13*ovg13*l13g13 +p14*ovg14*l13g14 +p21*ovg21*l13g21 +p22*ovg22*l13g22 +p23*ovg23*l13g23 +p24*ovg24*l13g24 +p31*ovg31*l13g31 +p32*ovg32*l13g32 +p33*ovg33*l13g33 +p34*ovg34*l13g34) /
			(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34);

wtot1.y2	<- (p11.x1*ovg11*l1g11 + p12.x1*ovg12*l1g12 + p13.x1*ovg13*l1g13 +p14.x1*ovg14*l1g14 +p21.x1*ovg21*l1g21 +p22.x1*ovg22*l1g22 +p23.x1*ovg23*l1g23 +p24.x1*ovg24*l1g24 +p31.x1*ovg31*l1g31 +p32.x1*ovg32*l1g32 +p33.x1*ovg33*l1g33 +p34.x1*ovg34*l1g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);
wtot2.y2	<- (p11.x1*ovg11*l2g11 + p12.x1*ovg12*l2g12 + p13.x1*ovg13*l2g13 +p14.x1*ovg14*l2g14 +p21.x1*ovg21*l2g21 +p22.x1*ovg22*l2g22 +p23.x1*ovg23*l2g23 +p24.x1*ovg24*l2g24 +p31.x1*ovg31*l2g31 +p32.x1*ovg32*l2g32 +p33.x1*ovg33*l2g33 +p34.x1*ovg34*l2g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);
wtot12.y2	<- (p11.x1*ovg11*l12g11 + p12.x1*ovg12*l12g12 + p13.x1*ovg13*l12g13 +p14.x1*ovg14*l12g14 +p21.x1*ovg21*l12g21 +p22.x1*ovg22*l12g22 +p23.x1*ovg23*l12g23 +p24.x1*ovg24*l12g24 +p31.x1*ovg31*l12g31 +p32.x1*ovg32*l12g32 +p33.x1*ovg33*l12g33 +p34.x1*ovg34*l12g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);
wtot13.y2	<- (p11.x1*ovg11*l13g11 + p12.x1*ovg12*l13g12 + p13.x1*ovg13*l13g13 +p14.x1*ovg14*l13g14 +p21.x1*ovg21*l13g21 +p22.x1*ovg22*l13g22 +p23.x1*ovg23*l13g23 +p24.x1*ovg24*l13g24 +p31.x1*ovg31*l13g31 +p32.x1*ovg32*l13g32 +p33.x1*ovg33*l13g33 +p34.x1*ovg34*l13g34) /
			(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34);

wtnt1.y2	<- (p11.x0*ovg11*l1g11 + p12.x0*ovg12*l1g12 + p13.x0*ovg13*l1g13 +p14.x0*ovg14*l1g14 +p21.x0*ovg21*l1g21 +p22.x0*ovg22*l1g22 +p23.x0*ovg23*l1g23 +p24.x0*ovg24*l1g24 +p31.x0*ovg31*l1g31 +p32.x0*ovg32*l1g32 +p33.x0*ovg33*l1g33 +p34.x0*ovg34*l1g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);
wtnt2.y2	<- (p11.x0*ovg11*l2g11 + p12.x0*ovg12*l2g12 + p13.x0*ovg13*l2g13 +p14.x0*ovg14*l2g14 +p21.x0*ovg21*l2g21 +p22.x0*ovg22*l2g22 +p23.x0*ovg23*l2g23 +p24.x0*ovg24*l2g24 +p31.x0*ovg31*l2g31 +p32.x0*ovg32*l2g32 +p33.x0*ovg33*l2g33 +p34.x0*ovg34*l2g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);
wtnt12.y2	<- (p11.x0*ovg11*l12g11 + p12.x0*ovg12*l12g12 + p13.x0*ovg13*l12g13 +p14.x0*ovg14*l12g14 +p21.x0*ovg21*l12g21 +p22.x0*ovg22*l12g22 +p23.x0*ovg23*l12g23 +p24.x0*ovg24*l12g24 +p31.x0*ovg31*l12g31 +p32.x0*ovg32*l12g32 +p33.x0*ovg33*l12g33 +p34.x0*ovg34*l12g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);
wtnt13.y2	<- (p11.x0*ovg11*l13g11 + p12.x0*ovg12*l13g12 + p13.x0*ovg13*l13g13 +p14.x0*ovg14*l13g14 +p21.x0*ovg21*l13g21 +p22.x0*ovg22*l13g22 +p23.x0*ovg23*l13g23 +p24.x0*ovg24*l13g24 +p31.x0*ovg31*l13g31 +p32.x0*ovg32*l13g32 +p33.x0*ovg33*l13g33 +p34.x0*ovg34*l13g34) /
			(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34);



w1g11.y2	<- w1g11;
w1g12.y2	<- w1g12;
w1g13.y2	<- w1g13;
w1g14.y2	<- w1g14;
w1g21.y2	<- w1g21;
w1g22.y2	<- w1g22;
w1g23.y2	<- w1g23;
w1g24.y2	<- w1g24;
w1g31.y2	<- w1g31;
w1g32.y2	<- w1g32;
w1g33.y2	<- w1g33;
w1g34.y2	<- w1g34;

w2g11.y2	<- w2g11;
w2g12.y2	<- w2g12;
w2g13.y2	<- w2g13;
w2g14.y2	<- w2g14;
w2g21.y2	<- w2g21;
w2g22.y2	<- w2g22;
w2g23.y2	<- w2g23;
w2g24.y2	<- w2g24;
w2g31.y2	<- w2g31;
w2g32.y2	<- w2g32;
w2g33.y2	<- w2g33;
w2g34.y2	<- w2g34;

l1g11.y2	<- l1g11;
l1g12.y2	<- l1g12;
l1g13.y2	<- l1g13;
l1g14.y2	<- l1g14;
l1g21.y2	<- l1g21;
l1g22.y2	<- l1g22;
l1g23.y2	<- l1g23;
l1g24.y2	<- l1g24;
l1g31.y2	<- l1g31;
l1g32.y2	<- l1g32;
l1g33.y2	<- l1g33;
l1g34.y2	<- l1g34;

l2g11.y2	<- l2g11;
l2g12.y2	<- l2g12;
l2g13.y2	<- l2g13;
l2g14.y2	<- l2g14;
l2g21.y2	<- l2g21;
l2g22.y2	<- l2g22;
l2g23.y2	<- l2g23;
l2g24.y2	<- l2g24;
l2g31.y2	<- l2g31;
l2g32.y2	<- l2g32;
l2g33.y2	<- l2g33;
l2g34.y2	<- l2g34;

l12g11.y2	<- l12g11;
l12g12.y2	<- l12g12;
l12g13.y2	<- l12g13;
l12g14.y2	<- l12g14;
l12g21.y2	<- l12g21;
l12g22.y2	<- l12g22;
l12g23.y2	<- l12g23;
l12g24.y2	<- l12g24;
l12g31.y2	<- l12g31;
l12g32.y2	<- l12g32;
l12g33.y2	<- l12g33;
l12g34.y2	<- l12g34;

l13g11.y2	<- l13g11;
l13g12.y2	<- l13g12;
l13g13.y2	<- l13g13;
l13g14.y2	<- l13g14;
l13g21.y2	<- l13g21;
l13g22.y2	<- l13g22;
l13g23.y2	<- l13g23;
l13g24.y2	<- l13g24;
l13g31.y2	<- l13g31;
l13g32.y2	<- l13g32;
l13g33.y2	<- l13g33;
l13g34.y2	<- l13g34;


ovg11.y2	<- ovg11;
ovg12.y2	<- ovg12;
ovg13.y2	<- ovg13;
ovg14.y2	<- ovg14;
ovg21.y2	<- ovg21;
ovg22.y2	<- ovg22;
ovg23.y2	<- ovg23;
ovg24.y2	<- ovg24;
ovg31.y2	<- ovg31;
ovg32.y2	<- ovg32;
ovg33.y2	<- ovg33;
ovg34.y2	<- ovg34;



sel1g11.y2	<- sqrt(iv1g11$V[2,2]);
sel1g12.y2	<- sqrt(iv1g12$V[2,2]);
sel1g13.y2	<- sqrt(iv1g13$V[2,2]);
sel1g14.y2	<- sqrt(iv1g14$V[2,2]);
sel1g21.y2	<- sqrt(iv1g21$V[2,2]);
sel1g22.y2	<- sqrt(iv1g22$V[2,2]);
sel1g23.y2	<- sqrt(iv1g23$V[2,2]);
sel1g24.y2	<- sqrt(iv1g24$V[2,2]);
sel1g31.y2	<- sqrt(iv1g31$V[2,2]);
sel1g32.y2	<- sqrt(iv1g32$V[2,2]);
sel1g33.y2	<- sqrt(iv1g33$V[2,2]);
sel1g34.y2	<- sqrt(iv1g34$V[2,2]);

sel2g11.y2	<- sqrt(iv2g11$V[2,2]);
sel2g12.y2	<- sqrt(iv2g12$V[2,2]);
sel2g13.y2	<- sqrt(iv2g13$V[2,2]);
sel2g14.y2	<- sqrt(iv2g14$V[2,2]);
sel2g21.y2	<- sqrt(iv2g21$V[2,2]);
sel2g22.y2	<- sqrt(iv2g22$V[2,2]);
sel2g23.y2	<- sqrt(iv2g23$V[2,2]);
sel2g24.y2	<- sqrt(iv2g24$V[2,2]);
sel2g31.y2	<- sqrt(iv2g31$V[2,2]);
sel2g32.y2	<- sqrt(iv2g32$V[2,2]);
sel2g33.y2	<- sqrt(iv2g33$V[2,2]);
sel2g34.y2	<- sqrt(iv2g34$V[2,2]);

sel13g11.y2	<- summary(gmm12g11)$par[2,2];
sel13g12.y2	<- summary(gmm12g12)$par[2,2];
sel13g13.y2	<- summary(gmm12g13)$par[2,2];
sel13g14.y2	<- summary(gmm12g14)$par[2,2];
sel13g21.y2	<- summary(gmm12g21)$par[2,2];
sel13g22.y2	<- summary(gmm12g22)$par[2,2];
sel13g23.y2	<- summary(gmm12g23)$par[2,2];
sel13g24.y2	<- summary(gmm12g24)$par[2,2];
sel13g31.y2	<- summary(gmm12g31)$par[2,2];
sel13g32.y2	<- summary(gmm12g32)$par[2,2];
sel13g33.y2	<- summary(gmm12g33)$par[2,2];
sel13g34.y2	<- summary(gmm12g34)$par[2,2];



################################################################################################;
#				2 - BOOTSTRAP: STD. ERRORS;
################################################################################################;

B 	<- 1000;
n 	<- length(y1);
b	<- n; #bootstrap
# b	<- 60000; #subsampling

#############################;
# WEEKS WORKED;
#############################;



# EL PROBABILITIES;

g11gmm1	<- gmm(g = y1[g == 11] ~ x[g == 11], x = cbind(z1[g == 11], z2[g == 11]), vcov = "iid", type = "twoStep");
g12gmm1	<- gmm(g = y1[g == 12] ~ x[g == 12], x = cbind(z1[g == 12], z2[g == 12]), vcov = "iid", type = "twoStep");
g13gmm1	<- gmm(g = y1[g == 13] ~ x[g == 13], x = cbind(z1[g == 13], z2[g == 13]), vcov = "iid", type = "twoStep");
g14gmm1	<- gmm(g = y1[g == 14] ~ x[g == 14], x = cbind(z1[g == 14], z2[g == 14]), vcov = "iid", type = "twoStep");
g21gmm1	<- gmm(g = y1[g == 21] ~ x[g == 21], x = cbind(z1[g == 21], z2[g == 21]), vcov = "iid", type = "twoStep");
g22gmm1	<- gmm(g = y1[g == 22] ~ x[g == 22], x = cbind(z1[g == 22], z2[g == 22]), vcov = "iid", type = "twoStep");
g23gmm1	<- gmm(g = y1[g == 23] ~ x[g == 23], x = cbind(z1[g == 23], z2[g == 23]), vcov = "iid", type = "twoStep");
g24gmm1	<- gmm(g = y1[g == 24] ~ x[g == 24], x = cbind(z1[g == 24], z2[g == 24]), vcov = "iid", type = "twoStep");
g31gmm1	<- gmm(g = y1[g == 31] ~ x[g == 31], x = cbind(z1[g == 31], z2[g == 31]), vcov = "iid", type = "twoStep");
g32gmm1	<- gmm(g = y1[g == 32] ~ x[g == 32], x = cbind(z1[g == 32], z2[g == 32]), vcov = "iid", type = "twoStep");
g33gmm1	<- gmm(g = y1[g == 33] ~ x[g == 33], x = cbind(z1[g == 33], z2[g == 33]), vcov = "iid", type = "twoStep");
g34gmm1	<- gmm(g = y1[g == 34] ~ x[g == 34], x = cbind(z1[g == 34], z2[g == 34]), vcov = "iid", type = "twoStep");


ini11	<- g11gmm1$par;
ini12	<- g12gmm1$par;
ini13	<- g13gmm1$par;
ini14	<- g14gmm1$par;
ini21	<- g21gmm1$par;
ini22	<- g22gmm1$par;
ini23	<- g23gmm1$par;
ini24	<- g24gmm1$par;
ini31	<- g31gmm1$par;
ini32	<- g32gmm1$par;
ini33	<- g33gmm1$par;
ini34	<- g34gmm1$par;

g11el1	<- gel(g = y1[g == 11] ~ x[g == 11], x = cbind(z1[g == 11], z2[g == 11]), tet0 = ini11, smooth = FALSE, type = "EL");
g12el1	<- gel(g = y1[g == 12] ~ x[g == 12], x = cbind(z1[g == 12], z2[g == 12]), tet0 = ini12, smooth = FALSE, type = "EL");
g13el1	<- gel(g = y1[g == 13] ~ x[g == 13], x = cbind(z1[g == 13], z2[g == 13]), tet0 = ini13, smooth = FALSE, type = "EL");
g14el1	<- gel(g = y1[g == 14] ~ x[g == 14], x = cbind(z1[g == 14], z2[g == 14]), tet0 = ini14, smooth = FALSE, type = "EL");
g21el1	<- gel(g = y1[g == 21] ~ x[g == 21], x = cbind(z1[g == 21], z2[g == 21]), tet0 = ini21, smooth = FALSE, type = "EL");
g22el1	<- gel(g = y1[g == 22] ~ x[g == 22], x = cbind(z1[g == 22], z2[g == 22]), tet0 = ini22, smooth = FALSE, type = "EL");
g23el1	<- gel(g = y1[g == 23] ~ x[g == 23], x = cbind(z1[g == 23], z2[g == 23]), tet0 = ini23, smooth = FALSE, type = "EL");
g24el1	<- gel(g = y1[g == 24] ~ x[g == 24], x = cbind(z1[g == 24], z2[g == 24]), tet0 = ini24, smooth = FALSE, type = "EL");
g31el1	<- gel(g = y1[g == 31] ~ x[g == 31], x = cbind(z1[g == 31], z2[g == 31]), tet0 = ini31, smooth = FALSE, type = "EL");
g32el1	<- gel(g = y1[g == 32] ~ x[g == 32], x = cbind(z1[g == 32], z2[g == 32]), tet0 = ini32, smooth = FALSE, type = "EL");
g33el1	<- gel(g = y1[g == 33] ~ x[g == 33], x = cbind(z1[g == 33], z2[g == 33]), tet0 = ini33, smooth = FALSE, type = "EL");
g34el1	<- gel(g = y1[g == 34] ~ x[g == 34], x = cbind(z1[g == 34], z2[g == 34]), tet0 = ini34, smooth = FALSE, type = "EL");


el.probs	<- c(g11el1$pt*mean(g==11), g12el1$pt*mean(g==12), g13el1$pt*mean(g==13), g14el1$pt*mean(g==14), g21el1$pt*mean(g==21), g22el1$pt*mean(g==22), g23el1$pt*mean(g==23), g24el1$pt*mean(g==24), g31el1$pt*mean(g==31), g32el1$pt*mean(g==32), g33el1$pt*mean(g==33), g34el1$pt*mean(g==34) );

rm(g11el1, g12el1, g13el1, g14el1, g21el1, g22el1, g23el1, g24el1, g31el1, g32el1, g33el1, g34el1);

detach(data);


late11.y1.b	<- NULL;
late12.y1.b	<- NULL;
late13.y1.b	<- NULL;
late21.y1.b	<- NULL;
late22.y1.b	<- NULL;
late23.y1.b	<- NULL;

ate1.y1.b	<- NULL;
ate2.y1.b	<- NULL;
ate12.y1.b	<- NULL;
ate13.y1.b	<- NULL;

ulate1.y1.b	<- NULL;
ulate2.y1.b	<- NULL;
ulate12.y1.b	<- NULL;
ulate13.y1.b	<- NULL;

ate1.y1.b	<- NULL;
ate2.y1.b	<- NULL;
ate12.y1.b	<- NULL;
ate13.y1.b	<- NULL;

tot1.y1.b	<- NULL;
tot2.y1.b	<- NULL;
tot12.y1.b	<- NULL;
tot13.y1.b	<- NULL;

tnt1.y1.b	<- NULL;
tnt2.y1.b	<- NULL;
tnt12.y1.b	<- NULL;
tnt13.y1.b	<- NULL;

wlate11.y1.b	<- NULL;
wlate12.y1.b	<- NULL;
wlate21.y1.b	<- NULL;
wlate22.y1.b	<- NULL;

wate1.y1.b	<- NULL;
wate2.y1.b	<- NULL;
wate12.y1.b	<- NULL;
wate13.y1.b	<- NULL;

wate1.y1.b	<- NULL;
wate2.y1.b	<- NULL;
wate12.y1.b	<- NULL;
wate13.y1.b	<- NULL;

wtot1.y1.b	<- NULL;
wtot2.y1.b	<- NULL;
wtot12.y1.b	<- NULL;
wtot13.y1.b	<- NULL;

wtnt1.y1.b	<- NULL;
wtnt2.y1.b	<- NULL;
wtnt12.y1.b	<- NULL;
wtnt13.y1.b	<- NULL;

l1g11.y1.b	<- NULL;
l1g12.y1.b	<- NULL;
l1g13.y1.b	<- NULL;
l1g14.y1.b	<- NULL;
l1g21.y1.b	<- NULL;
l1g22.y1.b	<- NULL;
l1g23.y1.b	<- NULL;
l1g24.y1.b	<- NULL;
l1g31.y1.b	<- NULL;
l1g32.y1.b	<- NULL;
l1g33.y1.b	<- NULL;
l1g34.y1.b	<- NULL;

l2g11.y1.b	<- NULL;
l2g12.y1.b	<- NULL;
l2g13.y1.b	<- NULL;
l2g14.y1.b	<- NULL;
l2g21.y1.b	<- NULL;
l2g22.y1.b	<- NULL;
l2g23.y1.b	<- NULL;
l2g24.y1.b	<- NULL;
l2g31.y1.b	<- NULL;
l2g32.y1.b	<- NULL;
l2g33.y1.b	<- NULL;
l2g34.y1.b	<- NULL;

l12g11.y1.b	<- NULL;
l12g12.y1.b	<- NULL;
l12g13.y1.b	<- NULL;
l12g14.y1.b	<- NULL;
l12g21.y1.b	<- NULL;
l12g22.y1.b	<- NULL;
l12g23.y1.b	<- NULL;
l12g24.y1.b	<- NULL;
l12g31.y1.b	<- NULL;
l12g32.y1.b	<- NULL;
l12g33.y1.b	<- NULL;
l12g34.y1.b	<- NULL;

l13g11.y1.b	<- NULL;
l13g12.y1.b	<- NULL;
l13g13.y1.b	<- NULL;
l13g14.y1.b	<- NULL;
l13g21.y1.b	<- NULL;
l13g22.y1.b	<- NULL;
l13g23.y1.b	<- NULL;
l13g24.y1.b	<- NULL;
l13g31.y1.b	<- NULL;
l13g32.y1.b	<- NULL;
l13g33.y1.b	<- NULL;
l13g34.y1.b	<- NULL;


set.seed(888);


for (i in 1:B) {;

	bdata	<- as.data.frame(data[sample(n, b, replace = TRUE, prob = el.probs), ]);
	#  bdata  <- as.data.frame(data[sample(n, b, replace = FALSE), ]);
	attach(bdata);

 
	iv1	<- tsls(form1, ~ z1, data = bdata);
	iv2	<- tsls(form1, ~ z2, data = bdata);
	iv12	<- tsls(form1, ~ z1 + z2, data = bdata);
	gmm12	<- gmm(form1, x = cbind(z1,z2), vcov = "iid", type = "twoStep");


	# MODELS WITH COVARIATES;

	iv1g11	<- tsls(y1[g==11]~x[g==11], ~z1[g==11], data = bdata);
	iv1g12	<- tsls(y1[g==12]~x[g==12], ~z1[g==12], data = bdata);
	iv1g13	<- tsls(y1[g==13]~x[g==13], ~z1[g==13], data = bdata);
	iv1g14	<- tsls(y1[g==14]~x[g==14], ~z1[g==14], data = bdata);
	iv1g21	<- tsls(y1[g==21]~x[g==21], ~z1[g==21], data = bdata);
	iv1g22	<- tsls(y1[g==22]~x[g==22], ~z1[g==22], data = bdata);
	iv1g23	<- tsls(y1[g==23]~x[g==23], ~z1[g==23], data = bdata);
	iv1g24	<- tsls(y1[g==24]~x[g==24], ~z1[g==24], data = bdata);
	iv1g31	<- tsls(y1[g==31]~x[g==31], ~z1[g==31], data = bdata);
	iv1g32	<- tsls(y1[g==32]~x[g==32], ~z1[g==32], data = bdata);
	iv1g33	<- tsls(y1[g==33]~x[g==33], ~z1[g==33], data = bdata);
	iv1g34	<- tsls(y1[g==34]~x[g==34], ~z1[g==34], data = bdata);


	iv2g11	<- tsls(y1[g==11]~x[g==11], ~z2[g==11], data = bdata);
	iv2g12	<- tsls(y1[g==12]~x[g==12], ~z2[g==12], data = bdata);
	iv2g13	<- tsls(y1[g==13]~x[g==13], ~z2[g==13], data = bdata);
	iv2g14	<- tsls(y1[g==14]~x[g==14], ~z2[g==14], data = bdata);
	iv2g21	<- tsls(y1[g==21]~x[g==21], ~z2[g==21], data = bdata);
	iv2g22	<- tsls(y1[g==22]~x[g==22], ~z2[g==22], data = bdata);
	iv2g23	<- tsls(y1[g==23]~x[g==23], ~z2[g==23], data = bdata);
	iv2g24	<- tsls(y1[g==24]~x[g==24], ~z2[g==24], data = bdata);
	iv2g31	<- tsls(y1[g==31]~x[g==31], ~z2[g==31], data = bdata);
	iv2g32	<- tsls(y1[g==32]~x[g==32], ~z2[g==32], data = bdata);
	iv2g33	<- tsls(y1[g==33]~x[g==33], ~z2[g==33], data = bdata);
	iv2g34	<- tsls(y1[g==34]~x[g==34], ~z2[g==34], data = bdata);

	iv12g11	<- tsls(y1[g==11]~x[g==11], ~z1[g==11] + z2[g==11], data = bdata);
	iv12g12	<- tsls(y1[g==12]~x[g==12], ~z1[g==12] + z2[g==12], data = bdata);
	iv12g13	<- tsls(y1[g==13]~x[g==13], ~z1[g==13] + z2[g==13], data = bdata);
	iv12g14	<- tsls(y1[g==14]~x[g==14], ~z1[g==14] + z2[g==14], data = bdata);
	iv12g21	<- tsls(y1[g==21]~x[g==21], ~z1[g==21] + z2[g==21], data = bdata);
	iv12g22	<- tsls(y1[g==22]~x[g==22], ~z1[g==22] + z2[g==22], data = bdata);
	iv12g23	<- tsls(y1[g==23]~x[g==23], ~z1[g==23] + z2[g==23], data = bdata);
	iv12g24	<- tsls(y1[g==24]~x[g==24], ~z1[g==24] + z2[g==24], data = bdata);
	iv12g31	<- tsls(y1[g==31]~x[g==31], ~z1[g==31] + z2[g==31], data = bdata);
	iv12g32	<- tsls(y1[g==32]~x[g==32], ~z1[g==32] + z2[g==32], data = bdata);
	iv12g33	<- tsls(y1[g==33]~x[g==33], ~z1[g==33] + z2[g==33], data = bdata);
	iv12g34	<- tsls(y1[g==34]~x[g==34], ~z1[g==34] + z2[g==34], data = bdata);


	gmm12g11<- gmm(y1[g==11]~x[g==11], x = cbind(z1[g==11],z2[g==11]), vcov = "iid", type = "twoStep");
	gmm12g12<- gmm(y1[g==12]~x[g==12], x = cbind(z1[g==12],z2[g==12]), vcov = "iid", type = "twoStep");
	gmm12g13<- gmm(y1[g==13]~x[g==13], x = cbind(z1[g==13],z2[g==13]), vcov = "iid", type = "twoStep");
	gmm12g14<- gmm(y1[g==14]~x[g==14], x = cbind(z1[g==14],z2[g==14]), vcov = "iid", type = "twoStep");
	gmm12g21<- gmm(y1[g==21]~x[g==21], x = cbind(z1[g==21],z2[g==21]), vcov = "iid", type = "twoStep");
	gmm12g22<- gmm(y1[g==22]~x[g==22], x = cbind(z1[g==22],z2[g==22]), vcov = "iid", type = "twoStep");
	gmm12g23<- gmm(y1[g==23]~x[g==23], x = cbind(z1[g==23],z2[g==23]), vcov = "iid", type = "twoStep");
	gmm12g24<- gmm(y1[g==24]~x[g==24], x = cbind(z1[g==24],z2[g==24]), vcov = "iid", type = "twoStep");
	gmm12g31<- gmm(y1[g==31]~x[g==31], x = cbind(z1[g==31],z2[g==31]), vcov = "iid", type = "twoStep");
	gmm12g32<- gmm(y1[g==32]~x[g==32], x = cbind(z1[g==32],z2[g==32]), vcov = "iid", type = "twoStep");
	gmm12g33<- gmm(y1[g==33]~x[g==33], x = cbind(z1[g==33],z2[g==33]), vcov = "iid", type = "twoStep");
	gmm12g34<- gmm(y1[g==34]~x[g==34], x = cbind(z1[g==34],z2[g==34]), vcov = "iid", type = "twoStep");

	p11	<- mean(g==11);
	p12	<- mean(g==12);
	p13	<- mean(g==13);
	p14	<- mean(g==14);
	p21	<- mean(g==21);
	p22	<- mean(g==22);
	p23	<- mean(g==23);
	p24	<- mean(g==24);
	p31	<- mean(g==31);
	p32	<- mean(g==32);
	p33	<- mean(g==33);
	p34	<- mean(g==34);


	p11.x1	<- mean(g==11 & x==1) / mean(x==1);
	p12.x1	<- mean(g==12 & x==1) / mean(x==1);
	p13.x1	<- mean(g==13 & x==1) / mean(x==1);
	p14.x1	<- mean(g==14 & x==1) / mean(x==1);
	p21.x1	<- mean(g==21 & x==1) / mean(x==1);
	p22.x1	<- mean(g==22 & x==1) / mean(x==1);
	p23.x1	<- mean(g==23 & x==1) / mean(x==1);
	p24.x1	<- mean(g==24 & x==1) / mean(x==1);
	p31.x1	<- mean(g==31 & x==1) / mean(x==1);
	p32.x1	<- mean(g==32 & x==1) / mean(x==1);
	p33.x1	<- mean(g==33 & x==1) / mean(x==1);
	p34.x1	<- mean(g==34 & x==1) / mean(x==1);

	p11.x0	<- mean(g==11 & x==0) / mean(x==0);
	p12.x0	<- mean(g==12 & x==0) / mean(x==0);
	p13.x0	<- mean(g==13 & x==0) / mean(x==0);
	p14.x0	<- mean(g==14 & x==0) / mean(x==0);
	p21.x0	<- mean(g==21 & x==0) / mean(x==0);
	p22.x0	<- mean(g==22 & x==0) / mean(x==0);
	p23.x0	<- mean(g==23 & x==0) / mean(x==0);
	p24.x0	<- mean(g==24 & x==0) / mean(x==0);
	p31.x0	<- mean(g==31 & x==0) / mean(x==0);
	p32.x0	<- mean(g==32 & x==0) / mean(x==0);
	p33.x0	<- mean(g==33 & x==0) / mean(x==0);
	p34.x0	<- mean(g==34 & x==0) / mean(x==0);

	ov	<- p11*exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) + p12*exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) + p13*exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) + p14*exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) + p21*exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) + p22*exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) + p23*exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) + p24*exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) + p31*exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) + p32*exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) + p33*exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) + p34*exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n));
	ovg11	<- exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) / ov ;
	ovg12	<- exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) / ov ;
	ovg13	<- exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) / ov ;
	ovg14	<- exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) / ov ;
	ovg21	<- exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) / ov ;
	ovg22	<- exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) / ov ;
	ovg23	<- exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) / ov ;
	ovg24	<- exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) / ov ;
	ovg31	<- exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) / ov ;
	ovg32	<- exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) / ov ;
	ovg33	<- exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) / ov ;
	ovg34	<- exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n)) / ov ;



	w1g11	<- (sum(x[z1==1 & g==11])/sum(z1==1 & g==11) - sum(x[z1==0 & g==11])/sum(z1==0 & g==11)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g12	<- (sum(x[z1==1 & g==12])/sum(z1==1 & g==12) - sum(x[z1==0 & g==12])/sum(z1==0 & g==12)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g13	<- (sum(x[z1==1 & g==13])/sum(z1==1 & g==13) - sum(x[z1==0 & g==13])/sum(z1==0 & g==13)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g14	<- (sum(x[z1==1 & g==14])/sum(z1==1 & g==14) - sum(x[z1==0 & g==14])/sum(z1==0 & g==14)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g21	<- (sum(x[z1==1 & g==21])/sum(z1==1 & g==21) - sum(x[z1==0 & g==21])/sum(z1==0 & g==21)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g22	<- (sum(x[z1==1 & g==22])/sum(z1==1 & g==22) - sum(x[z1==0 & g==22])/sum(z1==0 & g==22)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g23	<- (sum(x[z1==1 & g==23])/sum(z1==1 & g==23) - sum(x[z1==0 & g==23])/sum(z1==0 & g==23)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g24	<- (sum(x[z1==1 & g==24])/sum(z1==1 & g==24) - sum(x[z1==0 & g==24])/sum(z1==0 & g==24)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g31	<- (sum(x[z1==1 & g==31])/sum(z1==1 & g==31) - sum(x[z1==0 & g==31])/sum(z1==0 & g==31)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g32	<- (sum(x[z1==1 & g==32])/sum(z1==1 & g==32) - sum(x[z1==0 & g==32])/sum(z1==0 & g==32)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g33	<- (sum(x[z1==1 & g==33])/sum(z1==1 & g==33) - sum(x[z1==0 & g==33])/sum(z1==0 & g==33)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g34	<- (sum(x[z1==1 & g==34])/sum(z1==1 & g==34) - sum(x[z1==0 & g==34])/sum(z1==0 & g==34)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));


	w2g11	<- (sum(x[z2==1 & g==11])/sum(z2==1 & g==11) - sum(x[z2==0 & g==11])/sum(z2==0 & g==11)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g12	<- (sum(x[z2==1 & g==12])/sum(z2==1 & g==12) - sum(x[z2==0 & g==12])/sum(z2==0 & g==12)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g13	<- (sum(x[z2==1 & g==13])/sum(z2==1 & g==13) - sum(x[z2==0 & g==13])/sum(z2==0 & g==13)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g14	<- (sum(x[z2==1 & g==14])/sum(z2==1 & g==14) - sum(x[z2==0 & g==14])/sum(z2==0 & g==14)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g21	<- (sum(x[z2==1 & g==21])/sum(z2==1 & g==21) - sum(x[z2==0 & g==21])/sum(z2==0 & g==21)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g22	<- (sum(x[z2==1 & g==22])/sum(z2==1 & g==22) - sum(x[z2==0 & g==22])/sum(z2==0 & g==22)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g23	<- (sum(x[z2==1 & g==23])/sum(z2==1 & g==23) - sum(x[z2==0 & g==23])/sum(z2==0 & g==23)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g24	<- (sum(x[z2==1 & g==24])/sum(z2==1 & g==24) - sum(x[z2==0 & g==24])/sum(z2==0 & g==24)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g31	<- (sum(x[z2==1 & g==31])/sum(z2==1 & g==31) - sum(x[z2==0 & g==31])/sum(z2==0 & g==31)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g32	<- (sum(x[z2==1 & g==32])/sum(z2==1 & g==32) - sum(x[z2==0 & g==32])/sum(z2==0 & g==32)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g33	<- (sum(x[z2==1 & g==33])/sum(z2==1 & g==33) - sum(x[z2==0 & g==33])/sum(z2==0 & g==33)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g34	<- (sum(x[z2==1 & g==34])/sum(z2==1 & g==34) - sum(x[z2==0 & g==34])/sum(z2==0 & g==34)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));


	l1g11	<- iv1g11$coeff[2];
	l1g12	<- iv1g12$coeff[2];
	l1g13	<- iv1g13$coeff[2];
	l1g14	<- iv1g14$coeff[2];
	l1g21	<- iv1g21$coeff[2];
	l1g22	<- iv1g22$coeff[2];
	l1g23	<- iv1g23$coeff[2];
	l1g24	<- iv1g24$coeff[2];
	l1g31	<- iv1g31$coeff[2];
	l1g32	<- iv1g32$coeff[2];
	l1g33	<- iv1g33$coeff[2];
	l1g34	<- iv1g34$coeff[2];
	
	l2g11	<- iv2g11$coeff[2];
	l2g12	<- iv2g12$coeff[2];
	l2g13	<- iv2g13$coeff[2];
	l2g14	<- iv2g14$coeff[2];
	l2g21	<- iv2g21$coeff[2];
	l2g22	<- iv2g22$coeff[2];
	l2g23	<- iv2g23$coeff[2];
	l2g24	<- iv2g24$coeff[2];
	l2g31	<- iv2g31$coeff[2];
	l2g32	<- iv2g32$coeff[2];
	l2g33	<- iv2g33$coeff[2];
	l2g34	<- iv2g34$coeff[2];

	l12g11	<- iv12g11$coeff[2];
	l12g12	<- iv12g12$coeff[2];
	l12g13	<- iv12g13$coeff[2];
	l12g14	<- iv12g14$coeff[2];
	l12g21	<- iv12g21$coeff[2];
	l12g22	<- iv12g22$coeff[2];
	l12g23	<- iv12g23$coeff[2];
	l12g24	<- iv12g24$coeff[2];
	l12g31	<- iv12g31$coeff[2];
	l12g32	<- iv12g32$coeff[2];
	l12g33	<- iv12g33$coeff[2];
	l12g34	<- iv12g34$coeff[2];

	l13g11	<- gmm12g11$par[2];
	l13g12	<- gmm12g12$par[2];
	l13g13	<- gmm12g13$par[2];
	l13g14	<- gmm12g14$par[2];
	l13g21	<- gmm12g21$par[2];
	l13g22	<- gmm12g22$par[2];
	l13g23	<- gmm12g23$par[2];
	l13g24	<- gmm12g24$par[2];
	l13g31	<- gmm12g31$par[2];
	l13g32	<- gmm12g32$par[2];
	l13g33	<- gmm12g33$par[2];
	l13g34	<- gmm12g34$par[2];

	late11.y1.b	<- c(late11.y1.b, (p11*w1g11*l1g11 + p12*w1g12*l1g12 + p13*w1g13*l1g13 +p14*w1g14*l1g14 +p21*w1g21*l1g21 +p22*w1g22*l1g22 +p23*w1g23*l1g23 +p24*w1g24*l1g24 +p31*w1g31*l1g31 +p32*w1g32*l1g32 +p33*w1g33*l1g33 +p34*w1g34*l1g34) /
				(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34) );
	late12.y1.b	<- c(late12.y1.b, (p11*w2g11*l1g11 + p12*w2g12*l1g12 + p13*w2g13*l1g13 +p14*w2g14*l1g14 +p21*w2g21*l1g21 +p22*w2g22*l1g22 +p23*w2g23*l1g23 +p24*w2g24*l1g24 +p31*w2g31	*l1g31 +p32*w2g32*l1g32 +p33*w2g33*l1g33 +p34*w2g34*l1g34) /
				(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34) );			
	late13.y1.b	<- c(late13.y1.b, (p11*w1g11*l13g11 + p12*w1g12*l13g12 + p13*w1g13*l13g13 +p14*w1g14*l13g14 +p21*w1g21*l13g21 +p22*w1g22*l13g22 +p23*w1g23*l13g23 +p24*w1g24*l13g24 +p31*w1g31*l13g31 +p32*w1g32*l13g32 +p33*w1g33*l13g33 +p34*w1g34*l13g34) /
				(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34) );
	late21.y1.b	<- c(late21.y1.b, (p11*w1g11*l2g11 + p12*w1g12*l2g12 + p13*w1g13*l2g13 +p14*w1g14*l2g14 +p21*w1g21*l2g21 +p22*w1g22*l2g22 +p23*w1g23*l2g23 +p24*w1g24*l2g24 +p31*w1g31*l2g31 +p32*w1g32*l2g32 +p33*w1g33*l2g33 +p34*w1g34*l2g34) /
				(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34) );
	late22.y1.b	<- c(late22.y1.b, (p11*w2g11*l2g11 + p12*w2g12*l2g12 + p13*w2g13*l2g13 +p14*w2g14*l2g14 +p21*w2g21*l2g21 +p22*w2g22*l2g22 +p23*w2g23*l2g23 +p24*w2g24*l2g24 +p31*w2g31*l2g31 +p32*w2g32*l2g32 +p33*w2g33*l2g33 +p34*w2g34*l2g34) /
				(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34) );			
	late23.y1.b	<- c(late23.y1.b, (p11*w2g11*l13g11 + p12*w2g12*l13g12 + p13*w2g13*l13g13 +p14*w2g14*l13g14 +p21*w2g21*l13g21 +p22*w2g22*l13g22 +p23*w2g23*l13g23 +p24*w2g24*l13g24 +p31*w2g31*l13g31 +p32*w2g32*l13g32 +p33*w2g33*l13g33 +p34*w2g34*l13g34) /
				(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34) );			


	ate1.y1.b	<- c(ate1.y1.b, p11*l1g11 + p12*l1g12 + p13*l1g13 +p14*l1g14 +p21*l1g21 +p22*l1g22 +p23*l1g23 +p24*l1g24 +p31*l1g31 +p32*l1g32 +p33*l1g33 +p34*l1g34 );
	ate2.y1.b	<- c(ate2.y1.b, p11*l2g11 + p12*l2g12 + p13*l2g13 +p14*l2g14 +p21*l2g21 +p22*l2g22 +p23*l2g23 +p24*l2g24 +p31*l2g31 +p32*l2g32 +p33*l2g33 +p34*l2g34 );
	ate12.y1.b	<- c(ate12.y1.b, p11*l12g11 + p12*l12g12 + p13*l12g13 +p14*l12g14 +p21*l12g21 +p22*l12g22 +p23*l12g23 +p24*l12g24 +p31*l12g31 +p32*l12g32 +p33*l12g33 +p34*l12g34 );
	ate13.y1.b	<- c(ate13.y1.b, p11*l13g11 + p12*l13g12 + p13*l13g13 +p14*l13g14 +p21*l13g21 +p22*l13g22 +p23*l13g23 +p24*l13g24 +p31*l13g31 +p32*l13g32 +p33*l13g33 +p34*l13g34 );


	ulate1.y1.b	<- c(ulate1.y1.b, iv1$coeff[2] );
	ulate2.y1.b	<- c(ulate2.y1.b, iv2$coeff[2] );
	ulate12.y1.b	<- c(ulate12.y1.b, iv12$coeff[2] );
	ulate13.y1.b	<- c(ulate13.y1.b, gmm12$par[2] );

	tot1.y1.b	<- c(tot1.y1.b, p11.x1*l1g11 + p12.x1*l1g12 + p13.x1*l1g13 +p14.x1*l1g14 +p21.x1*l1g21 +p22.x1*l1g22 +p23.x1*l1g23 +p24.x1*l1g24 +p31.x1*l1g31 +p32.x1*l1g32 +p33.x1*l1g33 +p34.x1*l1g34 );
	tot2.y1.b	<- c(tot2.y1.b, p11.x1*l2g11 + p12.x1*l2g12 + p13.x1*l2g13 +p14.x1*l2g14 +p21.x1*l2g21 +p22.x1*l2g22 +p23.x1*l2g23 +p24.x1*l2g24 +p31.x1*l2g31 +p32.x1*l2g32 +p33.x1*l2g33 +p34.x1*l2g34 );
	tot12.y1.b	<- c(tot12.y1.b, p11.x1*l12g11 + p12.x1*l12g12 + p13.x1*l12g13 +p14.x1*l12g14 +p21.x1*l12g21 +p22.x1*l12g22 +p23.x1*l12g23 +p24.x1*l12g24 +p31.x1*l12g31 +p32.x1*l12g32 +p33.x1*l12g33 +p34*l12g34 );
	tot13.y1.b	<- c(tot13.y1.b, p11.x1*l13g11 + p12.x1*l13g12 + p13.x1*l13g13 +p14.x1*l13g14 +p21.x1*l13g21 +p22.x1*l13g22 +p23.x1*l13g23 +p24.x1*l13g24 +p31.x1*l13g31 +p32.x1*l13g32 +p33.x1*l13g33 +p34*l13g34 );

	tnt1.y1.b	<- c(tnt1.y1.b, p11.x0*l1g11 + p12.x0*l1g12 + p13.x0*l1g13 +p14.x0*l1g14 +p21.x0*l1g21 +p22.x0*l1g22 +p23.x0*l1g23 +p24.x0*l1g24 +p31.x0*l1g31 +p32.x0*l1g32 +p33.x0*l1g33 +p34.x0*l1g34 );
	tnt2.y1.b	<- c(tnt2.y1.b, p11.x0*l2g11 + p12.x0*l2g12 + p13.x0*l2g13 +p14.x0*l2g14 +p21.x0*l2g21 +p22.x0*l2g22 +p23.x0*l2g23 +p24.x0*l2g24 +p31.x0*l2g31 +p32.x0*l2g32 +p33.x0*l2g33 +p34.x0*l2g34 );
	tnt12.y1.b	<- c(tnt12.y1.b, p11.x0*l12g11 + p12.x0*l12g12 + p13.x0*l12g13 +p14.x0*l12g14 +p21.x0*l12g21 +p22.x0*l12g22 +p23.x0*l12g23 +p24.x0*l12g24 +p31.x0*l12g31 +p32.x0*l12g32 +p33.x0*l12g33 +p34*l12g34 );
	tnt13.y1.b	<- c(tnt13.y1.b, p11.x0*l13g11 + p12.x0*l13g12 + p13.x0*l13g13 +p14.x0*l13g14 +p21.x0*l13g21 +p22.x0*l13g22 +p23.x0*l13g23 +p24.x0*l13g24 +p31.x0*l13g31 +p32.x0*l13g32 +p33.x0*l13g33 +p34*l13g34 );


	wlate11.y1.b	<- c(wlate11.y1.b, (p11*w1g11*ovg11*l1g11 + p12*w1g12*ovg12*l1g12 + p13*w1g13*ovg13*l1g13 +p14*w1g14*ovg14*l1g14 +p21*w1g21*ovg21*l1g21 +p22*w1g22*ovg22*l1g22 +p23*w1g23*ovg23*l1g23 +p24*w1g24*ovg24*l1g24 +p31*w1g31*ovg31*l1g31 +p32*w1g32*ovg32*l1g32 +p33*w1g33*ovg33*l1g33 +p34*w1g34*ovg34*l1g34) /
				(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34) );
	wlate12.y1.b	<- c(wlate12.y1.b, (p11*w2g11*ovg11*l1g11 + p12*w2g12*ovg12*l1g12 + p13*w2g13*ovg13*l1g13 +p14*w2g14*ovg14*l1g14 +p21*w2g21*ovg21*l1g21 +p22*w2g22*ovg22*l1g22 +p23*w2g23*ovg23*l1g23 +p24*w2g24*ovg24*l1g24 +p31*w2g31*ovg31*l1g31 +p32*w2g32*ovg32*l1g32 +p33*w2g33*ovg33*l1g33 +p34*w2g34*ovg34*l1g34) /
				(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34) );
	wlate21.y1.b	<- c(wlate21.y1.b, (p11*w1g11*ovg11*l2g11 + p12*w1g12*ovg12*l2g12 + p13*w1g13*ovg13*l2g13 +p14*w1g14*ovg14*l2g14 +p21*w1g21*ovg21*l2g21 +p22*w1g22*ovg22*l2g22 +p23*w1g23*ovg23*l2g23 +p24*w1g24*ovg24*l2g24 +p31*w1g31*ovg31*l2g31 +p32*w1g32*ovg32*l2g32 +p33*w1g33*ovg33*l2g33 +p34*w1g34*ovg34*l2g34) /
				(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34) );
	wlate22.y1.b	<- c(wlate22.y1.b, (p11*w2g11*ovg11*l2g11 + p12*w2g12*ovg12*l2g12 + p13*w2g13*ovg13*l2g13 +p14*w2g14*ovg14*l2g14 +p21*w2g21*ovg21*l2g21 +p22*w2g22*ovg22*l2g22 +p23*w2g23*ovg23*l2g23 +p24*w2g24*ovg24*l2g24 +p31*w2g31*ovg31*l2g31 +p32*w2g32*ovg32*l2g32 +p33*w2g33*ovg33*l2g33 +p34*w2g34*ovg34*l2g34) /
				(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34) );


	wate1.y1.b	<- c(wate1.y1.b, (p11*ovg11*l1g11 + p12*ovg12*l1g12 + p13*ovg13*l1g13 +p14*ovg14*l1g14 +p21*ovg21*l1g21 +p22*ovg22*l1g22 +p23*ovg23*l1g23 +p24*ovg24*l1g24 +p31*ovg31*l1g31 +p32*ovg32*l1g32 +p33*ovg33*l1g33 +p34*ovg34*l1g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );
	wate2.y1.b	<- c(wate2.y1.b, (p11*ovg11*l2g11 + p12*ovg12*l2g12 + p13*ovg13*l2g13 +p14*ovg14*l2g14 +p21*ovg21*l2g21 +p22*ovg22*l2g22 +p23*ovg23*l2g23 +p24*ovg24*l2g24 +p31*ovg31*l2g31 +p32*ovg32*l2g32 +p33*ovg33*l2g33 +p34*ovg34*l2g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );
	wate12.y1.b	<- c(wate12.y1.b, (p11*ovg11*l12g11 + p12*ovg12*l12g12 + p13*ovg13*l12g13 +p14*ovg14*l12g14 +p21*ovg21*l12g21 +p22*ovg22*l12g22 +p23*ovg23*l12g23 +p24*ovg24*l12g24 +p31*ovg31*l12g31 +p32*ovg32*l12g32 +p33*ovg33*l12g33 +p34*ovg34*l12g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );
	wate13.y1.b	<- c(wate13.y1.b, (p11*ovg11*l13g11 + p12*ovg12*l13g12 + p13*ovg13*l13g13 +p14*ovg14*l13g14 +p21*ovg21*l13g21 +p22*ovg22*l13g22 +p23*ovg23*l13g23 +p24*ovg24*l13g24 +p31*ovg31*l13g31 +p32*ovg32*l13g32 +p33*ovg33*l13g33 +p34*ovg34*l13g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );

	wtot1.y1.b	<- c(wtot1.y1.b, (p11.x1*ovg11*l1g11 + p12.x1*ovg12*l1g12 + p13.x1*ovg13*l1g13 +p14.x1*ovg14*l1g14 +p21.x1*ovg21*l1g21 +p22.x1*ovg22*l1g22 +p23.x1*ovg23*l1g23 +p24.x1*ovg24*l1g24 +p31.x1*ovg31*l1g31 +p32.x1*ovg32*l1g32 +p33.x1*ovg33*l1g33 +p34.x1*ovg34*l1g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );
	wtot2.y1.b	<- c(wtot2.y1.b, (p11.x1*ovg11*l2g11 + p12.x1*ovg12*l2g12 + p13.x1*ovg13*l2g13 +p14.x1*ovg14*l2g14 +p21.x1*ovg21*l2g21 +p22.x1*ovg22*l2g22 +p23.x1*ovg23*l2g23 +p24.x1*ovg24*l2g24 +p31.x1*ovg31*l2g31 +p32.x1*ovg32*l2g32 +p33.x1*ovg33*l2g33 +p34.x1*ovg34*l2g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );
	wtot12.y1.b	<- c(wtot12.y1.b, (p11.x1*ovg11*l12g11 + p12.x1*ovg12*l12g12 + p13.x1*ovg13*l12g13 +p14.x1*ovg14*l12g14 +p21.x1*ovg21*l12g21 +p22.x1*ovg22*l12g22 +p23.x1*ovg23*l12g23 +p24.x1*ovg24*l12g24 +p31.x1*ovg31*l12g31 +p32.x1*ovg32*l12g32 +p33.x1*ovg33*l12g33 +p34.x1*ovg34*l12g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );
	wtot13.y1.b	<- c(wtot13.y1.b, (p11.x1*ovg11*l13g11 + p12.x1*ovg12*l13g12 + p13.x1*ovg13*l13g13 +p14.x1*ovg14*l13g14 +p21.x1*ovg21*l13g21 +p22.x1*ovg22*l13g22 +p23.x1*ovg23*l13g23 +p24.x1*ovg24*l13g24 +p31.x1*ovg31*l13g31 +p32.x1*ovg32*l13g32 +p33.x1*ovg33*l13g33 +p34.x1*ovg34*l13g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );

	wtnt1.y1.b	<- c(wtnt1.y1.b, (p11.x0*ovg11*l1g11 + p12.x0*ovg12*l1g12 + p13.x0*ovg13*l1g13 +p14.x0*ovg14*l1g14 +p21.x0*ovg21*l1g21 +p22.x0*ovg22*l1g22 +p23.x0*ovg23*l1g23 +p24.x0*ovg24*l1g24 +p31.x0*ovg31*l1g31 +p32.x0*ovg32*l1g32 +p33.x0*ovg33*l1g33 +p34.x0*ovg34*l1g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
	wtnt2.y1.b	<- c(wtnt2.y1.b, (p11.x0*ovg11*l2g11 + p12.x0*ovg12*l2g12 + p13.x0*ovg13*l2g13 +p14.x0*ovg14*l2g14 +p21.x0*ovg21*l2g21 +p22.x0*ovg22*l2g22 +p23.x0*ovg23*l2g23 +p24.x0*ovg24*l2g24 +p31.x0*ovg31*l2g31 +p32.x0*ovg32*l2g32 +p33.x0*ovg33*l2g33 +p34.x0*ovg34*l2g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
	wtnt12.y1.b	<- c(wtnt12.y1.b, (p11.x0*ovg11*l12g11 + p12.x0*ovg12*l12g12 + p13.x0*ovg13*l12g13 +p14.x0*ovg14*l12g14 +p21.x0*ovg21*l12g21 +p22.x0*ovg22*l12g22 +p23.x0*ovg23*l12g23 +p24.x0*ovg24*l12g24 +p31.x0*ovg31*l12g31 +p32.x0*ovg32*l12g32 +p33.x0*ovg33*l12g33 +p34.x0*ovg34*l12g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
	wtnt13.y1.b	<- c(wtnt13.y1.b, (p11.x0*ovg11*l13g11 + p12.x0*ovg12*l13g12 + p13.x0*ovg13*l13g13 +p14.x0*ovg14*l13g14 +p21.x0*ovg21*l13g21 +p22.x0*ovg22*l13g22 +p23.x0*ovg23*l13g23 +p24.x0*ovg24*l13g24 +p31.x0*ovg31*l13g31 +p32.x0*ovg32*l13g32 +p33.x0*ovg33*l13g33 +p34.x0*ovg34*l13g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
 

	l1g11.y1.b	<- c(l1g11.y1.b, l1g11);
	l1g12.y1.b	<- c(l1g12.y1.b, l1g12);
	l1g13.y1.b	<- c(l1g13.y1.b, l1g13);
	l1g14.y1.b	<- c(l1g14.y1.b, l1g14);
	l1g21.y1.b	<- c(l1g21.y1.b, l1g21);
	l1g22.y1.b	<- c(l1g22.y1.b, l1g22);
	l1g23.y1.b	<- c(l1g23.y1.b, l1g23);
	l1g24.y1.b	<- c(l1g24.y1.b, l1g24);
	l1g31.y1.b	<- c(l1g31.y1.b, l1g31);
	l1g32.y1.b	<- c(l1g32.y1.b, l1g32);
	l1g33.y1.b	<- c(l1g33.y1.b, l1g33);
	l1g34.y1.b	<- c(l1g34.y1.b, l1g34);

	l2g11.y1.b	<- c(l2g11.y1.b, l2g11);
	l2g12.y1.b	<- c(l2g12.y1.b, l2g12);
	l2g13.y1.b	<- c(l2g13.y1.b, l2g13);
	l2g14.y1.b	<- c(l2g14.y1.b, l2g14);
	l2g21.y1.b	<- c(l2g21.y1.b, l2g21);
	l2g22.y1.b	<- c(l2g22.y1.b, l2g22);
	l2g23.y1.b	<- c(l2g23.y1.b, l2g23);
	l2g24.y1.b	<- c(l2g24.y1.b, l2g24);
	l2g31.y1.b	<- c(l2g31.y1.b, l2g31);
	l2g32.y1.b	<- c(l2g32.y1.b, l2g32);
	l2g33.y1.b	<- c(l2g33.y1.b, l2g33);
	l2g34.y1.b	<- c(l2g34.y1.b, l2g34);

	l12g11.y1.b	<- c(l12g11.y1.b, l12g11);
	l12g12.y1.b	<- c(l12g12.y1.b, l12g12);
	l12g13.y1.b	<- c(l12g13.y1.b, l12g13);
	l12g14.y1.b	<- c(l12g14.y1.b, l12g14);
	l12g21.y1.b	<- c(l12g21.y1.b, l12g21);
	l12g22.y1.b	<- c(l12g22.y1.b, l12g22);
	l12g23.y1.b	<- c(l12g23.y1.b, l12g23);
	l12g24.y1.b	<- c(l12g24.y1.b, l12g24);
	l12g31.y1.b	<- c(l12g31.y1.b, l12g31);
	l12g32.y1.b	<- c(l12g32.y1.b, l12g32);
	l12g33.y1.b	<- c(l12g33.y1.b, l12g33);
	l12g34.y1.b	<- c(l12g34.y1.b, l12g34);

	l13g11.y1.b	<- c(l13g11.y1.b, l13g11);
	l13g12.y1.b	<- c(l13g12.y1.b, l13g12);
	l13g13.y1.b	<- c(l13g13.y1.b, l13g13);
	l13g14.y1.b	<- c(l13g14.y1.b, l13g14);
	l13g21.y1.b	<- c(l13g21.y1.b, l13g21);
	l13g22.y1.b	<- c(l13g22.y1.b, l13g22);
	l13g23.y1.b	<- c(l13g23.y1.b, l13g23);
	l13g24.y1.b	<- c(l13g24.y1.b, l13g24);
	l13g31.y1.b	<- c(l13g31.y1.b, l13g31);
	l13g32.y1.b	<- c(l13g32.y1.b, l13g32);
	l13g33.y1.b	<- c(l13g33.y1.b, l13g33);
	l13g34.y1.b	<- c(l13g34.y1.b, l13g34);


	detach(bdata);

	};



#############################;
# LFP;
#############################;

attach(data);


# EL PROBABILITIES;

g11gmm1	<- gmm(g = y2[g == 11] ~ x[g == 11], x = cbind(z1[g == 11], z2[g == 11]), vcov = "iid", type = "twoStep");
g12gmm1	<- gmm(g = y2[g == 12] ~ x[g == 12], x = cbind(z1[g == 12], z2[g == 12]), vcov = "iid", type = "twoStep");
g13gmm1	<- gmm(g = y2[g == 13] ~ x[g == 13], x = cbind(z1[g == 13], z2[g == 13]), vcov = "iid", type = "twoStep");
g14gmm1	<- gmm(g = y2[g == 14] ~ x[g == 14], x = cbind(z1[g == 14], z2[g == 14]), vcov = "iid", type = "twoStep");
g21gmm1	<- gmm(g = y2[g == 21] ~ x[g == 21], x = cbind(z1[g == 21], z2[g == 21]), vcov = "iid", type = "twoStep");
g22gmm1	<- gmm(g = y2[g == 22] ~ x[g == 22], x = cbind(z1[g == 22], z2[g == 22]), vcov = "iid", type = "twoStep");
g23gmm1	<- gmm(g = y2[g == 23] ~ x[g == 23], x = cbind(z1[g == 23], z2[g == 23]), vcov = "iid", type = "twoStep");
g24gmm1	<- gmm(g = y2[g == 24] ~ x[g == 24], x = cbind(z1[g == 24], z2[g == 24]), vcov = "iid", type = "twoStep");
g31gmm1	<- gmm(g = y2[g == 31] ~ x[g == 31], x = cbind(z1[g == 31], z2[g == 31]), vcov = "iid", type = "twoStep");
g32gmm1	<- gmm(g = y2[g == 32] ~ x[g == 32], x = cbind(z1[g == 32], z2[g == 32]), vcov = "iid", type = "twoStep");
g33gmm1	<- gmm(g = y2[g == 33] ~ x[g == 33], x = cbind(z1[g == 33], z2[g == 33]), vcov = "iid", type = "twoStep");
g34gmm1	<- gmm(g = y2[g == 34] ~ x[g == 34], x = cbind(z1[g == 34], z2[g == 34]), vcov = "iid", type = "twoStep");


ini11	<- g11gmm1$par;
ini12	<- g12gmm1$par;
ini13	<- g13gmm1$par;
ini14	<- g14gmm1$par;
ini21	<- g21gmm1$par;
ini22	<- g22gmm1$par;
ini23	<- g23gmm1$par;
ini24	<- g24gmm1$par;
ini31	<- g31gmm1$par;
ini32	<- g32gmm1$par;
ini33	<- g33gmm1$par;
ini34	<- g34gmm1$par;

g11el1	<- gel(g = y2[g == 11] ~ x[g == 11], x = cbind(z1[g == 11], z2[g == 11]), tet0 = ini11, smooth = FALSE, type = "EL");
g12el1	<- gel(g = y2[g == 12] ~ x[g == 12], x = cbind(z1[g == 12], z2[g == 12]), tet0 = ini12, smooth = FALSE, type = "EL");
g13el1	<- gel(g = y2[g == 13] ~ x[g == 13], x = cbind(z1[g == 13], z2[g == 13]), tet0 = ini13, smooth = FALSE, type = "EL");
g14el1	<- gel(g = y2[g == 14] ~ x[g == 14], x = cbind(z1[g == 14], z2[g == 14]), tet0 = ini14, smooth = FALSE, type = "EL");
g21el1	<- gel(g = y2[g == 21] ~ x[g == 21], x = cbind(z1[g == 21], z2[g == 21]), tet0 = ini21, smooth = FALSE, type = "EL");
g22el1	<- gel(g = y2[g == 22] ~ x[g == 22], x = cbind(z1[g == 22], z2[g == 22]), tet0 = ini22, smooth = FALSE, type = "EL");
g23el1	<- gel(g = y2[g == 23] ~ x[g == 23], x = cbind(z1[g == 23], z2[g == 23]), tet0 = ini23, smooth = FALSE, type = "EL");
g24el1	<- gel(g = y2[g == 24] ~ x[g == 24], x = cbind(z1[g == 24], z2[g == 24]), tet0 = ini24, smooth = FALSE, type = "EL");
g31el1	<- gel(g = y2[g == 31] ~ x[g == 31], x = cbind(z1[g == 31], z2[g == 31]), tet0 = ini31, smooth = FALSE, type = "EL");
g32el1	<- gel(g = y2[g == 32] ~ x[g == 32], x = cbind(z1[g == 32], z2[g == 32]), tet0 = ini32, smooth = FALSE, type = "EL");
g33el1	<- gel(g = y2[g == 33] ~ x[g == 33], x = cbind(z1[g == 33], z2[g == 33]), tet0 = ini33, smooth = FALSE, type = "EL");
g34el1	<- gel(g = y2[g == 34] ~ x[g == 34], x = cbind(z1[g == 34], z2[g == 34]), tet0 = ini34, smooth = FALSE, type = "EL");


el.probs	<- c(g11el1$pt*mean(g==11), g12el1$pt*mean(g==12), g13el1$pt*mean(g==13), g14el1$pt*mean(g==14), g21el1$pt*mean(g==21), g22el1$pt*mean(g==22), g23el1$pt*mean(g==23), g24el1$pt*mean(g==24), g31el1$pt*mean(g==31), g32el1$pt*mean(g==32), g33el1$pt*mean(g==33), g34el1$pt*mean(g==34) );

rm(g11el1, g12el1, g13el1, g14el1, g21el1, g22el1, g23el1, g24el1, g31el1, g32el1, g33el1, g34el1);


detach(data);


late11.y2.b	<- NULL;
late12.y2.b	<- NULL;
late13.y2.b	<- NULL;
late21.y2.b	<- NULL;
late22.y2.b	<- NULL;
late23.y2.b	<- NULL;

ate1.y2.b	<- NULL;
ate2.y2.b	<- NULL;
ate12.y2.b	<- NULL;
ate13.y2.b	<- NULL;

ulate1.y2.b	<- NULL;
ulate2.y2.b	<- NULL;
ulate12.y2.b	<- NULL;
ulate13.y2.b	<- NULL;

ate1.y2.b	<- NULL;
ate2.y2.b	<- NULL;
ate12.y2.b	<- NULL;
ate13.y2.b	<- NULL;

tot1.y2.b	<- NULL;
tot2.y2.b	<- NULL;
tot12.y2.b	<- NULL;
tot13.y2.b	<- NULL;

tnt1.y2.b	<- NULL;
tnt2.y2.b	<- NULL;
tnt12.y2.b	<- NULL;
tnt13.y2.b	<- NULL;

wlate11.y2.b	<- NULL;
wlate12.y2.b	<- NULL;
wlate21.y2.b	<- NULL;
wlate22.y2.b	<- NULL;

wate1.y2.b	<- NULL;
wate2.y2.b	<- NULL;
wate12.y2.b	<- NULL;
wate13.y2.b	<- NULL;

wate1.y2.b	<- NULL;
wate2.y2.b	<- NULL;
wate12.y2.b	<- NULL;
wate13.y2.b	<- NULL;

wtot1.y2.b	<- NULL;
wtot2.y2.b	<- NULL;
wtot12.y2.b	<- NULL;
wtot13.y2.b	<- NULL;

wtnt1.y2.b	<- NULL;
wtnt2.y2.b	<- NULL;
wtnt12.y2.b	<- NULL;
wtnt13.y2.b	<- NULL;

l1g11.y2.b	<- NULL;
l1g12.y2.b	<- NULL;
l1g13.y2.b	<- NULL;
l1g14.y2.b	<- NULL;
l1g21.y2.b	<- NULL;
l1g22.y2.b	<- NULL;
l1g23.y2.b	<- NULL;
l1g24.y2.b	<- NULL;
l1g31.y2.b	<- NULL;
l1g32.y2.b	<- NULL;
l1g33.y2.b	<- NULL;
l1g34.y2.b	<- NULL;

l2g11.y2.b	<- NULL;
l2g12.y2.b	<- NULL;
l2g13.y2.b	<- NULL;
l2g14.y2.b	<- NULL;
l2g21.y2.b	<- NULL;
l2g22.y2.b	<- NULL;
l2g23.y2.b	<- NULL;
l2g24.y2.b	<- NULL;
l2g31.y2.b	<- NULL;
l2g32.y2.b	<- NULL;
l2g33.y2.b	<- NULL;
l2g34.y2.b	<- NULL;

l12g11.y2.b	<- NULL;
l12g12.y2.b	<- NULL;
l12g13.y2.b	<- NULL;
l12g14.y2.b	<- NULL;
l12g21.y2.b	<- NULL;
l12g22.y2.b	<- NULL;
l12g23.y2.b	<- NULL;
l12g24.y2.b	<- NULL;
l12g31.y2.b	<- NULL;
l12g32.y2.b	<- NULL;
l12g33.y2.b	<- NULL;
l12g34.y2.b	<- NULL;

l13g11.y2.b	<- NULL;
l13g12.y2.b	<- NULL;
l13g13.y2.b	<- NULL;
l13g14.y2.b	<- NULL;
l13g21.y2.b	<- NULL;
l13g22.y2.b	<- NULL;
l13g23.y2.b	<- NULL;
l13g24.y2.b	<- NULL;
l13g31.y2.b	<- NULL;
l13g32.y2.b	<- NULL;
l13g33.y2.b	<- NULL;
l13g34.y2.b	<- NULL;


set.seed(888);


for (i in 1:B) {;

	bdata	<- as.data.frame(data[sample(n, b, replace = TRUE, prob = el.probs), ]);
	#  bdata  <- as.data.frame(data[sample(n, b, replace = FALSE), ]);
	attach(bdata);

 
	iv1	<- tsls(form2, ~ z1, data = bdata);
	iv2	<- tsls(form2, ~ z2, data = bdata);
	iv12	<- tsls(form2, ~ z1 + z2, data = bdata);
	gmm12	<- gmm(form1, x = cbind(z1,z2), vcov = "iid", type = "twoStep");


	# MODELS WITH COVARIATES;

	iv1g11	<- tsls(y2[g==11]~x[g==11], ~z1[g==11], data = bdata);
	iv1g12	<- tsls(y2[g==12]~x[g==12], ~z1[g==12], data = bdata);
	iv1g13	<- tsls(y2[g==13]~x[g==13], ~z1[g==13], data = bdata);
	iv1g14	<- tsls(y2[g==14]~x[g==14], ~z1[g==14], data = bdata);
	iv1g21	<- tsls(y2[g==21]~x[g==21], ~z1[g==21], data = bdata);
	iv1g22	<- tsls(y2[g==22]~x[g==22], ~z1[g==22], data = bdata);
	iv1g23	<- tsls(y2[g==23]~x[g==23], ~z1[g==23], data = bdata);
	iv1g24	<- tsls(y2[g==24]~x[g==24], ~z1[g==24], data = bdata);
	iv1g31	<- tsls(y2[g==31]~x[g==31], ~z1[g==31], data = bdata);
	iv1g32	<- tsls(y2[g==32]~x[g==32], ~z1[g==32], data = bdata);
	iv1g33	<- tsls(y2[g==33]~x[g==33], ~z1[g==33], data = bdata);
	iv1g34	<- tsls(y2[g==34]~x[g==34], ~z1[g==34], data = bdata);


	iv2g11	<- tsls(y2[g==11]~x[g==11], ~z2[g==11], data = bdata);
	iv2g12	<- tsls(y2[g==12]~x[g==12], ~z2[g==12], data = bdata);
	iv2g13	<- tsls(y2[g==13]~x[g==13], ~z2[g==13], data = bdata);
	iv2g14	<- tsls(y2[g==14]~x[g==14], ~z2[g==14], data = bdata);
	iv2g21	<- tsls(y2[g==21]~x[g==21], ~z2[g==21], data = bdata);
	iv2g22	<- tsls(y2[g==22]~x[g==22], ~z2[g==22], data = bdata);
	iv2g23	<- tsls(y2[g==23]~x[g==23], ~z2[g==23], data = bdata);
	iv2g24	<- tsls(y2[g==24]~x[g==24], ~z2[g==24], data = bdata);
	iv2g31	<- tsls(y2[g==31]~x[g==31], ~z2[g==31], data = bdata);
	iv2g32	<- tsls(y2[g==32]~x[g==32], ~z2[g==32], data = bdata);
	iv2g33	<- tsls(y2[g==33]~x[g==33], ~z2[g==33], data = bdata);
	iv2g34	<- tsls(y2[g==34]~x[g==34], ~z2[g==34], data = bdata);

	iv12g11	<- tsls(y2[g==11]~x[g==11], ~z1[g==11] + z2[g==11], data = bdata);
	iv12g12	<- tsls(y2[g==12]~x[g==12], ~z1[g==12] + z2[g==12], data = bdata);
	iv12g13	<- tsls(y2[g==13]~x[g==13], ~z1[g==13] + z2[g==13], data = bdata);
	iv12g14	<- tsls(y2[g==14]~x[g==14], ~z1[g==14] + z2[g==14], data = bdata);
	iv12g21	<- tsls(y2[g==21]~x[g==21], ~z1[g==21] + z2[g==21], data = bdata);
	iv12g22	<- tsls(y2[g==22]~x[g==22], ~z1[g==22] + z2[g==22], data = bdata);
	iv12g23	<- tsls(y2[g==23]~x[g==23], ~z1[g==23] + z2[g==23], data = bdata);
	iv12g24	<- tsls(y2[g==24]~x[g==24], ~z1[g==24] + z2[g==24], data = bdata);
	iv12g31	<- tsls(y2[g==31]~x[g==31], ~z1[g==31] + z2[g==31], data = bdata);
	iv12g32	<- tsls(y2[g==32]~x[g==32], ~z1[g==32] + z2[g==32], data = bdata);
	iv12g33	<- tsls(y2[g==33]~x[g==33], ~z1[g==33] + z2[g==33], data = bdata);
	iv12g34	<- tsls(y2[g==34]~x[g==34], ~z1[g==34] + z2[g==34], data = bdata);


	gmm12g11<- gmm(y2[g==11]~x[g==11], x = cbind(z1[g==11],z2[g==11]), vcov = "iid", type = "twoStep");
	gmm12g12<- gmm(y2[g==12]~x[g==12], x = cbind(z1[g==12],z2[g==12]), vcov = "iid", type = "twoStep");
	gmm12g13<- gmm(y2[g==13]~x[g==13], x = cbind(z1[g==13],z2[g==13]), vcov = "iid", type = "twoStep");
	gmm12g14<- gmm(y2[g==14]~x[g==14], x = cbind(z1[g==14],z2[g==14]), vcov = "iid", type = "twoStep");
	gmm12g21<- gmm(y2[g==21]~x[g==21], x = cbind(z1[g==21],z2[g==21]), vcov = "iid", type = "twoStep");
	gmm12g22<- gmm(y2[g==22]~x[g==22], x = cbind(z1[g==22],z2[g==22]), vcov = "iid", type = "twoStep");
	gmm12g23<- gmm(y2[g==23]~x[g==23], x = cbind(z1[g==23],z2[g==23]), vcov = "iid", type = "twoStep");
	gmm12g24<- gmm(y2[g==24]~x[g==24], x = cbind(z1[g==24],z2[g==24]), vcov = "iid", type = "twoStep");
	gmm12g31<- gmm(y2[g==31]~x[g==31], x = cbind(z1[g==31],z2[g==31]), vcov = "iid", type = "twoStep");
	gmm12g32<- gmm(y2[g==32]~x[g==32], x = cbind(z1[g==32],z2[g==32]), vcov = "iid", type = "twoStep");
	gmm12g33<- gmm(y2[g==33]~x[g==33], x = cbind(z1[g==33],z2[g==33]), vcov = "iid", type = "twoStep");
	gmm12g34<- gmm(y2[g==34]~x[g==34], x = cbind(z1[g==34],z2[g==34]), vcov = "iid", type = "twoStep");

	p11	<- mean(g==11);
	p12	<- mean(g==12);
	p13	<- mean(g==13);
	p14	<- mean(g==14);
	p21	<- mean(g==21);
	p22	<- mean(g==22);
	p23	<- mean(g==23);
	p24	<- mean(g==24);
	p31	<- mean(g==31);
	p32	<- mean(g==32);
	p33	<- mean(g==33);
	p34	<- mean(g==34);

	p11.x1	<- mean(g==11 & x==1) / mean(x==1);
	p12.x1	<- mean(g==12 & x==1) / mean(x==1);
	p13.x1	<- mean(g==13 & x==1) / mean(x==1);
	p14.x1	<- mean(g==14 & x==1) / mean(x==1);
	p21.x1	<- mean(g==21 & x==1) / mean(x==1);
	p22.x1	<- mean(g==22 & x==1) / mean(x==1);
	p23.x1	<- mean(g==23 & x==1) / mean(x==1);
	p24.x1	<- mean(g==24 & x==1) / mean(x==1);
	p31.x1	<- mean(g==31 & x==1) / mean(x==1);
	p32.x1	<- mean(g==32 & x==1) / mean(x==1);
	p33.x1	<- mean(g==33 & x==1) / mean(x==1);
	p34.x1	<- mean(g==34 & x==1) / mean(x==1);

	p11.x0	<- mean(g==11 & x==0) / mean(x==0);
	p12.x0	<- mean(g==12 & x==0) / mean(x==0);
	p13.x0	<- mean(g==13 & x==0) / mean(x==0);
	p14.x0	<- mean(g==14 & x==0) / mean(x==0);
	p21.x0	<- mean(g==21 & x==0) / mean(x==0);
	p22.x0	<- mean(g==22 & x==0) / mean(x==0);
	p23.x0	<- mean(g==23 & x==0) / mean(x==0);
	p24.x0	<- mean(g==24 & x==0) / mean(x==0);
	p31.x0	<- mean(g==31 & x==0) / mean(x==0);
	p32.x0	<- mean(g==32 & x==0) / mean(x==0);
	p33.x0	<- mean(g==33 & x==0) / mean(x==0);
	p34.x0	<- mean(g==34 & x==0) / mean(x==0);

	ov	<- p11*exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) + p12*exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) + p13*exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) + p14*exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) + p21*exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) + p22*exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) + p23*exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) + p24*exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) + p31*exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) + p32*exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) + p33*exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) + p34*exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n));
	ovg11	<- exp(- 12*summary(gmm12g11)$j[1]/log(gmm12g11$n)) / ov ;
	ovg12	<- exp(- 12*summary(gmm12g12)$j[1]/log(gmm12g12$n)) / ov ;
	ovg13	<- exp(- 12*summary(gmm12g13)$j[1]/log(gmm12g13$n)) / ov ;
	ovg14	<- exp(- 12*summary(gmm12g14)$j[1]/log(gmm12g14$n)) / ov ;
	ovg21	<- exp(- 12*summary(gmm12g21)$j[1]/log(gmm12g21$n)) / ov ;
	ovg22	<- exp(- 12*summary(gmm12g22)$j[1]/log(gmm12g22$n)) / ov ;
	ovg23	<- exp(- 12*summary(gmm12g23)$j[1]/log(gmm12g23$n)) / ov ;
	ovg24	<- exp(- 12*summary(gmm12g24)$j[1]/log(gmm12g24$n)) / ov ;
	ovg31	<- exp(- 12*summary(gmm12g31)$j[1]/log(gmm12g31$n)) / ov ;
	ovg32	<- exp(- 12*summary(gmm12g32)$j[1]/log(gmm12g32$n)) / ov ;
	ovg33	<- exp(- 12*summary(gmm12g33)$j[1]/log(gmm12g33$n)) / ov ;
	ovg34	<- exp(- 12*summary(gmm12g34)$j[1]/log(gmm12g34$n)) / ov ;
 

	w1g11	<- (sum(x[z1==1 & g==11])/sum(z1==1 & g==11) - sum(x[z1==0 & g==11])/sum(z1==0 & g==11)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g12	<- (sum(x[z1==1 & g==12])/sum(z1==1 & g==12) - sum(x[z1==0 & g==12])/sum(z1==0 & g==12)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g13	<- (sum(x[z1==1 & g==13])/sum(z1==1 & g==13) - sum(x[z1==0 & g==13])/sum(z1==0 & g==13)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g14	<- (sum(x[z1==1 & g==14])/sum(z1==1 & g==14) - sum(x[z1==0 & g==14])/sum(z1==0 & g==14)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g21	<- (sum(x[z1==1 & g==21])/sum(z1==1 & g==21) - sum(x[z1==0 & g==21])/sum(z1==0 & g==21)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g22	<- (sum(x[z1==1 & g==22])/sum(z1==1 & g==22) - sum(x[z1==0 & g==22])/sum(z1==0 & g==22)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g23	<- (sum(x[z1==1 & g==23])/sum(z1==1 & g==23) - sum(x[z1==0 & g==23])/sum(z1==0 & g==23)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g24	<- (sum(x[z1==1 & g==24])/sum(z1==1 & g==24) - sum(x[z1==0 & g==24])/sum(z1==0 & g==24)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g31	<- (sum(x[z1==1 & g==31])/sum(z1==1 & g==31) - sum(x[z1==0 & g==31])/sum(z1==0 & g==31)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g32	<- (sum(x[z1==1 & g==32])/sum(z1==1 & g==32) - sum(x[z1==0 & g==32])/sum(z1==0 & g==32)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g33	<- (sum(x[z1==1 & g==33])/sum(z1==1 & g==33) - sum(x[z1==0 & g==33])/sum(z1==0 & g==33)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));
	w1g34	<- (sum(x[z1==1 & g==34])/sum(z1==1 & g==34) - sum(x[z1==0 & g==34])/sum(z1==0 & g==34)) / (sum(x[z1==1])/sum(z1==1) - sum(x[z1==0])/sum(z1==0));


	w2g11	<- (sum(x[z2==1 & g==11])/sum(z2==1 & g==11) - sum(x[z2==0 & g==11])/sum(z2==0 & g==11)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g12	<- (sum(x[z2==1 & g==12])/sum(z2==1 & g==12) - sum(x[z2==0 & g==12])/sum(z2==0 & g==12)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g13	<- (sum(x[z2==1 & g==13])/sum(z2==1 & g==13) - sum(x[z2==0 & g==13])/sum(z2==0 & g==13)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g14	<- (sum(x[z2==1 & g==14])/sum(z2==1 & g==14) - sum(x[z2==0 & g==14])/sum(z2==0 & g==14)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g21	<- (sum(x[z2==1 & g==21])/sum(z2==1 & g==21) - sum(x[z2==0 & g==21])/sum(z2==0 & g==21)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g22	<- (sum(x[z2==1 & g==22])/sum(z2==1 & g==22) - sum(x[z2==0 & g==22])/sum(z2==0 & g==22)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g23	<- (sum(x[z2==1 & g==23])/sum(z2==1 & g==23) - sum(x[z2==0 & g==23])/sum(z2==0 & g==23)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g24	<- (sum(x[z2==1 & g==24])/sum(z2==1 & g==24) - sum(x[z2==0 & g==24])/sum(z2==0 & g==24)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g31	<- (sum(x[z2==1 & g==31])/sum(z2==1 & g==31) - sum(x[z2==0 & g==31])/sum(z2==0 & g==31)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g32	<- (sum(x[z2==1 & g==32])/sum(z2==1 & g==32) - sum(x[z2==0 & g==32])/sum(z2==0 & g==32)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g33	<- (sum(x[z2==1 & g==33])/sum(z2==1 & g==33) - sum(x[z2==0 & g==33])/sum(z2==0 & g==33)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));
	w2g34	<- (sum(x[z2==1 & g==34])/sum(z2==1 & g==34) - sum(x[z2==0 & g==34])/sum(z2==0 & g==34)) / (sum(x[z2==1])/sum(z2==1) - sum(x[z2==0])/sum(z2==0));


	l1g11	<- iv1g11$coeff[2];
	l1g12	<- iv1g12$coeff[2];
	l1g13	<- iv1g13$coeff[2];
	l1g14	<- iv1g14$coeff[2];
	l1g21	<- iv1g21$coeff[2];
	l1g22	<- iv1g22$coeff[2];
	l1g23	<- iv1g23$coeff[2];
	l1g24	<- iv1g24$coeff[2];
	l1g31	<- iv1g31$coeff[2];
	l1g32	<- iv1g32$coeff[2];
	l1g33	<- iv1g33$coeff[2];
	l1g34	<- iv1g34$coeff[2];
	
	l2g11	<- iv2g11$coeff[2];
	l2g12	<- iv2g12$coeff[2];
	l2g13	<- iv2g13$coeff[2];
	l2g14	<- iv2g14$coeff[2];
	l2g21	<- iv2g21$coeff[2];
	l2g22	<- iv2g22$coeff[2];
	l2g23	<- iv2g23$coeff[2];
	l2g24	<- iv2g24$coeff[2];
	l2g31	<- iv2g31$coeff[2];
	l2g32	<- iv2g32$coeff[2];
	l2g33	<- iv2g33$coeff[2];
	l2g34	<- iv2g34$coeff[2];

	l12g11	<- iv12g11$coeff[2];
	l12g12	<- iv12g12$coeff[2];
	l12g13	<- iv12g13$coeff[2];
	l12g14	<- iv12g14$coeff[2];
	l12g21	<- iv12g21$coeff[2];
	l12g22	<- iv12g22$coeff[2];
	l12g23	<- iv12g23$coeff[2];
	l12g24	<- iv12g24$coeff[2];
	l12g31	<- iv12g31$coeff[2];
	l12g32	<- iv12g32$coeff[2];
	l12g33	<- iv12g33$coeff[2];
	l12g34	<- iv12g34$coeff[2];

	l13g11	<- gmm12g11$par[2];
	l13g12	<- gmm12g12$par[2];
	l13g13	<- gmm12g13$par[2];
	l13g14	<- gmm12g14$par[2];
	l13g21	<- gmm12g21$par[2];
	l13g22	<- gmm12g22$par[2];
	l13g23	<- gmm12g23$par[2];
	l13g24	<- gmm12g24$par[2];
	l13g31	<- gmm12g31$par[2];
	l13g32	<- gmm12g32$par[2];
	l13g33	<- gmm12g33$par[2];
	l13g34	<- gmm12g34$par[2];

	late11.y2.b	<- c(late11.y2.b, (p11*w1g11*l1g11 + p12*w1g12*l1g12 + p13*w1g13*l1g13 +p14*w1g14*l1g14 +p21*w1g21*l1g21 +p22*w1g22*l1g22 +p23*w1g23*l1g23 +p24*w1g24*l1g24 +p31*w1g31*l1g31 +p32*w1g32*l1g32 +p33*w1g33*l1g33 +p34*w1g34*l1g34) /
				(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34) );
	late12.y2.b	<- c(late12.y2.b, (p11*w2g11*l1g11 + p12*w2g12*l1g12 + p13*w2g13*l1g13 +p14*w2g14*l1g14 +p21*w2g21*l1g21 +p22*w2g22*l1g22 +p23*w2g23*l1g23 +p24*w2g24*l1g24 +p31*w2g31	*l1g31 +p32*w2g32*l1g32 +p33*w2g33*l1g33 +p34*w2g34*l1g34) /
				(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34) );			
	late13.y2.b	<- c(late13.y2.b, (p11*w1g11*l13g11 + p12*w1g12*l13g12 + p13*w1g13*l13g13 +p14*w1g14*l13g14 +p21*w1g21*l13g21 +p22*w1g22*l13g22 +p23*w1g23*l13g23 +p24*w1g24*l13g24 +p31*w1g31*l13g31 +p32*w1g32*l13g32 +p33*w1g33*l13g33 +p34*w1g34*l13g34) /
				(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34) );
	late21.y2.b	<- c(late21.y2.b, (p11*w1g11*l2g11 + p12*w1g12*l2g12 + p13*w1g13*l2g13 +p14*w1g14*l2g14 +p21*w1g21*l2g21 +p22*w1g22*l2g22 +p23*w1g23*l2g23 +p24*w1g24*l2g24 +p31*w1g31*l2g31 +p32*w1g32*l2g32 +p33*w1g33*l2g33 +p34*w1g34*l2g34) /
				(p11*w1g11 + p12*w1g12 + p13*w1g13 +p14*w1g14 +p21*w1g21 +p22*w1g22 +p23*w1g23 +p24*w1g24 +p31*w1g31 +p32*w1g32 +p33*w1g33 +p34*w1g34) );
	late22.y2.b	<- c(late22.y2.b, (p11*w2g11*l2g11 + p12*w2g12*l2g12 + p13*w2g13*l2g13 +p14*w2g14*l2g14 +p21*w2g21*l2g21 +p22*w2g22*l2g22 +p23*w2g23*l2g23 +p24*w2g24*l2g24 +p31*w2g31*l2g31 +p32*w2g32*l2g32 +p33*w2g33*l2g33 +p34*w2g34*l2g34) /
				(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34) );			
	late23.y2.b	<- c(late23.y2.b, (p11*w2g11*l13g11 + p12*w2g12*l13g12 + p13*w2g13*l13g13 +p14*w2g14*l13g14 +p21*w2g21*l13g21 +p22*w2g22*l13g22 +p23*w2g23*l13g23 +p24*w2g24*l13g24 +p31*w2g31*l13g31 +p32*w2g32*l13g32 +p33*w2g33*l13g33 +p34*w2g34*l13g34) /
				(p11*w2g11 + p12*w2g12 + p13*w2g13 +p14*w2g14 +p21*w2g21 +p22*w2g22 +p23*w2g23 +p24*w2g24 +p31*w2g31 +p32*w2g32 +p33*w2g33 +p34*w2g34) );			


	ate1.y2.b	<- c(ate1.y2.b, p11*l1g11 + p12*l1g12 + p13*l1g13 +p14*l1g14 +p21*l1g21 +p22*l1g22 +p23*l1g23 +p24*l1g24 +p31*l1g31 +p32*l1g32 +p33*l1g33 +p34*l1g34 );
	ate2.y2.b	<- c(ate2.y2.b, p11*l2g11 + p12*l2g12 + p13*l2g13 +p14*l2g14 +p21*l2g21 +p22*l2g22 +p23*l2g23 +p24*l2g24 +p31*l2g31 +p32*l2g32 +p33*l2g33 +p34*l2g34 );
	ate12.y2.b	<- c(ate12.y2.b, p11*l12g11 + p12*l12g12 + p13*l12g13 +p14*l12g14 +p21*l12g21 +p22*l12g22 +p23*l12g23 +p24*l12g24 +p31*l12g31 +p32*l12g32 +p33*l12g33 +p34*l12g34 );
	ate13.y2.b	<- c(ate13.y2.b, p11*l13g11 + p12*l13g12 + p13*l13g13 +p14*l13g14 +p21*l13g21 +p22*l13g22 +p23*l13g23 +p24*l13g24 +p31*l13g31 +p32*l13g32 +p33*l13g33 +p34*l13g34 );


	ulate1.y2.b	<- c(ulate1.y2.b, iv1$coeff[2] );
	ulate2.y2.b	<- c(ulate2.y2.b, iv2$coeff[2] );
	ulate12.y2.b	<- c(ulate12.y2.b, iv12$coeff[2] );
	ulate13.y2.b	<- c(ulate13.y2.b, gmm12$par[2] );

	tot1.y2.b	<- c(tot1.y2.b, p11.x1*l1g11 + p12.x1*l1g12 + p13.x1*l1g13 +p14.x1*l1g14 +p21.x1*l1g21 +p22.x1*l1g22 +p23.x1*l1g23 +p24.x1*l1g24 +p31.x1*l1g31 +p32.x1*l1g32 +p33.x1*l1g33 +p34.x1*l1g34 );
	tot2.y2.b	<- c(tot2.y2.b, p11.x1*l2g11 + p12.x1*l2g12 + p13.x1*l2g13 +p14.x1*l2g14 +p21.x1*l2g21 +p22.x1*l2g22 +p23.x1*l2g23 +p24.x1*l2g24 +p31.x1*l2g31 +p32.x1*l2g32 +p33.x1*l2g33 +p34.x1*l2g34 );
	tot12.y2.b	<- c(tot12.y2.b, p11.x1*l12g11 + p12.x1*l12g12 + p13.x1*l12g13 +p14.x1*l12g14 +p21.x1*l12g21 +p22.x1*l12g22 +p23.x1*l12g23 +p24.x1*l12g24 +p31.x1*l12g31 +p32.x1*l12g32 +p33.x1*l12g33 +p34*l12g34 );
	tot13.y2.b	<- c(tot13.y2.b, p11.x1*l13g11 + p12.x1*l13g12 + p13.x1*l13g13 +p14.x1*l13g14 +p21.x1*l13g21 +p22.x1*l13g22 +p23.x1*l13g23 +p24.x1*l13g24 +p31.x1*l13g31 +p32.x1*l13g32 +p33.x1*l13g33 +p34*l13g34 );

	tnt1.y2.b	<- c(tnt1.y2.b, p11.x0*l1g11 + p12.x0*l1g12 + p13.x0*l1g13 +p14.x0*l1g14 +p21.x0*l1g21 +p22.x0*l1g22 +p23.x0*l1g23 +p24.x0*l1g24 +p31.x0*l1g31 +p32.x0*l1g32 +p33.x0*l1g33 +p34.x0*l1g34 );
	tnt2.y2.b	<- c(tnt2.y2.b, p11.x0*l2g11 + p12.x0*l2g12 + p13.x0*l2g13 +p14.x0*l2g14 +p21.x0*l2g21 +p22.x0*l2g22 +p23.x0*l2g23 +p24.x0*l2g24 +p31.x0*l2g31 +p32.x0*l2g32 +p33.x0*l2g33 +p34.x0*l2g34 );
	tnt12.y2.b	<- c(tnt12.y2.b, p11.x0*l12g11 + p12.x0*l12g12 + p13.x0*l12g13 +p14.x0*l12g14 +p21.x0*l12g21 +p22.x0*l12g22 +p23.x0*l12g23 +p24.x0*l12g24 +p31.x0*l12g31 +p32.x0*l12g32 +p33.x0*l12g33 +p34*l12g34 );
	tnt13.y2.b	<- c(tnt13.y2.b, p11.x0*l13g11 + p12.x0*l13g12 + p13.x0*l13g13 +p14.x0*l13g14 +p21.x0*l13g21 +p22.x0*l13g22 +p23.x0*l13g23 +p24.x0*l13g24 +p31.x0*l13g31 +p32.x0*l13g32 +p33.x0*l13g33 +p34*l13g34 );


	wlate11.y2.b	<- c(wlate11.y2.b, (p11*w1g11*ovg11*l1g11 + p12*w1g12*ovg12*l1g12 + p13*w1g13*ovg13*l1g13 +p14*w1g14*ovg14*l1g14 +p21*w1g21*ovg21*l1g21 +p22*w1g22*ovg22*l1g22 +p23*w1g23*ovg23*l1g23 +p24*w1g24*ovg24*l1g24 +p31*w1g31*ovg31*l1g31 +p32*w1g32*ovg32*l1g32 +p33*w1g33*ovg33*l1g33 +p34*w1g34*ovg34*l1g34) /
				(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34) );
	wlate12.y2.b	<- c(wlate12.y2.b, (p11*w2g11*ovg11*l1g11 + p12*w2g12*ovg12*l1g12 + p13*w2g13*ovg13*l1g13 +p14*w2g14*ovg14*l1g14 +p21*w2g21*ovg21*l1g21 +p22*w2g22*ovg22*l1g22 +p23*w2g23*ovg23*l1g23 +p24*w2g24*ovg24*l1g24 +p31*w2g31*ovg31*l1g31 +p32*w2g32*ovg32*l1g32 +p33*w2g33*ovg33*l1g33 +p34*w2g34*ovg34*l1g34) /
				(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34) );
	wlate21.y2.b	<- c(wlate21.y2.b, (p11*w1g11*ovg11*l2g11 + p12*w1g12*ovg12*l2g12 + p13*w1g13*ovg13*l2g13 +p14*w1g14*ovg14*l2g14 +p21*w1g21*ovg21*l2g21 +p22*w1g22*ovg22*l2g22 +p23*w1g23*ovg23*l2g23 +p24*w1g24*ovg24*l2g24 +p31*w1g31*ovg31*l2g31 +p32*w1g32*ovg32*l2g32 +p33*w1g33*ovg33*l2g33 +p34*w1g34*ovg34*l2g34) /
				(p11*w1g11*ovg11 + p12*w1g12*ovg12 + p13*w1g13*ovg13 +p14*w1g14*ovg14 +p21*w1g21*ovg21 +p22*w1g22*ovg22 +p23*w1g23*ovg23 +p24*w1g24*ovg24 +p31*w1g31*ovg31 +p32*w1g32*ovg32 +p33*w1g33*ovg33 +p34*w1g34*ovg34) );
	wlate22.y2.b	<- c(wlate22.y2.b, (p11*w2g11*ovg11*l2g11 + p12*w2g12*ovg12*l2g12 + p13*w2g13*ovg13*l2g13 +p14*w2g14*ovg14*l2g14 +p21*w2g21*ovg21*l2g21 +p22*w2g22*ovg22*l2g22 +p23*w2g23*ovg23*l2g23 +p24*w2g24*ovg24*l2g24 +p31*w2g31*ovg31*l2g31 +p32*w2g32*ovg32*l2g32 +p33*w2g33*ovg33*l2g33 +p34*w2g34*ovg34*l2g34) /
				(p11*w2g11*ovg11 + p12*w2g12*ovg12 + p13*w2g13*ovg13 +p14*w2g14*ovg14 +p21*w2g21*ovg21 +p22*w2g22*ovg22 +p23*w2g23*ovg23 +p24*w2g24*ovg24 +p31*w2g31*ovg31 +p32*w2g32*ovg32 +p33*w2g33*ovg33 +p34*w2g34*ovg34) );


	wate1.y2.b	<- c(wate1.y2.b, (p11*ovg11*l1g11 + p12*ovg12*l1g12 + p13*ovg13*l1g13 +p14*ovg14*l1g14 +p21*ovg21*l1g21 +p22*ovg22*l1g22 +p23*ovg23*l1g23 +p24*ovg24*l1g24 +p31*ovg31*l1g31 +p32*ovg32*l1g32 +p33*ovg33*l1g33 +p34*ovg34*l1g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );
	wate2.y2.b	<- c(wate2.y2.b, (p11*ovg11*l2g11 + p12*ovg12*l2g12 + p13*ovg13*l2g13 +p14*ovg14*l2g14 +p21*ovg21*l2g21 +p22*ovg22*l2g22 +p23*ovg23*l2g23 +p24*ovg24*l2g24 +p31*ovg31*l2g31 +p32*ovg32*l2g32 +p33*ovg33*l2g33 +p34*ovg34*l2g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );
	wate12.y2.b	<- c(wate12.y2.b, (p11*ovg11*l12g11 + p12*ovg12*l12g12 + p13*ovg13*l12g13 +p14*ovg14*l12g14 +p21*ovg21*l12g21 +p22*ovg22*l12g22 +p23*ovg23*l12g23 +p24*ovg24*l12g24 +p31*ovg31*l12g31 +p32*ovg32*l12g32 +p33*ovg33*l12g33 +p34*ovg34*l12g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );
	wate13.y2.b	<- c(wate13.y2.b, (p11*ovg11*l13g11 + p12*ovg12*l13g12 + p13*ovg13*l13g13 +p14*ovg14*l13g14 +p21*ovg21*l13g21 +p22*ovg22*l13g22 +p23*ovg23*l13g23 +p24*ovg24*l13g24 +p31*ovg31*l13g31 +p32*ovg32*l13g32 +p33*ovg33*l13g33 +p34*ovg34*l13g34) /
				(p11*ovg11 + p12*ovg12 + p13*ovg13 +p14*ovg14 +p21*ovg21 +p22*ovg22 +p23*ovg23 +p24*ovg24 +p31*ovg31 +p32*ovg32 +p33*ovg33 +p34*ovg34) );

	wtot1.y2.b	<- c(wtot1.y2.b, (p11.x1*ovg11*l1g11 + p12.x1*ovg12*l1g12 + p13.x1*ovg13*l1g13 +p14.x1*ovg14*l1g14 +p21.x1*ovg21*l1g21 +p22.x1*ovg22*l1g22 +p23.x1*ovg23*l1g23 +p24.x1*ovg24*l1g24 +p31.x1*ovg31*l1g31 +p32.x1*ovg32*l1g32 +p33.x1*ovg33*l1g33 +p34.x1*ovg34*l1g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );
	wtot2.y2.b	<- c(wtot2.y2.b, (p11.x1*ovg11*l2g11 + p12.x1*ovg12*l2g12 + p13.x1*ovg13*l2g13 +p14.x1*ovg14*l2g14 +p21.x1*ovg21*l2g21 +p22.x1*ovg22*l2g22 +p23.x1*ovg23*l2g23 +p24.x1*ovg24*l2g24 +p31.x1*ovg31*l2g31 +p32.x1*ovg32*l2g32 +p33.x1*ovg33*l2g33 +p34.x1*ovg34*l2g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );
	wtot12.y2.b	<- c(wtot12.y2.b, (p11.x1*ovg11*l12g11 + p12.x1*ovg12*l12g12 + p13.x1*ovg13*l12g13 +p14.x1*ovg14*l12g14 +p21.x1*ovg21*l12g21 +p22.x1*ovg22*l12g22 +p23.x1*ovg23*l12g23 +p24.x1*ovg24*l12g24 +p31.x1*ovg31*l12g31 +p32.x1*ovg32*l12g32 +p33.x1*ovg33*l12g33 +p34.x1*ovg34*l12g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );
	wtot13.y2.b	<- c(wtot13.y2.b, (p11.x1*ovg11*l13g11 + p12.x1*ovg12*l13g12 + p13.x1*ovg13*l13g13 +p14.x1*ovg14*l13g14 +p21.x1*ovg21*l13g21 +p22.x1*ovg22*l13g22 +p23.x1*ovg23*l13g23 +p24.x1*ovg24*l13g24 +p31.x1*ovg31*l13g31 +p32.x1*ovg32*l13g32 +p33.x1*ovg33*l13g33 +p34.x1*ovg34*l13g34) /
				(p11.x1*ovg11 + p12.x1*ovg12 + p13.x1*ovg13 +p14.x1*ovg14 +p21.x1*ovg21 +p22.x1*ovg22 +p23.x1*ovg23 +p24.x1*ovg24 +p31.x1*ovg31 +p32.x1*ovg32 +p33.x1*ovg33 +p34.x1*ovg34) );

	wtnt1.y2.b	<- c(wtnt1.y2.b, (p11.x0*ovg11*l1g11 + p12.x0*ovg12*l1g12 + p13.x0*ovg13*l1g13 +p14.x0*ovg14*l1g14 +p21.x0*ovg21*l1g21 +p22.x0*ovg22*l1g22 +p23.x0*ovg23*l1g23 +p24.x0*ovg24*l1g24 +p31.x0*ovg31*l1g31 +p32.x0*ovg32*l1g32 +p33.x0*ovg33*l1g33 +p34.x0*ovg34*l1g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
	wtnt2.y2.b	<- c(wtnt2.y2.b, (p11.x0*ovg11*l2g11 + p12.x0*ovg12*l2g12 + p13.x0*ovg13*l2g13 +p14.x0*ovg14*l2g14 +p21.x0*ovg21*l2g21 +p22.x0*ovg22*l2g22 +p23.x0*ovg23*l2g23 +p24.x0*ovg24*l2g24 +p31.x0*ovg31*l2g31 +p32.x0*ovg32*l2g32 +p33.x0*ovg33*l2g33 +p34.x0*ovg34*l2g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
	wtnt12.y2.b	<- c(wtnt12.y2.b, (p11.x0*ovg11*l12g11 + p12.x0*ovg12*l12g12 + p13.x0*ovg13*l12g13 +p14.x0*ovg14*l12g14 +p21.x0*ovg21*l12g21 +p22.x0*ovg22*l12g22 +p23.x0*ovg23*l12g23 +p24.x0*ovg24*l12g24 +p31.x0*ovg31*l12g31 +p32.x0*ovg32*l12g32 +p33.x0*ovg33*l12g33 +p34.x0*ovg34*l12g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
	wtnt13.y2.b	<- c(wtnt13.y2.b, (p11.x0*ovg11*l13g11 + p12.x0*ovg12*l13g12 + p13.x0*ovg13*l13g13 +p14.x0*ovg14*l13g14 +p21.x0*ovg21*l13g21 +p22.x0*ovg22*l13g22 +p23.x0*ovg23*l13g23 +p24.x0*ovg24*l13g24 +p31.x0*ovg31*l13g31 +p32.x0*ovg32*l13g32 +p33.x0*ovg33*l13g33 +p34.x0*ovg34*l13g34) /
				(p11.x0*ovg11 + p12.x0*ovg12 + p13.x0*ovg13 +p14.x0*ovg14 +p21.x0*ovg21 +p22.x0*ovg22 +p23.x0*ovg23 +p24.x0*ovg24 +p31.x0*ovg31 +p32.x0*ovg32 +p33.x0*ovg33 +p34.x0*ovg34) );
 

	l1g11.y2.b	<- c(l1g11.y2.b, l1g11);
	l1g12.y2.b	<- c(l1g12.y2.b, l1g12);
	l1g13.y2.b	<- c(l1g13.y2.b, l1g13);
	l1g14.y2.b	<- c(l1g14.y2.b, l1g14);
	l1g21.y2.b	<- c(l1g21.y2.b, l1g21);
	l1g22.y2.b	<- c(l1g22.y2.b, l1g22);
	l1g23.y2.b	<- c(l1g23.y2.b, l1g23);
	l1g24.y2.b	<- c(l1g24.y2.b, l1g24);
	l1g31.y2.b	<- c(l1g31.y2.b, l1g31);
	l1g32.y2.b	<- c(l1g32.y2.b, l1g32);
	l1g33.y2.b	<- c(l1g33.y2.b, l1g33);
	l1g34.y2.b	<- c(l1g34.y2.b, l1g34);

	l2g11.y2.b	<- c(l2g11.y2.b, l2g11);
	l2g12.y2.b	<- c(l2g12.y2.b, l2g12);
	l2g13.y2.b	<- c(l2g13.y2.b, l2g13);
	l2g14.y2.b	<- c(l2g14.y2.b, l2g14);
	l2g21.y2.b	<- c(l2g21.y2.b, l2g21);
	l2g22.y2.b	<- c(l2g22.y2.b, l2g22);
	l2g23.y2.b	<- c(l2g23.y2.b, l2g23);
	l2g24.y2.b	<- c(l2g24.y2.b, l2g24);
	l2g31.y2.b	<- c(l2g31.y2.b, l2g31);
	l2g32.y2.b	<- c(l2g32.y2.b, l2g32);
	l2g33.y2.b	<- c(l2g33.y2.b, l2g33);
	l2g34.y2.b	<- c(l2g34.y2.b, l2g34);

	l12g11.y2.b	<- c(l12g11.y2.b, l12g11);
	l12g12.y2.b	<- c(l12g12.y2.b, l12g12);
	l12g13.y2.b	<- c(l12g13.y2.b, l12g13);
	l12g14.y2.b	<- c(l12g14.y2.b, l12g14);
	l12g21.y2.b	<- c(l12g21.y2.b, l12g21);
	l12g22.y2.b	<- c(l12g22.y2.b, l12g22);
	l12g23.y2.b	<- c(l12g23.y2.b, l12g23);
	l12g24.y2.b	<- c(l12g24.y2.b, l12g24);
	l12g31.y2.b	<- c(l12g31.y2.b, l12g31);
	l12g32.y2.b	<- c(l12g32.y2.b, l12g32);
	l12g33.y2.b	<- c(l12g33.y2.b, l12g33);
	l12g34.y2.b	<- c(l12g34.y2.b, l12g34);

	l13g11.y2.b	<- c(l13g11.y2.b, l13g11);
	l13g12.y2.b	<- c(l13g12.y2.b, l13g12);
	l13g13.y2.b	<- c(l13g13.y2.b, l13g13);
	l13g14.y2.b	<- c(l13g14.y2.b, l13g14);
	l13g21.y2.b	<- c(l13g21.y2.b, l13g21);
	l13g22.y2.b	<- c(l13g22.y2.b, l13g22);
	l13g23.y2.b	<- c(l13g23.y2.b, l13g23);
	l13g24.y2.b	<- c(l13g24.y2.b, l13g24);
	l13g31.y2.b	<- c(l13g31.y2.b, l13g31);
	l13g32.y2.b	<- c(l13g32.y2.b, l13g32);
	l13g33.y2.b	<- c(l13g33.y2.b, l13g33);
	l13g34.y2.b	<- c(l13g34.y2.b, l13g34);


	detach(bdata);

	};






################################################################################################;
#				3 - OVERIDENTIFICATION TESTS;
################################################################################################;

attach(data);

form1	<- y1 ~ x;

gmm12	<- gmm(form1, x = cbind(z1,z2), vcov = "iid", type = "twoStep");
gmm12g11<- gmm(y1[g==11]~x[g==11], x = cbind(z1[g==11],z2[g==11]), vcov = "iid", type = "twoStep");
gmm12g12<- gmm(y1[g==12]~x[g==12], x = cbind(z1[g==12],z2[g==12]), vcov = "iid", type = "twoStep");
gmm12g13<- gmm(y1[g==13]~x[g==13], x = cbind(z1[g==13],z2[g==13]), vcov = "iid", type = "twoStep");
gmm12g14<- gmm(y1[g==14]~x[g==14], x = cbind(z1[g==14],z2[g==14]), vcov = "iid", type = "twoStep");
gmm12g21<- gmm(y1[g==21]~x[g==21], x = cbind(z1[g==21],z2[g==21]), vcov = "iid", type = "twoStep");
gmm12g22<- gmm(y1[g==22]~x[g==22], x = cbind(z1[g==22],z2[g==22]), vcov = "iid", type = "twoStep");
gmm12g23<- gmm(y1[g==23]~x[g==23], x = cbind(z1[g==23],z2[g==23]), vcov = "iid", type = "twoStep");
gmm12g24<- gmm(y1[g==24]~x[g==24], x = cbind(z1[g==24],z2[g==24]), vcov = "iid", type = "twoStep");
gmm12g31<- gmm(y1[g==31]~x[g==31], x = cbind(z1[g==31],z2[g==31]), vcov = "iid", type = "twoStep");
gmm12g32<- gmm(y1[g==32]~x[g==32], x = cbind(z1[g==32],z2[g==32]), vcov = "iid", type = "twoStep");
gmm12g33<- gmm(y1[g==33]~x[g==33], x = cbind(z1[g==33],z2[g==33]), vcov = "iid", type = "twoStep");
gmm12g34<- gmm(y1[g==34]~x[g==34], x = cbind(z1[g==34],z2[g==34]), vcov = "iid", type = "twoStep");


oid12.y1	<- summary(gmm12)$j[1];
oid12g11.y1	<- summary(gmm12g11)$j[1];
oid12g12.y1	<- summary(gmm12g12)$j[1];
oid12g13.y1	<- summary(gmm12g13)$j[1];
oid12g14.y1	<- summary(gmm12g14)$j[1];
oid12g21.y1	<- summary(gmm12g21)$j[1];
oid12g22.y1	<- summary(gmm12g22)$j[1];
oid12g23.y1	<- summary(gmm12g23)$j[1];
oid12g24.y1	<- summary(gmm12g24)$j[1];
oid12g31.y1	<- summary(gmm12g31)$j[1];
oid12g32.y1	<- summary(gmm12g32)$j[1];
oid12g33.y1	<- summary(gmm12g33)$j[1];
oid12g34.y1	<- summary(gmm12g34)$j[1];

poid12.y1	<- summary(gmm12)$j[2];
poid12g11.y1	<- summary(gmm12g11)$j[2];
poid12g12.y1	<- summary(gmm12g12)$j[2];
poid12g13.y1	<- summary(gmm12g13)$j[2];
poid12g14.y1	<- summary(gmm12g14)$j[2];
poid12g21.y1	<- summary(gmm12g21)$j[2];
poid12g22.y1	<- summary(gmm12g22)$j[2];
poid12g23.y1	<- summary(gmm12g23)$j[2];
poid12g24.y1	<- summary(gmm12g24)$j[2];
poid12g31.y1	<- summary(gmm12g31)$j[2];
poid12g32.y1	<- summary(gmm12g32)$j[2];
poid12g33.y1	<- summary(gmm12g33)$j[2];
poid12g34.y1	<- summary(gmm12g34)$j[2];


gnam	 	<- paste("gi", 2:12, sep="")
xgnam	 	<- paste("x*gi", 2:12, sep="")
z1gnam	 	<- paste("z1*gi", 2:12, sep="")
z2gnam	 	<- paste("z2*gi", 2:12, sep="")
form2 	 	<- as.formula(paste("y1 ~ x + ", paste(gnam, collapse= "+"), "+", paste(xgnam, collapse= "+")));
inst	 	<- cbind(gi2, gi3, gi4, gi5, gi6, gi7, gi8, gi9, gi10, gi11, gi12, z1, z1*gi2, z1*gi3, z1*gi4, z1*gi5, z1*gi6, z1*gi7, z1*gi8, z1*gi9, z1*gi10, z1*gi11, z1*gi12, z2, z2*gi2, z2*gi3, z2*gi4, z2*gi5, z2*gi6, z2*gi7, z2*gi8, z2*gi9, z2*gi10, z2*gi11, z2*gi12);
gmm13	 	<- gmm(g = form2, x = inst, vcov = "iid", type = "twoStep");

oid13.y1 	<- summary(gmm13)$j[1];
poid13.y1 	<- summary(gmm13)$j[2];

rm(inst, gmm13);

form1	<- y2 ~ x;

gmm12	<- gmm(form1, x = cbind(z1,z2), vcov = "iid", type = "twoStep");
gmm12g11<- gmm(y2[g==11]~x[g==11], x = cbind(z1[g==11],z2[g==11]), vcov = "iid", type = "twoStep");
gmm12g12<- gmm(y2[g==12]~x[g==12], x = cbind(z1[g==12],z2[g==12]), vcov = "iid", type = "twoStep");
gmm12g13<- gmm(y2[g==13]~x[g==13], x = cbind(z1[g==13],z2[g==13]), vcov = "iid", type = "twoStep");
gmm12g14<- gmm(y2[g==14]~x[g==14], x = cbind(z1[g==14],z2[g==14]), vcov = "iid", type = "twoStep");
gmm12g21<- gmm(y2[g==21]~x[g==21], x = cbind(z1[g==21],z2[g==21]), vcov = "iid", type = "twoStep");
gmm12g22<- gmm(y2[g==22]~x[g==22], x = cbind(z1[g==22],z2[g==22]), vcov = "iid", type = "twoStep");
gmm12g23<- gmm(y2[g==23]~x[g==23], x = cbind(z1[g==23],z2[g==23]), vcov = "iid", type = "twoStep");
gmm12g24<- gmm(y2[g==24]~x[g==24], x = cbind(z1[g==24],z2[g==24]), vcov = "iid", type = "twoStep");
gmm12g31<- gmm(y2[g==31]~x[g==31], x = cbind(z1[g==31],z2[g==31]), vcov = "iid", type = "twoStep");
gmm12g32<- gmm(y2[g==32]~x[g==32], x = cbind(z1[g==32],z2[g==32]), vcov = "iid", type = "twoStep");
gmm12g33<- gmm(y2[g==33]~x[g==33], x = cbind(z1[g==33],z2[g==33]), vcov = "iid", type = "twoStep");
gmm12g34<- gmm(y2[g==34]~x[g==34], x = cbind(z1[g==34],z2[g==34]), vcov = "iid", type = "twoStep");


oid12.y2	<- summary(gmm12)$j[1];
oid12g11.y2	<- summary(gmm12g11)$j[1];
oid12g12.y2	<- summary(gmm12g12)$j[1];
oid12g13.y2	<- summary(gmm12g13)$j[1];
oid12g14.y2	<- summary(gmm12g14)$j[1];
oid12g21.y2	<- summary(gmm12g21)$j[1];
oid12g22.y2	<- summary(gmm12g22)$j[1];
oid12g23.y2	<- summary(gmm12g23)$j[1];
oid12g24.y2	<- summary(gmm12g24)$j[1];
oid12g31.y2	<- summary(gmm12g31)$j[1];
oid12g32.y2	<- summary(gmm12g32)$j[1];
oid12g33.y2	<- summary(gmm12g33)$j[1];
oid12g34.y2	<- summary(gmm12g34)$j[1];

poid12.y2	<- summary(gmm12)$j[2];
poid12g11.y2	<- summary(gmm12g11)$j[2];
poid12g12.y2	<- summary(gmm12g12)$j[2];
poid12g13.y2	<- summary(gmm12g13)$j[2];
poid12g14.y2	<- summary(gmm12g14)$j[2];
poid12g21.y2	<- summary(gmm12g21)$j[2];
poid12g22.y2	<- summary(gmm12g22)$j[2];
poid12g23.y2	<- summary(gmm12g23)$j[2];
poid12g24.y2	<- summary(gmm12g24)$j[2];
poid12g31.y2	<- summary(gmm12g31)$j[2];
poid12g32.y2	<- summary(gmm12g32)$j[2];
poid12g33.y2	<- summary(gmm12g33)$j[2];
poid12g34.y2	<- summary(gmm12g34)$j[2];


gnam	 	<- paste("gi", 2:12, sep="")
xgnam	 	<- paste("x*gi", 2:12, sep="")
z1gnam	 	<- paste("z1*gi", 2:12, sep="")
z2gnam	 	<- paste("z2*gi", 2:12, sep="")
form2 	 	<- as.formula(paste("y2 ~ x + ", paste(gnam, collapse= "+"), "+", paste(xgnam, collapse= "+")));
inst	 	<- cbind(gi2, gi3, gi4, gi5, gi6, gi7, gi8, gi9, gi10, gi11, gi12, z1, z1*gi2, z1*gi3, z1*gi4, z1*gi5, z1*gi6, z1*gi7, z1*gi8, z1*gi9, z1*gi10, z1*gi11, z1*gi12, z2, z2*gi2, z2*gi3, z2*gi4, z2*gi5, z2*gi6, z2*gi7, z2*gi8, z2*gi9, z2*gi10, z2*gi11, z2*gi12);
gmm13	 	<- gmm(g = form2, x = inst, vcov = "iid", type = "twoStep");

oid13.y2 	<- summary(gmm13)$j[1];
poid13.y2 	<- summary(gmm13)$j[2];

rm(inst, gmm13);


p11	<- mean(g==11);
p12	<- mean(g==12);
p13	<- mean(g==13);
p14	<- mean(g==14);
p21	<- mean(g==21);
p22	<- mean(g==22);
p23	<- mean(g==23);
p24	<- mean(g==24);
p31	<- mean(g==31);
p32	<- mean(g==32);
p33	<- mean(g==33);
p34	<- mean(g==34);

p11.x1	<- mean(g==11 & x==1) / mean(x==1);
p12.x1	<- mean(g==12 & x==1) / mean(x==1);
p13.x1	<- mean(g==13 & x==1) / mean(x==1);
p14.x1	<- mean(g==14 & x==1) / mean(x==1);
p21.x1	<- mean(g==21 & x==1) / mean(x==1);
p22.x1	<- mean(g==22 & x==1) / mean(x==1);
p23.x1	<- mean(g==23 & x==1) / mean(x==1);
p24.x1	<- mean(g==24 & x==1) / mean(x==1);
p31.x1	<- mean(g==31 & x==1) / mean(x==1);
p32.x1	<- mean(g==32 & x==1) / mean(x==1);
p33.x1	<- mean(g==33 & x==1) / mean(x==1);
p34.x1	<- mean(g==34 & x==1) / mean(x==1);

p11.x0	<- mean(g==11 & x==0) / mean(x==0);
p12.x0	<- mean(g==12 & x==0) / mean(x==0);
p13.x0	<- mean(g==13 & x==0) / mean(x==0);
p14.x0	<- mean(g==14 & x==0) / mean(x==0);
p21.x0	<- mean(g==21 & x==0) / mean(x==0);
p22.x0	<- mean(g==22 & x==0) / mean(x==0);
p23.x0	<- mean(g==23 & x==0) / mean(x==0);
p24.x0	<- mean(g==24 & x==0) / mean(x==0);
p31.x0	<- mean(g==31 & x==0) / mean(x==0);
p32.x0	<- mean(g==32 & x==0) / mean(x==0);
p33.x0	<- mean(g==33 & x==0) / mean(x==0);
p34.x0	<- mean(g==34 & x==0) / mean(x==0);




################################################################################################;
#				4 - PAIWISE COMPARISONS;
################################################################################################;

tdulate.y1	<- abs(ulate1.y1 - ulate2.y1)/sd(ulate1.y1.b - ulate2.y1.b);
tdlate1.y1	<- abs(late11.y1 - late12.y1)/sd(late11.y1.b - late12.y1.b);
tdlate2.y1	<- abs(late22.y1 - late21.y1)/sd(late22.y1.b - late21.y1.b);
tdate.y1	<- abs(ate1.y1 - ate2.y1)/sd(ate1.y1.b - ate2.y1.b);
tdtot.y1	<- abs(tot1.y1 - tot2.y1)/sd(tot1.y1.b - tot2.y1.b);
tdtnt.y1	<- abs(tnt1.y1 - tnt2.y1)/sd(tnt1.y1.b - tnt2.y1.b);
tdwate.y1	<- abs(wate1.y1 - wate2.y1)/sd(wate1.y1.b - wate2.y1.b);

ptdulate.y1	<- 2*(1-pnorm(tdulate.y1));
ptdlate1.y1	<- 2*(1-pnorm(tdlate1.y1));
ptdlate2.y1	<- 2*(1-pnorm(tdlate2.y1));
ptdate.y1	<- 2*(1-pnorm(tdate.y1));
ptdtot.y1	<- 2*(1-pnorm(tdtot.y1));
ptdtnt.y1	<- 2*(1-pnorm(tdtnt.y1));
ptdwate.y1	<- 2*(1-pnorm(tdwate.y1));

tdulate.y2	<- abs(ulate1.y2 - ulate2.y2)/sd(ulate1.y2.b - ulate2.y2.b);
tdlate1.y2	<- abs(late11.y2 - late12.y2)/sd(late11.y2.b - late12.y2.b);
tdlate2.y2	<- abs(late22.y2 - late21.y2)/sd(late22.y2.b - late21.y2.b);
tdate.y2	<- abs(ate1.y2 - ate2.y2)/sd(ate1.y2.b - ate2.y2.b);
tdtot.y2	<- abs(tot1.y2 - tot2.y2)/sd(tot1.y2.b - tot2.y2.b);
tdtnt.y2	<- abs(tnt1.y2 - tnt2.y2)/sd(tnt1.y2.b - tnt2.y2.b);
tdwate.y2	<- abs(wate1.y2 - wate2.y2)/sd(wate1.y2.b - wate2.y2.b);

ptdulate.y2	<- 2*(1-pnorm(tdulate.y2));
ptdlate1.y2	<- 2*(1-pnorm(tdlate1.y2));
ptdlate2.y2	<- 2*(1-pnorm(tdlate2.y2));
ptdate.y2	<- 2*(1-pnorm(tdate.y2));
ptdtot.y2	<- 2*(1-pnorm(tdtot.y2));
ptdtnt.y2	<- 2*(1-pnorm(tdtnt.y2));
ptdwate.y2	<- 2*(1-pnorm(tdwate.y2));





################################################################################################;
#				5 - TABLES OF RESULTS;
################################################################################################;


table3a		<- matrix(0, nrow = 24, ncol = 10, dimnames = list(c('X=(1,1)', ' ', 'X=(1,2)', ' ', 'X=(1,3)', ' ', 'X=(1,4)', ' ', 'X=(2,1)', ' ', 'X=(2,2)', ' ', 'X=(2,3)', ' ', 'X=(2,4)', ' ', 'X=(3,1)', ' ', 'X=(3,2)', ' ', 'X=(3,3)', ' ', 'X=(3,4)', ' '), c('P(X)', 'P(X|D=1)', 'P(X|D=0)',  'Estimate', 'Weight', 'Estimate', 'Weight','Estimate', 'J-stat', 'Weight')));

table3a[1,1]	<- p11;
table3a[1,2]	<- p11.x1/p11;
table3a[1,3]	<- p11.x0/p11;
table3a[1,4]	<- l1g11.y1;
table3a[1,5]	<- w1g11.y1;
table3a[1,6]	<- l2g11.y1;
table3a[1,7]	<- w2g11.y1;
table3a[1,8]	<- l13g11.y1;
table3a[1,9]	<- poid12g11.y1;
table3a[1,10]	<- ovg11.y1;


table3a[2,4]	<- sel1g11.y1;
#table3a[2,5]	<- sd(w1g11.y1.b);
table3a[2,6]	<- sel2g11.y1;
#table3a[2,7]	<- sd(w2g11.y1.b);
table3a[2,8]	<- sel13g11.y1;
#table3a[2,9]	<- poid12g11.y1;
#table3a[2,10]	<- sd(ovg11.y1.b);


table3a[3,1]	<- p12;
table3a[3,2]	<- p12.x1/p12;
table3a[3,3]	<- p12.x0/p12;
table3a[3,4]	<- l1g12.y1;
table3a[3,5]	<- w1g12.y1;
table3a[3,6]	<- l2g12.y1;
table3a[3,7]	<- w2g12.y1;
table3a[3,8]	<- l13g12.y1;
table3a[3,9]	<- poid12g12.y1;
table3a[3,10]	<- ovg12.y1;


table3a[4,4]	<- sel1g12.y1;
#table3a[4,5]	<- sd(w1g12.y1.b);
table3a[4,6]	<- sel2g12.y1;
#table3a[4,7]	<- sd(w2g12.y1.b);
table3a[4,8]	<- sel13g12.y1;
#table3a[4,9]	<- poid12g12.y1;
#table3a[4,10]	<- sd(ovg12.y1.b);

table3a[5,1]	<- p13;
table3a[5,2]	<- p13.x1/p13;
table3a[5,3]	<- p13.x0/p13;
table3a[5,4]	<- l1g13.y1;
table3a[5,5]	<- w1g13.y1;
table3a[5,6]	<- l2g13.y1;
table3a[5,7]	<- w2g13.y1;
table3a[5,8]	<- l13g13.y1;
table3a[5,9]	<- poid12g13.y1;
table3a[5,10]	<- ovg13.y1;


table3a[6,4]	<- sel1g13.y1;
#table3a[6,5]	<- sd(w1g13.y1.b);
table3a[6,6]	<- sel2g13.y1;
#table3a[6,7]	<- sd(w2g13.y1.b);
table3a[6,8]	<- sel13g13.y1;
#table3a[6,9]	<- poid12g13.y1;
#table3a[6,10]	<- sd(ovg13.y1.b);


table3a[7,1]	<- p14;
table3a[7,2]	<- p14.x1/p14;
table3a[7,3]	<- p14.x0/p14;
table3a[7,4]	<- l1g14.y1;
table3a[7,5]	<- w1g14.y1;
table3a[7,6]	<- l2g14.y1;
table3a[7,7]	<- w2g14.y1;
table3a[7,8]	<- l13g14.y1;
table3a[7,9]	<- poid12g14.y1;
table3a[7,10]	<- ovg14.y1;


table3a[8,4]	<- sel1g14.y1;
#table3a[8,5]	<- sd(w1g14.y1.b);
table3a[8,6]	<- sel2g14.y1;
#table3a[8,7]	<- sd(w2g14.y1.b);
table3a[8,8]	<- sel13g14.y1;
#table3a[8,9]	<- poid12g14.y1;
#table3a[8,10]	<- sd(ovg14.y1.b);


table3a[9,1]	<- p21;
table3a[9,2]	<- p21.x1/p21;
table3a[9,3]	<- p21.x0/p21;
table3a[9,4]	<- l1g21.y1;
table3a[9,5]	<- w1g21.y1;
table3a[9,6]	<- l2g21.y1;
table3a[9,7]	<- w2g21.y1;
table3a[9,8]	<- l13g21.y1;
table3a[9,9]	<- poid12g21.y1;
table3a[9,10]	<- ovg21.y1;


table3a[10,4]	<- sel1g21.y1;
#table3a[10,5]	<- sd(w1g21.y1.b);
table3a[10,6]	<- sel2g21.y1;
#table3a[10,7]	<- sd(w2g21.y1.b);
table3a[10,8]	<- sel13g21.y1;
#table3a[10,9]	<- poid12g21.y1;
#table3a[10,10]	<- sd(ovg21.y1.b);

table3a[11,1]	<- p22;
table3a[11,2]	<- p22.x1/p22;
table3a[11,3]	<- p22.x0/p22;
table3a[11,4]	<- l1g22.y1;
table3a[11,5]	<- w1g22.y1;
table3a[11,6]	<- l2g22.y1;
table3a[11,7]	<- w2g22.y1;
table3a[11,8]	<- l13g22.y1;
table3a[11,9]	<- poid12g22.y1;
table3a[11,10]	<- ovg22.y1;


table3a[12,4]	<- sel1g22.y1;
#table3a[12,5]	<- sd(w1g22.y1.b);
table3a[12,6]	<- sel2g22.y1;
#table3a[12,7]	<- sd(w2g22.y1.b);
table3a[12,8]	<- sel13g22.y1;
#table3a[12,9]	<- poid12g22.y1;
#table3a[12,10]	<- sd(ovg22.y1.b);

table3a[13,1]	<- p23;
table3a[13,2]	<- p23.x1/p23;
table3a[13,3]	<- p23.x0/p23;
table3a[13,4]	<- l1g23.y1;
table3a[13,5]	<- w1g23.y1;
table3a[13,6]	<- l2g23.y1;
table3a[13,7]	<- w2g23.y1;
table3a[13,8]	<- l13g23.y1;
table3a[13,9]	<- poid12g23.y1;
table3a[13,10]	<- ovg23.y1;


table3a[14,4]	<- sel1g23.y1;
#table3a[14,5]	<- sd(w1g23.y1.b);
table3a[14,6]	<- sel2g23.y1;
#table3a[14,7]	<- sd(w2g23.y1.b);
table3a[14,8]	<- sel13g23.y1;
#table3a[14,9]	<- poid12g23.y1;
#table3a[14,10]	<- sd(ovg23.y1.b);

table3a[15,1]	<- p24;
table3a[15,2]	<- p24.x1/p24;
table3a[15,3]	<- p24.x0/p24;
table3a[15,4]	<- l1g24.y1;
table3a[15,5]	<- w1g24.y1;
table3a[15,6]	<- l2g24.y1;
table3a[15,7]	<- w2g24.y1;
table3a[15,8]	<- l13g24.y1;
table3a[15,9]	<- poid12g24.y1;
table3a[15,10]	<- ovg24.y1;


table3a[16,4]	<- sel1g24.y1;
#table3a[16,5]	<- sd(w1g24.y1.b);
table3a[16,6]	<- sel2g24.y1;
#table3a[16,7]	<- sd(w2g24.y1.b);
table3a[16,8]	<- sel13g24.y1;
#table3a[16,9]	<- poid12g24.y1;
#table3a[16,10]	<- sd(ovg24.y1.b);

table3a[17,1]	<- p31;
table3a[17,2]	<- p31.x1/p31;
table3a[17,3]	<- p31.x0/p31;
table3a[17,4]	<- l1g31.y1;
table3a[17,5]	<- w1g31.y1;
table3a[17,6]	<- l2g31.y1;
table3a[17,7]	<- w2g31.y1;
table3a[17,8]	<- l13g31.y1;
table3a[17,9]	<- poid12g31.y1;
table3a[17,10]	<- ovg31.y1;


table3a[18,4]	<- sel1g31.y1;
#table3a[18,5]	<- sd(w1g31.y1.b);
table3a[18,6]	<- sel2g31.y1;
#table3a[18,7]	<- sd(w2g31.y1.b);
table3a[18,8]	<- sel13g31.y1;
#table3a[18,9]	<- poid12g31.y1;
#table3a[18,10]	<- sd(ovg31.y1.b);

table3a[19,1]	<- p32;
table3a[19,2]	<- p32.x1/p32;
table3a[19,3]	<- p32.x0/p32;
table3a[19,4]	<- l1g32.y1;
table3a[19,5]	<- w1g32.y1;
table3a[19,6]	<- l2g32.y1;
table3a[19,7]	<- w2g32.y1;
table3a[19,8]	<- l13g32.y1;
table3a[19,9]	<- poid12g32.y1;
table3a[19,10]	<- ovg32.y1;


table3a[20,4]	<- sel1g32.y1;
#table3a[20,5]	<- sd(w1g32.y1.b);
table3a[20,6]	<- sel2g32.y1;
#table3a[20,7]	<- sd(w2g32.y1.b);
table3a[20,8]	<- sel13g32.y1;
#table3a[20,9]	<- poid12g32.y1;
#table3a[20,10]	<- sd(ovg32.y1.b);

table3a[21,1]	<- p33;
table3a[21,2]	<- p33.x1/p33;
table3a[21,3]	<- p33.x0/p33;
table3a[21,4]	<- l1g33.y1;
table3a[21,5]	<- w1g33.y1;
table3a[21,6]	<- l2g33.y1;
table3a[21,7]	<- w2g33.y1;
table3a[21,8]	<- l13g33.y1;
table3a[21,9]	<- poid12g33.y1;
table3a[21,10]	<- ovg33.y1;


table3a[22,4]	<- sel1g33.y1;
#table3a[22,5]	<- sd(w1g33.y1.b);
table3a[22,6]	<- sel2g33.y1;
#table3a[22,7]	<- sd(w2g33.y1.b);
table3a[22,8]	<- sel13g33.y1;
#table3a[22,9]	<- poid12g33.y1;
#table3a[22,10]	<- sd(ovg33.y1.b);

table3a[23,1]	<- p34;
table3a[23,2]	<- p34.x1/p34;
table3a[23,3]	<- p34.x0/p34;
table3a[23,4]	<- l1g34.y1;
table3a[23,5]	<- w1g34.y1;
table3a[23,6]	<- l2g34.y1;
table3a[23,7]	<- w2g34.y1;
table3a[23,8]	<- l13g34.y1;
table3a[23,9]	<- poid12g34.y1;
table3a[23,10]	<- ovg34.y1;


table3a[24,4]	<- sel1g34.y1;
#table3a[24,5]	<- sd(w1g34.y1.b);
table3a[24,6]	<- sel2g34.y1;
#table3a[24,7]	<- sd(w2g34.y1.b);
table3a[24,8]	<- sel13g34.y1;
#table3a[24,9]	<- poid12g34.y1;
#table3a[24,10]	<- sd(ovg34.y1.b);


table3b		<- matrix(0, nrow = 24, ncol = 10, dimnames = list(c('X=(1,1)', ' ', 'X=(1,2)', ' ', 'X=(1,3)', ' ', 'X=(1,4)', ' ', 'X=(2,1)', ' ', 'X=(2,2)', ' ', 'X=(2,3)', ' ', 'X=(2,4)', ' ', 'X=(3,1)', ' ', 'X=(3,2)', ' ', 'X=(3,3)', ' ', 'X=(3,4)', ' '), c('P(X)', 'P(X|D=1)', 'P(X|D=0)',  'Estimate', 'Weight', 'Estimate', 'Weight','Estimate', 'J-stat', 'Weight')));

table3b[1,1]	<- p11;
table3b[1,2]	<- p11.x1/p11;
table3b[1,3]	<- p11.x0/p11;
table3b[1,4]	<- l1g11.y2;
table3b[1,5]	<- w1g11.y2;
table3b[1,6]	<- l2g11.y2;
table3b[1,7]	<- w2g11.y2;
table3b[1,8]	<- l13g11.y2;
table3b[1,9]	<- poid12g11.y2;
table3b[1,10]	<- ovg11.y2;


table3b[2,4]	<- sel1g11.y2;
#table3b[2,5]	<- sd(w1g11.y2.b);
table3b[2,6]	<- sel2g11.y2;
#table3b[2,7]	<- sd(w2g11.y2.b);
table3b[2,8]	<- sel13g11.y2;
#table3b[2,9]	<- poid12g11.y2;
#table3b[2,10]	<- sd(ovg11.y2.b);


table3b[3,1]	<- p12;
table3b[3,2]	<- p12.x1/p12;
table3b[3,3]	<- p12.x0/p12;
table3b[3,4]	<- l1g12.y2;
table3b[3,5]	<- w1g12.y2;
table3b[3,6]	<- l2g12.y2;
table3b[3,7]	<- w2g12.y2;
table3b[3,8]	<- l13g12.y2;
table3b[3,9]	<- poid12g12.y2;
table3b[3,10]	<- ovg12.y2;


table3b[4,4]	<- sel1g12.y2;
#table3b[4,5]	<- sd(w1g12.y2.b);
table3b[4,6]	<- sel2g12.y2;
#table3b[4,7]	<- sd(w2g12.y2.b);
table3b[4,8]	<- sel13g12.y2;
#table3b[4,9]	<- poid12g12.y2;
#table3b[4,10]	<- sd(ovg12.y2.b);

table3b[5,1]	<- p13;
table3b[5,2]	<- p13.x1/p13;
table3b[5,3]	<- p13.x0/p13;
table3b[5,4]	<- l1g13.y2;
table3b[5,5]	<- w1g13.y2;
table3b[5,6]	<- l2g13.y2;
table3b[5,7]	<- w2g13.y2;
table3b[5,8]	<- l13g13.y2;
table3b[5,9]	<- poid12g13.y2;
table3b[5,10]	<- ovg13.y2;


table3b[6,4]	<- sel1g13.y2;
#table3b[6,5]	<- sd(w1g13.y2.b);
table3b[6,6]	<- sel2g13.y2;
#table3b[6,7]	<- sd(w2g13.y2.b);
table3b[6,8]	<- sel13g13.y2;
#table3b[6,9]	<- poid12g13.y2;
#table3b[6,10]	<- sd(ovg13.y2.b);


table3b[7,1]	<- p14;
table3b[7,2]	<- p14.x1/p14;
table3b[7,3]	<- p14.x0/p14;
table3b[7,4]	<- l1g14.y2;
table3b[7,5]	<- w1g14.y2;
table3b[7,6]	<- l2g14.y2;
table3b[7,7]	<- w2g14.y2;
table3b[7,8]	<- l13g14.y2;
table3b[7,9]	<- poid12g14.y2;
table3b[7,10]	<- ovg14.y2;


table3b[8,4]	<- sel1g14.y2;
#table3b[8,5]	<- sd(w1g14.y2.b);
table3b[8,6]	<- sel2g14.y2;
#table3b[8,7]	<- sd(w2g14.y2.b);
table3b[8,8]	<- sel13g14.y2;
#table3b[8,9]	<- poid12g14.y2;
#table3b[8,10]	<- sd(ovg14.y2.b);


table3b[9,1]	<- p21;
table3b[9,2]	<- p21.x1/p21;
table3b[9,3]	<- p21.x0/p21;
table3b[9,4]	<- l1g21.y2;
table3b[9,5]	<- w1g21.y2;
table3b[9,6]	<- l2g21.y2;
table3b[9,7]	<- w2g21.y2;
table3b[9,8]	<- l13g21.y2;
table3b[9,9]	<- poid12g21.y2;
table3b[9,10]	<- ovg21.y2;


table3b[10,4]	<- sel1g21.y2;
#table3b[10,5]	<- sd(w1g21.y2.b);
table3b[10,6]	<- sel2g21.y2;
#table3b[10,7]	<- sd(w2g21.y2.b);
table3b[10,8]	<- sel13g21.y2;
#table3b[10,9]	<- poid12g21.y2;
#table3b[10,10]	<- sd(ovg21.y2.b);

table3b[11,1]	<- p22;
table3b[11,2]	<- p22.x1/p22;
table3b[11,3]	<- p22.x0/p22;
table3b[11,4]	<- l1g22.y2;
table3b[11,5]	<- w1g22.y2;
table3b[11,6]	<- l2g22.y2;
table3b[11,7]	<- w2g22.y2;
table3b[11,8]	<- l13g22.y2;
table3b[11,9]	<- poid12g22.y2;
table3b[11,10]	<- ovg22.y2;


table3b[12,4]	<- sel1g22.y2;
#table3b[12,5]	<- sd(w1g22.y2.b);
table3b[12,6]	<- sel2g22.y2;
#table3b[12,7]	<- sd(w2g22.y2.b);
table3b[12,8]	<- sel13g22.y2;
#table3b[12,9]	<- poid12g22.y2;
#table3b[12,10]	<- sd(ovg22.y2.b);

table3b[13,1]	<- p23;
table3b[13,2]	<- p23.x1/p23;
table3b[13,3]	<- p23.x0/p23;
table3b[13,4]	<- l1g23.y2;
table3b[13,5]	<- w1g23.y2;
table3b[13,6]	<- l2g23.y2;
table3b[13,7]	<- w2g23.y2;
table3b[13,8]	<- l13g23.y2;
table3b[13,9]	<- poid12g23.y2;
table3b[13,10]	<- ovg23.y2;


table3b[14,4]	<- sel1g23.y2;
#table3b[14,5]	<- sd(w1g23.y2.b);
table3b[14,6]	<- sel2g23.y2;
#table3b[14,7]	<- sd(w2g23.y2.b);
table3b[14,8]	<- sel13g23.y2;
#table3b[14,9]	<- poid12g23.y2;
#table3b[14,10]	<- sd(ovg23.y2.b);

table3b[15,1]	<- p24;
table3b[15,2]	<- p24.x1/p24;
table3b[15,3]	<- p24.x0/p24;
table3b[15,4]	<- l1g24.y2;
table3b[15,5]	<- w1g24.y2;
table3b[15,6]	<- l2g24.y2;
table3b[15,7]	<- w2g24.y2;
table3b[15,8]	<- l13g24.y2;
table3b[15,9]	<- poid12g24.y2;
table3b[15,10]	<- ovg24.y2;


table3b[16,4]	<- sel1g24.y2;
#table3b[16,5]	<- sd(w1g24.y2.b);
table3b[16,6]	<- sel2g24.y2;
#table3b[16,7]	<- sd(w2g24.y2.b);
table3b[16,8]	<- sel13g24.y2;
#table3b[16,9]	<- poid12g24.y2;
#table3b[16,10]	<- sd(ovg24.y2.b);

table3b[17,1]	<- p31;
table3b[17,2]	<- p31.x1/p31;
table3b[17,3]	<- p31.x0/p31;
table3b[17,4]	<- l1g31.y2;
table3b[17,5]	<- w1g31.y2;
table3b[17,6]	<- l2g31.y2;
table3b[17,7]	<- w2g31.y2;
table3b[17,8]	<- l13g31.y2;
table3b[17,9]	<- poid12g31.y2;
table3b[17,10]	<- ovg31.y2;


table3b[18,4]	<- sel1g31.y2;
#table3b[18,5]	<- sd(w1g31.y2.b);
table3b[18,6]	<- sel2g31.y2;
#table3b[18,7]	<- sd(w2g31.y2.b);
table3b[18,8]	<- sel13g31.y2;
#table3b[18,9]	<- poid12g31.y2;
#table3b[18,10]	<- sd(ovg31.y2.b);

table3b[19,1]	<- p32;
table3b[19,2]	<- p32.x1/p32;
table3b[19,3]	<- p32.x0/p32;
table3b[19,4]	<- l1g32.y2;
table3b[19,5]	<- w1g32.y2;
table3b[19,6]	<- l2g32.y2;
table3b[19,7]	<- w2g32.y2;
table3b[19,8]	<- l13g32.y2;
table3b[19,9]	<- poid12g32.y2;
table3b[19,10]	<- ovg32.y2;


table3b[20,4]	<- sel1g32.y2;
#table3b[20,5]	<- sd(w1g32.y2.b);
table3b[20,6]	<- sel2g32.y2;
#table3b[20,7]	<- sd(w2g32.y2.b);
table3b[20,8]	<- sel13g32.y2;
#table3b[20,9]	<- poid12g32.y2;
#table3b[20,10]	<- sd(ovg32.y2.b);

table3b[21,1]	<- p33;
table3b[21,2]	<- p33.x1/p33;
table3b[21,3]	<- p33.x0/p33;
table3b[21,4]	<- l1g33.y2;
table3b[21,5]	<- w1g33.y2;
table3b[21,6]	<- l2g33.y2;
table3b[21,7]	<- w2g33.y2;
table3b[21,8]	<- l13g33.y2;
table3b[21,9]	<- poid12g33.y2;
table3b[21,10]	<- ovg33.y2;


table3b[22,4]	<- sel1g33.y2;
#table3b[22,5]	<- sd(w1g33.y2.b);
table3b[22,6]	<- sel2g33.y2;
#table3b[22,7]	<- sd(w2g33.y2.b);
table3b[22,8]	<- sel13g33.y2;
#table3b[22,9]	<- poid12g33.y2;
#table3b[22,10]	<- sd(ovg33.y2.b);

table3b[23,1]	<- p34;
table3b[23,2]	<- p34.x1/p34;
table3b[23,3]	<- p34.x0/p34;
table3b[23,4]	<- l1g34.y2;
table3b[23,5]	<- w1g34.y2;
table3b[23,6]	<- l2g34.y2;
table3b[23,7]	<- w2g34.y2;
table3b[23,8]	<- l13g34.y2;
table3b[23,9]	<- poid12g34.y2;
table3b[23,10]	<- ovg34.y2;


table3b[24,4]	<- sel1g34.y2;
#table3b[24,5]	<- sd(w1g34.y2.b);
table3b[24,6]	<- sel2g34.y2;
#table3b[24,7]	<- sd(w2g34.y2.b);
table3b[24,8]	<- sel13g34.y2;
#table3b[24,9]	<- poid12g34.y2;
#table3b[24,10]	<- sd(ovg34.y2.b);


table4		<- matrix(0, nrow = 38, ncol = 6, dimnames = list(c('IV', ' ',' ', ' ', ' ', ' ', 'LATE', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'ATE ', ' ', '', ' ', '', ' ', 'TOT', ' ', '', ' ', '', ' ', 'TNT', ' ', ' ', ' ', ' ', ' ', 'CATE', ' ', ' ', ' ', ' ', ' '), c('Instruments', 'Weights', 'Estimate', 't-stat', 'Estimate', 't-stat')));


table4[1,1]	<- 'samesex';
table4[2,1]	<- ' ';
table4[3,1]	<- 'twins';
table4[4,1]	<- ' ';
table4[5,1]	<- 'samesex, twins';
table4[6,1]	<- ' ';
table4[7,1]	<- 'samesex';
table4[8,1]	<- ' ';
table4[9,1]	<- 'twins';
table4[10,1]	<- ' ';
table4[11,1]	<- 'twins';
table4[12,1]	<- ' ';
table4[13,1]	<- 'samesex';
table4[14,1]	<- ' ';
table4[15,1]	<- 'samesex';
table4[16,1]	<- ' ';
table4[17,1]	<- 'twins';
table4[18,1]	<- ' ';
table4[19,1]	<- 'samesex, twins';
table4[20,1]	<- ' ';
table4[21,1]	<- 'samesex';
table4[22,1]	<- ' ';
table4[23,1]	<- 'twins';
table4[24,1]	<- ' ';
table4[25,1]	<- 'samesex, twins';
table4[26,1]	<- ' ';
table4[27,1]	<- 'samesex';
table4[28,1]	<- ' ';
table4[29,1]	<- 'twins';
table4[30,1]	<- ' ';
table4[31,1]	<- 'samesex, twins';
table4[32,1]	<- ' ';
table4[33,1]	<- 'samesex';
table4[34,1]	<- ' ';
table4[35,1]	<- 'twins';
table4[36,1]	<- ' ';
table4[37,1]	<- 'samesex, twins';
table4[38,1]	<- ' ';


table4[1,2]	<- ' ';
table4[2,2]	<- ' ';
table4[3,2]	<- ' ';
table4[4,2]	<- ' ';
table4[5,2]	<- ' ';
table4[6,2]	<- ' ';
table4[7,2]	<- 'samesex';
table4[8,2]	<- ' ';
table4[9,2]	<- 'samesex';
table4[10,2]	<- ' ';
table4[11,2]	<- 'twins';
table4[12,2]	<- ' ';
table4[13,2]	<- 'twins';
table4[14,2]	<- ' ';
table4[15,2]	<- ' ';
table4[16,2]	<- ' ';
table4[17,2]	<- ' ';
table4[18,2]	<- ' ';
table4[19,2]	<- ' ';
table4[20,2]	<- ' ';
table4[21,2]	<- ' ';
table4[22,2]	<- ' ';
table4[23,2]	<- ' ';
table4[24,2]	<- ' ';
table4[25,2]	<- ' ';
table4[26,2]	<- ' ';
table4[27,2]	<- ' ';
table4[28,2]	<- ' ';
table4[29,2]	<- ' ';
table4[30,2]	<- ' ';
table4[31,2]	<- ' ';
table4[32,2]	<- ' ';
table4[33,2]	<- ' ';
table4[34,2]	<- ' ';
table4[35,2]	<- ' ';
table4[36,2]	<- ' ';
table4[37,2]	<- ' ';
table4[38,2]	<- ' ';

table4[1,3]	<- ulate1.y1;
table4[3,3]	<- ulate2.y1;
table4[5,3]	<- ulate13.y1;
table4[7,3]	<- late11.y1;
table4[9,3]	<- late12.y1;
table4[11,3]	<- late22.y1;
table4[13,3]	<- late21.y1;
table4[15,3]	<- ate1.y1;
table4[17,3]	<- ate2.y1;
table4[19,3]	<- ate13.y1;
table4[21,3]	<- tot1.y1;
table4[23,3]	<- tot2.y1;
table4[25,3]	<- tot13.y1;
table4[27,3]	<- tnt1.y1;
table4[29,3]	<- tnt2.y1;
table4[31,3]	<- tnt13.y1;
table4[33,3]	<- wate1.y1;
table4[35,3]	<- wate2.y1;
table4[37,3]	<- wate13.y1;

table4[2,3]	<- sd(ulate1.y1.b);
table4[4,3]	<- sd(ulate2.y1.b);
table4[6,3]	<- sd(ulate13.y1.b);
table4[8,3]	<- sd(late11.y1.b);
table4[10,3]	<- sd(late12.y1.b);
table4[12,3]	<- sd(late22.y1.b);
table4[14,3]	<- sd(late21.y1.b);
table4[16,3]	<- sd(ate1.y1.b);
table4[18,3]	<- sd(ate2.y1.b);
table4[20,3]	<- sd(ate13.y1.b);
table4[22,3]	<- sd(tot1.y1.b);
table4[24,3]	<- sd(tot2.y1.b);
table4[26,3]	<- sd(tot13.y1.b);
table4[28,3]	<- sd(tnt1.y1.b);
table4[30,3]	<- sd(tnt2.y1.b);
table4[32,3]	<- sd(tnt13.y1.b);
table4[34,3]	<- sd(wate1.y1.b);
table4[36,3]	<- sd(wate2.y1.b);
table4[38,3]	<- sd(wate13.y1.b);


table4[1,4]	<- ' ';
table4[3,4]	<- ' ';
table4[5,4]	<- ' ';
table4[7,4]	<- ' ';
table4[9,4]	<- ' ';
table4[11,4]	<- ' ';
table4[13,4]	<- ' ';
table4[15,4]	<- ' ';
table4[17,4]	<- ' ';
table4[19,4]	<- ' ';
table4[21,4]	<- ' ';
table4[23,4]	<- ' ';
table4[25,4]	<- ' ';
table4[27,4]	<- ' ';
table4[29,4]	<- ' ';
table4[31,4]	<- ' ';
table4[33,4]	<- ' ';
table4[35,4]	<- ' ';
table4[37,4]	<- ' ';


table4[2,4]	<- tdulate.y1;
table4[4,4]	<- ' ';
table4[6,4]	<- ' ';
table4[8,4]	<- tdlate1.y1;
table4[10,4]	<- ' ';
table4[12,4]	<- tdlate2.y1;
table4[14,4]	<- ' ';
table4[16,4]	<- tdate.y1;
table4[18,4]	<- ' ';
table4[20,4]	<- ' ';
table4[22,4]	<- tdtot.y1;
table4[24,4]	<- ' ';
table4[26,4]	<- ' ';
table4[28,4]	<- tdtnt.y1;
table4[30,4]	<- ' ';
table4[32,4]	<- ' ';
table4[34,4]	<- tdwate.y1;
table4[36,4]	<- ' ';
table4[38,4]	<- ' ';

table4[1,5]	<- ulate1.y2;
table4[3,5]	<- ulate2.y2;
table4[5,5]	<- ulate13.y2;
table4[7,5]	<- late11.y2;
table4[9,5]	<- late12.y2;
table4[11,5]	<- late22.y2;
table4[13,5]	<- late21.y2;
table4[15,5]	<- ate1.y2;
table4[17,5]	<- ate2.y2;
table4[19,5]	<- ate13.y2;
table4[21,5]	<- tot1.y2;
table4[23,5]	<- tot2.y2;
table4[25,5]	<- tot13.y2;
table4[27,5]	<- tnt1.y2;
table4[29,5]	<- tnt2.y2;
table4[31,5]	<- tnt13.y2;
table4[33,5]	<- wate1.y2;
table4[35,5]	<- wate2.y2;
table4[37,5]	<- wate13.y2;

table4[2,5]	<- sd(ulate1.y2.b);
table4[4,5]	<- sd(ulate2.y2.b);
table4[6,5]	<- sd(ulate13.y2.b);
table4[8,5]	<- sd(late11.y2.b);
table4[10,5]	<- sd(late12.y2.b);
table4[12,5]	<- sd(late22.y2.b);
table4[14,5]	<- sd(late21.y2.b);
table4[16,5]	<- sd(ate1.y2.b);
table4[18,5]	<- sd(ate2.y2.b);
table4[20,5]	<- sd(ate13.y2.b);
table4[22,5]	<- sd(tot1.y2.b);
table4[24,5]	<- sd(tot2.y2.b);
table4[26,5]	<- sd(tot13.y2.b);
table4[28,5]	<- sd(tnt1.y2.b);
table4[30,5]	<- sd(tnt2.y2.b);
table4[32,5]	<- sd(tnt13.y2.b);
table4[34,5]	<- sd(wate1.y2.b);
table4[36,5]	<- sd(wate2.y2.b);
table4[38,5]	<- sd(wate13.y2.b);


table4[1,6]	<- ' ';
table4[3,6]	<- ' ';
table4[5,6]	<- ' ';
table4[7,6]	<- ' ';
table4[9,6]	<- ' ';
table4[11,6]	<- ' ';
table4[13,6]	<- ' ';
table4[15,6]	<- ' ';
table4[17,6]	<- ' ';
table4[19,6]	<- ' ';
table4[21,6]	<- ' ';
table4[23,6]	<- ' ';
table4[25,6]	<- ' ';
table4[27,6]	<- ' ';
table4[29,6]	<- ' ';
table4[31,6]	<- ' ';
table4[33,6]	<- ' ';
table4[35,6]	<- ' ';
table4[37,6]	<- ' ';

table4[2,6]	<- tdulate.y2;
table4[4,6]	<- ' ';
table4[6,6]	<- ' ';
table4[8,6]	<- tdlate1.y2;
table4[10,6]	<- ' ';
table4[12,6]	<- tdlate2.y2;
table4[14,6]	<- ' ';
table4[16,6]	<- tdate.y2;
table4[18,6]	<- ' ';
table4[20,6]	<- ' ';
table4[22,6]	<- tdtot.y2;
table4[24,6]	<- ' ';
table4[26,6]	<- ' ';
table4[28,6]	<- tdtnt.y2;
table4[30,6]	<- ' ';
table4[32,6]	<- ' ';
table4[34,6]	<- tdwate.y2;
table4[36,6]	<- ' ';
table4[38,6]	<- ' ';



################################################################################################;
#				6 - FIGURES;
################################################################################################;

ovid		<- c(ovg11.y1, ovg12.y1, ovg13.y1, ovg14.y1, ovg21.y1, ovg22.y1, ovg23.y1, ovg24.y1, ovg31.y1, ovg32.y1, ovg33.y1, ovg34.y1);
p		<- c(p11, p12, p13, p14, p21, p22, p23, p24, p31, p32, p33, p34);
p.x1		<- c(p11.x1, p12.x1, p13.x1, p14.x1, p21.x1, p22.x1, p23.x1, p24.x1, p31.x1, p32.x1, p33.x1, p34.x1);
p.x0		<- c(p11.x0, p12.x0, p13.x0, p14.x0, p21.x0, p22.x0, p23.x0, p24.x0, p31.x0, p32.x0, p33.x0, p34.x0);
pov		<- ovid * p;
cov		<- c(11, 12, 13, 14, 21, 22, 23, 24, 31, 32, 33, 34);
names(p) 	<- rep('P(X)',12);
names(p.x1) 	<- rep('P(X|D=1)',12);
names(p.x0) 	<- rep('P(X|D=0)',12);
names(pov) 	<- rep('P(X)*OVID',12);
names(cov)	<- c('Age=1, Educ=1', 'Age=1, Educ=2','Age=1, Educ=3','Age=1, Educ=4','Age=2, Educ=1','Age=2, Educ=2','Age=2, Educ=3','Age=2, Educ=4','Age=3, Educ=1','Age=3, Educ=2','Age=3, Educ=3','Age=3, Educ=4')


px1g11	<- mean(g==11 & x==1) / mean(g==11);
px1g12	<- mean(g==12 & x==1) / mean(g==12);
px1g13	<- mean(g==13 & x==1) / mean(g==13);
px1g14	<- mean(g==14 & x==1) / mean(g==14);
px1g21	<- mean(g==21 & x==1) / mean(g==21);
px1g22	<- mean(g==22 & x==1) / mean(g==22);
px1g23	<- mean(g==23 & x==1) / mean(g==23);
px1g24	<- mean(g==24 & x==1) / mean(g==24);
px1g31	<- mean(g==31 & x==1) / mean(g==31);
px1g32	<- mean(g==32 & x==1) / mean(g==32);
px1g33	<- mean(g==33 & x==1) / mean(g==33);
px1g34	<- mean(g==34 & x==1) / mean(g==34);

wpx1	<- c(px1g11, px1g12, px1g13, px1g14, px1g21, px1g22, px1g23, px1g24, px1g31, px1g32, px1g33, px1g34)/mean(x==1);

px0g11	<- mean(g==11 & x==0) / mean(g==11);
px0g12	<- mean(g==12 & x==0) / mean(g==12);
px0g13	<- mean(g==13 & x==0) / mean(g==13);
px0g14	<- mean(g==14 & x==0) / mean(g==14);
px0g21	<- mean(g==21 & x==0) / mean(g==21);
px0g22	<- mean(g==22 & x==0) / mean(g==22);
px0g23	<- mean(g==23 & x==0) / mean(g==23);
px0g24	<- mean(g==24 & x==0) / mean(g==24);
px0g31	<- mean(g==31 & x==0) / mean(g==31);
px0g32	<- mean(g==32 & x==0) / mean(g==32);
px0g33	<- mean(g==33 & x==0) / mean(g==33);
px0g34	<- mean(g==34 & x==0) / mean(g==34);

wpx0	<- c(px0g11, px0g12, px0g13, px0g14, px0g21, px0g22, px0g23, px0g24, px0g31, px0g32, px0g33, px0g34)/mean(x==0);

wovid	<- ovid;

wovid.y1	<- ovid;

wiv1	<- c(w1g11.y1, w1g12.y1, w1g13.y1, w1g14.y1, w1g21.y1, w1g22.y1, w1g23.y1, w1g24.y1, w1g31.y1, w1g32.y1, w1g33.y1, w1g34.y1);

wiv2	<- c(w2g11.y1, w2g12.y1, w2g13.y1, w2g14.y1, w2g21.y1, w2g22.y1, w2g23.y1, w2g24.y1, w2g31.y1, w2g32.y1, w2g33.y1, w2g34.y1);


ovid		<- c(ovg11.y2, ovg12.y2, ovg13.y2, ovg14.y2, ovg21.y2, ovg22.y2, ovg23.y2, ovg24.y2, ovg31.y2, ovg32.y2, ovg33.y2, ovg34.y2);
pov		<- ovid * p;

wovid	<- ovid;

wovid.y2	<- ovid;

wiv1	<- c(w1g11.y2, w1g12.y2, w1g13.y2, w1g14.y2, w1g21.y2, w1g22.y2, w1g23.y2, w1g24.y2, w1g31.y2, w1g32.y2, w1g33.y2, w1g34.y2);

wiv2	<- c(w2g11.y2, w2g12.y2, w2g13.y2, w2g14.y2, w2g21.y2, w2g22.y2, w2g23.y2, w2g24.y2, w2g31.y2, w2g32.y2, w2g33.y2, w2g34.y2);



postscript("weights-divided-by-2.eps",horizontal=TRUE,onefile=FALSE,height=6,width=8,pointsize=10);

par(mfrow=c(3,4));

barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[1,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = 'HS dropout', ylab = expression(bold("Age 2nd child <= 4")), ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[2,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = 'HS grad', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[3,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = 'Some college', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[4,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = 'College grad', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[5,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = expression(bold("4 < Age 2nd child <= 8")), ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[6,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[7,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[8,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[9,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = expression(bold("Age 2nd child > 8")), ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[10,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[11,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);
barplot(cbind(wiv2, wiv1, wpx1, wovid.y1, wovid.y2)[12,], names.arg = c('Twins (TNT)', 'Same-sex', 'TOT', 'CATE Y1', 'CATE Y2'), beside=TRUE, horiz=FALSE, main = ' ', ylab = ' ', ylim = c(0, 2.25), col = c(2:7), cex.names=.5, cex.axis = .65);

dev.off();

